@@ -47,8 +47,9 @@ module Kz
 
   begin
     require 'gtk2'
+    GLib::Log.cancel_handler
     ENABLE = true
-    TMP_DIR = File.join(GLib.tmp_dir, PACKAGE)
+    TMP_DIR = File.join(GLib.tmp_dir, "#{PACKAGE}-#{Process.pid}")
     barrier do
       FileUtils.rm_rf(TMP_DIR)
       FileUtils.mkdir_p(TMP_DIR)
@@ -58,6 +59,6 @@ module Kz
     end
   rescue Exception
     ENABLE = false
-    print_warning(_("Ruby extension disabled: failed require 'gtk2'"))
+    print_warning(Kz.gettext("Ruby extension disabled: failed require 'gtk2'"))
   end
 end
