@@ -1,7 +1,7 @@
 def act_move_tab_into_new_mini_window(action, group, kz)
   page = kz.current_page
   if page and kz.activate_action("NewWindow")
-    new_kz = Kz::Window.list.last
+    new_kz = Kz::APP.window_list.last # FIXME
     new_kz.resize(500, 600)
     new_kz.move_tab(page)
   end
