@@ -485,9 +485,17 @@ rb_kz_embed_get_printer_list(VALUE self)
 }
 
 static VALUE
-rb_kz_embed_create_thumbnail(VALUE self)
+rb_kz_embed_create_thumbnail(int argc, VALUE *argv, VALUE self)
 {
-    kz_embed_create_thumbnail(_SELF(self));
+    EggPixbufThumbSize size;
+    VALUE rb_size;
+
+    rb_scan_args(argc, argv, "01", &rb_size);
+    if (NIL_P(rb_size))
+        size = EGG_PIXBUF_THUMB_LARGE;
+    else
+        size = NUM2INT(rb_size); /* FIXME */
+    kz_embed_create_thumbnail(_SELF(self), size);
     return self;
 }
 
@@ -723,7 +731,7 @@ _kz_rb_embed_init(VALUE mKz)
     rb_define_method(cKzEmbed, "get_printer_list",
                      rb_kz_embed_get_printer_list, 0);
     rb_define_method(cKzEmbed, "create_thumbnail",
-                     rb_kz_embed_create_thumbnail, 0);
+                     rb_kz_embed_create_thumbnail, -1);
     rb_define_method(cKzEmbed, "save_with_content",
                      rb_kz_embed_save_with_content, 1);
     rb_define_method(cKzEmbed, "zoom_set", rb_kz_embed_zoom_set, 2);
