@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: GtkNSSDialogs.cpp 2922 2007-03-20 13:37:55Z ikezoe $
+ *  $Id: GtkNSSDialogs.cpp 3494 2008-03-24 13:01:09Z pal_gene $
  */
 
 /*
@@ -38,9 +38,7 @@
 
 #include <nsCOMPtr.h>
 #include <nsMemory.h>
-#define MOZILLA_INTERNAL_API
-#include <nsIServiceManager.h>
-#undef MOZILLA_INTERNAL_API
+#include <nsServiceManagerUtils.h>
 #include <nsIInterfaceRequestor.h>
 #include <nsIInterfaceRequestorUtils.h>
 #include <nsIX509Cert.h>
@@ -1255,7 +1253,7 @@ GtkNSSDialogs::ViewCert(nsIInterfaceRequestor *ctx,
 		       nsIX509Cert *cert)
 {
 	GtkWidget *dialog, *widget, *vbox, *notebook, *label;
-	GtkWidget *main_vbox, *hbox;
+	GtkWidget *main_vbox;
 	GtkWidget *chain_tree_view, *field_tree_view, *text_view;
 	nsEmbedString value;
 	nsresult rv;
