@@ -19,18 +19,15 @@
  *   Christopher Blizzard <blizzard@mozilla.org>
  */
 
-#define MOZILLA_INTERNAL_API
-#include <nsIServiceManager.h>
+#include <nsServiceManagerUtils.h>
 #include <nsIComponentManager.h>
-#undef MOZILLA_INTERNAL_API
 
 #include <nsIDocShell.h>
 #include <nsIWebProgress.h>
 #include <nsIWebBrowserFocus.h>
 #include <nsCRT.h>
-#if 0
-#include <nsNetUtil.h>
-#include <nsIWebBrowserStream.h>
+#ifndef HAVE_NSIDOMEVENTRECEIVER_H
+#include <nsIDOMUIListener.h>
 #endif
 
 // for NS_APPSHELL_CID
@@ -65,9 +62,9 @@
 #include "EmbedContentListener.h"
 #include "EmbedEventListener.h"
 #include "EmbedWindowCreator.h"
-#include "EmbedStream.h"
 #include "GtkPromptService.h"
 #include "MozillaPrivate.h"
+#include "kz-mozutils.h"
 
 #ifdef MOZ_ACCESSIBILITY_ATK
 #include "nsIAccessibilityService.h"
@@ -83,9 +80,11 @@ gtk_getModuleInfo(nsStaticModuleInfo **info, PRUint32 *count);
 
 static NS_DEFINE_CID(kAppShellCID, NS_APPSHELL_CID);
 
+#ifdef MOZ_NSIAPPSHELL_HAVE_SPINUP_
+nsIAppShell *EmbedPrivate::sAppShell    = nsnull;
+#endif
 PRUint32     EmbedPrivate::sWidgetCount = 0;
 char        *EmbedPrivate::sCompPath    = nsnull;
-nsIAppShell *EmbedPrivate::sAppShell    = nsnull;
 GList       *EmbedPrivate::sWindowList  = NULL;
 char        *EmbedPrivate::sProfileDir  = nsnull;
 char        *EmbedPrivate::sProfileName = nsnull;
@@ -101,7 +100,6 @@ EmbedPrivate::EmbedPrivate(void)
   mProgress         = nsnull;
   mContentListener  = nsnull;
   mEventListener    = nsnull;
-  mStream	    = nsnull;
   mChromeMask       = nsIWebBrowserChrome::CHROME_ALL;
   mIsChrome         = PR_FALSE;
   mChromeLoaded     = PR_FALSE;
@@ -323,9 +321,8 @@ EmbedPrivate::Destroy(void)
 
   // detach our event listeners and release the event receiver
   DetachListeners();
-  if (mEventReceiver)
-    mEventReceiver = nsnull;
-  
+  if (mEventTarget)
+    mEventTarget = nsnull;
   // destroy our child window
   mWindow->ReleaseChildren();
 
@@ -450,7 +447,7 @@ EmbedPrivate::PushStartup(void)
     sMozillaEmbedPrivate = new MozillaEmbedPrivate;
     rv = sMozillaEmbedPrivate->StartupProfile(sProfileDir, sProfileName);
     NS_WARN_IF_FALSE(NS_SUCCEEDED(rv), "Warning: Failed to start up profiles.\n");
-
+#ifdef MOZ_NSIAPPSHELL_HAVE_SPINUP_
     // XXX startup appshell service?
     // XXX create offscreen window for appshell service?
     // XXX remove X prop from offscreen window?
@@ -465,6 +462,7 @@ EmbedPrivate::PushStartup(void)
     NS_ADDREF(sAppShell);
     sAppShell->Create(0, nsnull);
     sAppShell->Spinup();
+#endif
   }
 }
 
@@ -481,13 +479,14 @@ EmbedPrivate::PopStartup(void)
     // shut down the profiles
     sMozillaEmbedPrivate->ShutdownProfile();
 
+#ifdef MOZ_NSIAPPSHELL_HAVE_SPINUP_
     if (sAppShell) {
       // Shutdown the appshell service.
       sAppShell->Spindown();
       NS_RELEASE(sAppShell);
       sAppShell = 0;
     }
-
+#endif
     delete sMozillaEmbedPrivate;
     // shut down XPCOM/Embedding
     NS_TermEmbedding();
@@ -506,16 +505,6 @@ EmbedPrivate::SetCompPath(const char *aPath)
     sCompPath = nsnull;
 }
 
-/* static */
-#if 1
-void
-EmbedPrivate::SetAppComponents(const nsModuleComponentInfo* aComps,
-                               int aNumComponents)
-{
-  //sAppComps = aComps;
-  //sNumAppComps = aNumComponents;
-}
-#endif
 /* static */
 void
 EmbedPrivate::SetProfilePath(const char *aDir, const char *aName)
@@ -549,103 +538,6 @@ EmbedPrivate::SetDirectoryServiceProvider(nsIDirectoryServiceProvider * appFileL
   }
 }
 
-#if 1
-nsresult
-EmbedPrivate::OpenStream(const char *aBaseURI, const char *aContentType)
-{
-  nsresult rv;
-
-  if (!mStream) {
-    mStream = new EmbedStream();
-    mStreamGuard = do_QueryInterface(mStream);
-    mStream->InitOwner(this);
-    rv = mStream->Init();
-    if (NS_FAILED(rv))
-      return rv;
-  }
-
-  rv = mStream->OpenStream(aBaseURI, aContentType);
-  return rv;
-}
-
-nsresult
-EmbedPrivate::AppendToStream(const char *aData, PRInt32 aLen)
-{
-  if (!mStream)
-    return NS_ERROR_FAILURE;
-
-  // Attach listeners to this document since in some cases we don't
-  // get updates for content added this way.
-  ContentStateChange();
-
-  return mStream->AppendToStream(aData, aLen);
-}
-
-nsresult
-EmbedPrivate::CloseStream(void)
-{
-  nsresult rv;
-
-  if (!mStream)
-    return NS_ERROR_FAILURE;
-  rv = mStream->CloseStream();
-
-  // release
-  mStream = 0;
-  mStreamGuard = 0;
-
-  return rv;
-}
-#endif
-
-#if 0
-nsresult
-EmbedPrivate::OpenStream(const char *aBaseURI, const char *aContentType)
-{
-  nsCOMPtr<nsIWebBrowser> webBrowser;
-  mWindow->GetWebBrowser(getter_AddRefs(webBrowser));
-
-  nsCOMPtr<nsIWebBrowserStream> wbStream = do_QueryInterface(webBrowser);
-  if (!wbStream) return NS_ERROR_FAILURE;
-
-  nsCOMPtr<nsIURI> uri;
-  nsresult rv = NS_NewURI(getter_AddRefs(uri), aBaseURI);
-  if (NS_FAILED(rv))
-    return rv;
-
-  rv = wbStream->OpenStream(uri, nsDependentCString(aContentType));
-  return rv;
-}
-
-nsresult
-EmbedPrivate::AppendToStream(const PRUint8 *aData, PRUint32 aLen)
-{
-  // Attach listeners to this document since in some cases we don't
-  // get updates for content added this way.
-  ContentStateChange();
-
-  nsCOMPtr<nsIWebBrowser> webBrowser;
-  mWindow->GetWebBrowser(getter_AddRefs(webBrowser));
-
-  nsCOMPtr<nsIWebBrowserStream> wbStream = do_QueryInterface(webBrowser);
-  if (!wbStream) return NS_ERROR_FAILURE;
-
-  return wbStream->AppendToStream(aData, aLen);
-}
-
-nsresult
-EmbedPrivate::CloseStream(void)
-{
-  nsCOMPtr<nsIWebBrowser> webBrowser;
-  mWindow->GetWebBrowser(getter_AddRefs(webBrowser));
-
-  nsCOMPtr<nsIWebBrowserStream> wbStream = do_QueryInterface(webBrowser);
-  if (!wbStream) return NS_ERROR_FAILURE;
-
-  return wbStream->CloseStream();
-}
-#endif
-
 /* static */
 EmbedPrivate *
 EmbedPrivate::FindPrivateForBrowser(nsIWebBrowserChrome *aBrowser)
@@ -678,10 +570,8 @@ EmbedPrivate::ContentStateChange(void)
     return;
 
   GetListener();
-
-  if (!mEventReceiver)
+  if (!mEventTarget)
     return;
-  
   AttachListeners();
 
 }
@@ -757,14 +647,51 @@ EmbedPrivate::ChildFocusOut(void)
   webBrowserFocus->Deactivate();
 }
 
+nsresult
+EmbedPrivate::GetPIDOMWindow(nsPIDOMWindow **aPIWin)
+{
+  *aPIWin = nsnull;
+
+  // get the web browser
+  nsCOMPtr<nsIWebBrowser> webBrowser;
+  mWindow->GetWebBrowser(getter_AddRefs(webBrowser));
+
+  // get the content DOM window for that web browser
+  nsCOMPtr<nsIDOMWindow> domWindow;
+  webBrowser->GetContentDOMWindow(getter_AddRefs(domWindow));
+  if (!domWindow)
+    return NS_ERROR_FAILURE;
+
+  // get the private DOM window
+  nsCOMPtr<nsPIDOMWindow> domWindowPrivate = do_QueryInterface(domWindow);
+  // and the root window for that DOM window
+  *aPIWin = domWindowPrivate->GetPrivateRoot();
+
+  if (*aPIWin) {
+    NS_ADDREF(*aPIWin);
+    return NS_OK;
+  }
+
+  return NS_ERROR_FAILURE;
+
+}
+
 // Get the event listener for the chrome event handler.
 
 void
 EmbedPrivate::GetListener(void)
 {
-  if (mEventReceiver)
+  if (mEventTarget)
+    return;
+#ifndef HAVE_NSIDOMEVENTRECEIVER_H
+  nsCOMPtr<nsPIDOMWindow> piWin;
+  GetPIDOMWindow(getter_AddRefs(piWin));
+
+  if (!piWin)
     return;
 
+  mEventTarget = do_QueryInterface(piWin->GetChromeEventHandler());
+#else
   nsCOMPtr<nsIWebBrowser> webBrowser;
   mWindow->GetWebBrowser(getter_AddRefs(webBrowser));
 
@@ -774,7 +701,8 @@ EmbedPrivate::GetListener(void)
   if (!domWindow)
     return; 
 
-  MozillaPrivate::GetEventReceiver(domWindow, getter_AddRefs(mEventReceiver));
+  MozillaPrivate::GetEventReceiver(domWindow, getter_AddRefs(mEventTarget));
+#endif
 }
 
 // attach key and mouse event listeners
@@ -782,7 +710,7 @@ EmbedPrivate::GetListener(void)
 void
 EmbedPrivate::AttachListeners(void)
 {
-  if (!mEventReceiver || mListenersAttached)
+  if (!mEventTarget || mListenersAttached)
     return;
 
   nsIDOMEventListener *eventListener =
@@ -790,26 +718,35 @@ EmbedPrivate::AttachListeners(void)
 
   // add the key listener
   nsresult rv;
-  rv = mEventReceiver->AddEventListenerByIID(eventListener,
-					     NS_GET_IID(nsIDOMKeyListener));
+  rv = mEventTarget->AddEventListenerByIID(eventListener,
+					   NS_GET_IID(nsIDOMKeyListener));
   if (NS_FAILED(rv)) {
     NS_WARNING("Failed to add key listener\n");
     return;
   }
 
-  rv = mEventReceiver->AddEventListenerByIID(eventListener,
-					     NS_GET_IID(nsIDOMMouseListener));
+  rv = mEventTarget->AddEventListenerByIID(eventListener,
+					   NS_GET_IID(nsIDOMMouseListener));
   if (NS_FAILED(rv)) {
     NS_WARNING("Failed to add mouse listener\n");
     return;
   }
-  rv = mEventReceiver->AddEventListenerByIID(eventListener,
-					     NS_GET_IID(nsIDOMEventListener));
-#if 1
+
+#ifndef HAVE_NSIDOMEVENTRECEIVER_H
+  rv = mEventTarget->AddEventListenerByIID(eventListener,
+                                           NS_GET_IID(nsIDOMUIListener));
+  if (NS_FAILED(rv)) {
+    NS_WARNING("Failed to add UI listener\n");
+    return;
+  }
+#else
+  rv = mEventTarget->AddEventListenerByIID(eventListener,
+					   NS_GET_IID(nsIDOMEventListener));
+
   const PRUnichar domLiteral[] = { 'D', 'O', 'M', 'L', 'i', 'n', 'k',
 	  			   'A', 'd', 'd', 'e', 'd', '\0' };
-  mEventReceiver->AddEventListener(nsEmbedString(domLiteral),
-			   	   eventListener, PR_FALSE);
+  mEventTarget->AddEventListener(nsEmbedString(domLiteral),
+			  	 eventListener, PR_FALSE);
 #endif
 #if 0
   rv = mEventReceiver->AddEventListenerByIID(eventListener,
@@ -826,39 +763,40 @@ EmbedPrivate::AttachListeners(void)
 void
 EmbedPrivate::DetachListeners(void)
 {
-  if (!mListenersAttached || !mEventReceiver)
+  if (!mListenersAttached || !mEventTarget)
     return;
 
   nsIDOMEventListener *eventListener =
     static_cast<nsIDOMEventListener *>(static_cast<nsIDOMKeyListener *>(mEventListener));
 
   nsresult rv;
-  rv = mEventReceiver->RemoveEventListenerByIID(eventListener,
-						NS_GET_IID(nsIDOMKeyListener));
+  rv = mEventTarget->RemoveEventListenerByIID(eventListener,
+					      NS_GET_IID(nsIDOMKeyListener));
   if (NS_FAILED(rv)) {
     NS_WARNING("Failed to remove key listener\n");
     return;
   }
 
   rv =
-    mEventReceiver->RemoveEventListenerByIID(eventListener,
-					     NS_GET_IID(nsIDOMMouseListener));
+    mEventTarget->RemoveEventListenerByIID(eventListener,
+					   NS_GET_IID(nsIDOMMouseListener));
   if (NS_FAILED(rv)) {
     NS_WARNING("Failed to remove mouse listener\n");
     return;
   }
 
-  const PRUnichar domLiteral[] = { 'D', 'O', 'M', 'L', 'i', 'n', 'k',
-  				   'A', 'd', 'd', 'e', 'd', '\0' };
-  rv = mEventReceiver->RemoveEventListener(nsEmbedString(domLiteral),
-					     eventListener, PR_FALSE);
-#if 0
-  rv = mEventReceiver->RemoveEventListenerByIID(eventListener,
-						NS_GET_IID(nsIDOMUIListener));
+#ifndef HAVE_NSIDOMEVENTRECEIVER_H
+  rv = mEventTarget->RemoveEventListenerByIID(eventListener,
+					      NS_GET_IID(nsIDOMUIListener));
   if (NS_FAILED(rv)) {
     NS_WARNING("Failed to remove UI listener\n");
     return;
   }
+#else
+  const PRUnichar domLiteral[] = { 'D', 'O', 'M', 'L', 'i', 'n', 'k',
+  				   'A', 'd', 'd', 'e', 'd', '\0' };
+  rv = mEventTarget->RemoveEventListener(nsEmbedString(domLiteral),
+					 eventListener, PR_FALSE);
 #endif
   mListenersAttached = PR_FALSE;
 }
