@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: MozillaPrivate.h 3390 2008-02-22 15:36:56Z kous $
+ *  $Id: MozillaPrivate.h 3479 2008-03-12 01:57:57Z ikezoe $
  */
 
 /*
@@ -28,7 +28,6 @@
 
 #include <glib.h>
 #include <gtk/gtk.h>
-#define MOZILLA_INTERNAL_API
 #include <nsIPrintSettings.h>
 #include <nsIDOMWindow.h>
 #include <nsIDOMDocument.h>
@@ -36,17 +35,25 @@
 #include <nsISelection.h>
 #include <nsIDocShell.h>
 #include <nsIBaseWindow.h>
-#include <nsIDOMEventReceiver.h>
-#undef MOZILLA_INTERNAL_API
 #ifdef MOZ_NSICANVASRENDERINGCONTEXTINTERNAL_HAVE_GETINPUTSTREAM_
 #include "egg-pixbuf-thumbnail.h"
 #endif
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+#ifdef HAVE_NSIDOMEVENTRECEIVER_H
+#include <nsIDOMEventReceiver.h>
+#endif
 
 namespace MozillaPrivate
 {
+#ifdef HAVE_NSIPRINTOPTIONS_AVAILABLEPRINTERS
 	GList    *GetPrinterList      ();
+#endif
 	gboolean  CreatePrintSettings (nsIPrintSettings **options);
 	GdkWindow *GetGdkWindow       (nsIBaseWindow *window);
+#ifdef HAVE_NSIDOMEVENTRECEIVER_H
 	gboolean  GetEventReceiver    (nsIDOMWindow *domWindow, nsIDOMEventReceiver **receiver);
+#endif
 }
 #endif /* __MOZILLA_PRIVATE_H__ */
