@@ -22,7 +22,7 @@
 #define __KZ_GECKO_EMBED_H__
 
 #include <glib-object.h>
-#include "gtkmozembed.h"
+#include <gtkmozembed.h>
 
 G_BEGIN_DECLS
 
