@@ -27,9 +27,7 @@
 
 #include <glib.h>
 #include <glib/gi18n.h>
-#define MOZILLA_INTERNAL_API
-#include <nsIComponentManager.h>
-#undef MOZILLA_INTERNAL_API
+#include <nsComponentManagerUtils.h>
 #include <nsCOMPtr.h>
 #define MOZILLA_STRICT_API
 #include <nsEmbedString.h>
@@ -47,9 +45,6 @@ NS_IMPL_ISUPPORTS1(KzContentHandler, nsIHelperAppLauncherDialog)
 
 KzContentHandler::KzContentHandler() :
 	mUri(nsnull),
-#ifndef MOZ_NSIMIMEINFO_NSACSTRING_
-	mMimeType(nsnull),
-#endif
 	mDownloadCanceled(PR_FALSE)
 {
 	NS_INIT_ISUPPORTS();
@@ -57,19 +52,12 @@ KzContentHandler::KzContentHandler() :
 
 KzContentHandler::~KzContentHandler()
 {
-#ifndef MOZ_NSIMIMEINFO_NSACSTRING_
-	nsMemory::Free (mMimeType);
-#endif
 }
 
 
 NS_IMETHODIMP KzContentHandler::Show(nsIHelperAppLauncher *aLauncher,
 				     nsISupports *aContext,
-#ifdef MOZ_NSIHELPERAPPLAUNCHERDIALOG_NSPRBOOL_
-				     PRBool aForced)
-#else
 				     PRUint32 aForced)
-#endif
 {
 	nsresult rv;
 
@@ -119,18 +107,11 @@ NS_IMETHODIMP KzContentHandler::PromptForSaveToFile(
 	NS_CStringToUTF16(cTitle,
 			  NS_CSTRING_ENCODING_UTF8, title);
 
-#ifdef MOZ_NSIFILEPICKER_NSASTRING_
 	filePicker->Init(windowInternal,
 			 title, 
 			 nsIFilePicker::modeSave);
 	nsEmbedString defaultFile(aDefaultFile);
 	filePicker->SetDefaultString(defaultFile);
-#else
-	filePicker->Init(windowInternal,
-			 title.get(), 
-			 nsIFilePicker::modeSave);
-	filePicker->SetDefaultString(aDefaultFile);
-#endif
 	filePicker->SetDisplayDirectory(saveDir);
 
 	filePicker->Show(&okToSave);
@@ -159,11 +140,8 @@ NS_METHOD KzContentHandler::Init (void)
 
 	nsCOMPtr<nsIMIMEInfo> MIMEInfo;
 	rv = mLauncher->GetMIMEInfo(getter_AddRefs(MIMEInfo));
-#ifdef MOZ_NSIMIMEINFO_NSACSTRING_
+
 	rv = MIMEInfo->GetMIMEType(mMimeType);
-#else
-	rv = MIMEInfo->GetMIMEType(&mMimeType);
-#endif
 
 	rv = mLauncher->GetSource(getter_AddRefs(mUri));
 	rv = mLauncher->GetTargetFile(getter_AddRefs(mTempFile));
