@@ -37,9 +37,7 @@
 #include <gtkmozembed_internal.h>
 
 #include <stdlib.h>
-#define MOZILLA_INTERNAL_API
-#include <nsIServiceManager.h>
-#undef MOZILLA_INTERNAL_API
+#include <nsServiceManagerUtils.h>
 #include <nsIInterfaceRequestorUtils.h>
 #include <nsILocalFile.h>
 #include <nsIDocShell.h>
@@ -94,9 +92,6 @@
 #include <nsIDocCharset.h>
 
 
-#ifdef HAVE_NSIPRESCONTEXT_H
-#  include <nsIPresContext.h>
-#else
 typedef nsString              nsAFlatString;
 typedef nsCString             nsAFlatCString;
 #  define nsString_h___
@@ -104,7 +99,6 @@ typedef nsCString             nsAFlatCString;
 #  include <nsPresContext.h>
 #  undef nsAString_h___
 #  undef nsString_h___
-#endif
 
 #include "kz-mozprogresslistener.h"
 #include "kz-mozutils.h"
@@ -198,24 +192,11 @@ KzMozWrapper::Init (KzGeckoEmbed *kzembed)
 // Original copyright notice.
 // Copyright (C) 2000 Marco Pesenti Gritti
 
-#ifdef HAVE_NSIDOCSHELL_GETSECUREUI
 	nsCOMPtr<nsIDocShell> docShell (do_GetInterface (mWebBrowser, &rv));
 	NS_ENSURE_SUCCESS (rv, rv);
 
 	rv = docShell->GetSecurityUI (getter_AddRefs (mSecurityInfo));
 	NS_ENSURE_SUCCESS (rv, rv);
-#else
-	// Workaround for http://bugzilla.gnome.org/show_bug.cgi?id=164670
-	mSecurityInfo = do_CreateInstance("@kazehakase.sf.jp/hacks/secure-browser-ui;1");
-	if (mSecurityInfo)
-	{
-		mSecurityInfo->Init (mDOMWindow);
-	}
-	else
-	{
-		g_warning ("Failed to instantiate nsISecureBrowserUI!\n");
-	}
-#endif
 
 	return NS_OK;
 }
@@ -1287,18 +1268,11 @@ KzMozWrapper::GetCacheEntryDescriptor(const nsACString &aKey,
 	cacheSession->SetDoomEntriesIfExpired(PR_FALSE);
 		
 	nsCOMPtr<nsICacheEntryDescriptor> cacheEntryDescriptor;
-#ifdef MOZ_NSICACHESESSION_NSACSTRING_
+
 	rv = cacheSession->OpenCacheEntry(aKey,
 					  nsICache::ACCESS_READ,
 					  nsICache::NON_BLOCKING,
 					  aCacheEntryDescriptor);
-#else
-	nsEmbedCString cKey(aKey);
-	rv = cacheSession->OpenCacheEntry(cKey.get(),
-					  nsICache::ACCESS_READ,
-					  nsICache::NON_BLOCKING,
-					  aCacheEntryDescriptor);
-#endif
 
 	if (NS_FAILED(rv) || !aCacheEntryDescriptor)
 	{
@@ -1309,18 +1283,10 @@ KzMozWrapper::GetCacheEntryDescriptor(const nsACString &aKey,
 		if(NS_FAILED(rv) || !cacheSession) return NS_ERROR_FAILURE;
 
 		cacheSession->SetDoomEntriesIfExpired (PR_FALSE);
-#ifdef MOZ_NSICACHESESSION_NSACSTRING_
 		return cacheSession->OpenCacheEntry(aKey,
 					  nsICache::ACCESS_READ,
 					  nsICache::NON_BLOCKING,
 					  aCacheEntryDescriptor);
-#else
-		nsEmbedCString cKey(aKey);
-		return cacheSession->OpenCacheEntry(cKey.get(),
-					  nsICache::ACCESS_READ,
-					  nsICache::NON_BLOCKING,
-					  aCacheEntryDescriptor);
-#endif
 	}
 
 	return NS_OK;
@@ -2197,11 +2163,7 @@ KzMozWrapper::GetSelectedRange (nsIDOMDocument *domDoc,
 gboolean
 KzMozWrapper::SetZoomOnDocShell (float aZoom, nsIDocShell *DocShell)
 {
-#ifdef HAVE_NSIPRESCONTEXT_H
-	nsCOMPtr<nsIPresContext> PresContext;
-#else
 	nsCOMPtr<nsPresContext> PresContext;
-#endif
 	nsresult rv = DocShell->GetPresContext (getter_AddRefs(PresContext));
 	if (NS_FAILED(rv) || !PresContext) return FALSE;
 
