@@ -30,12 +30,8 @@
 #include <nsCOMPtr.h>
 #include <nsIPrefService.h>
 #include <nsISupportsPrimitives.h>
-#define MOZILLA_INTERNAL_API
-#include <nsIServiceManager.h>
-#undef MOZILLA_INTERNAL_API
-#if 1
+#include <nsServiceManagerUtils.h>
 #include <nsIFontEnumerator.h>
-#endif
 #include <nsISimpleEnumerator.h>
 #include <nsMemory.h>
 
@@ -114,7 +110,7 @@ static gchar *
 convert_to_mozpref_name (const gchar *prefix, const gchar *key)
 {
 	gint i = 0;
-	gchar *ret, *pos;
+	gchar *ret;
 
 	g_return_val_if_fail(g_str_has_prefix(key, prefix), NULL);
 
