@@ -27,6 +27,9 @@
 G_BEGIN_DECLS
 
 gboolean   mozilla_register_components (void);
+#ifdef XPCOM_GLUE
+gboolean   xulrunner_init (void);
+#endif
 
 G_END_DECLS
 
