@@ -23,11 +23,14 @@
 
 #include "kz-webkit-gtk.h"
 
+#include <webkit/webkit.h>
+
 #include "kz-embed.h"
 
 typedef struct _KzWebKitGtkPrivate	KzWebKitGtkPrivate;
 struct _KzWebKitGtkPrivate
 {
+	WebKitWebView *web_view;
 	gint progress;
 	gchar *location;
 	gchar *title;
@@ -38,7 +41,7 @@ struct _KzWebKitGtkPrivate
 #define KZ_WEBKIT_GTK_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), KZ_TYPE_WEBKIT_GTK, KzWebKitGtkPrivate))
 
 static GType           kz_type_webkit_gtk = 0;
-static WebKitWebViewClass *kz_webkit_gtk_parent_class;
+static GtkScrolledWindowClass *kz_webkit_gtk_parent_class;
 
 GtkWidget  *kz_webkit_gtk_new          (void);
 static void kz_webkit_gtk_class_init   (KzWebKitGtkClass *klass);
@@ -46,6 +49,12 @@ static void kz_webkit_gtk_iface_init   (KzEmbedIFace     *iface);
 static void kz_webkit_gtk_init         (KzWebKitGtk      *webkit_gtk);
 static void kz_webkit_gtk_dispose      (GObject          *object);
 
+#if 0
+static gboolean button_press_event     (GtkWidget      *widget,
+				        GdkEventButton *event);
+static gboolean button_release_event   (GtkWidget      *widget,
+				        GdkEventButton *event);
+#endif
 static void	    load_url               (KzEmbed      *kzembed,
 					    const gchar  *url);
 static void	    stop_load              (KzEmbed      *kzembed);
@@ -55,6 +64,13 @@ static void	    go_back                (KzEmbed      *kzembed);
 static void	    go_forward             (KzEmbed      *kzembed);
 static gboolean	    can_go_back            (KzEmbed      *kzembed);
 static gboolean	    can_go_forward         (KzEmbed      *kzembed);
+static gboolean     can_go_nav_link	   (KzEmbed      *kzembed,
+					    KzEmbedNavLink link);
+static KzNavi      *get_nth_nav_link	   (KzEmbed      *kzembed,
+					    KzEmbedNavLink link,
+					    guint         n);
+static GList       *get_nav_links	   (KzEmbed      *kzembed,
+					    KzEmbedNavLink link);
 static gboolean     can_cut_selection      (KzEmbed      *kzembed);
 static gboolean     can_copy_selection     (KzEmbed      *kzembed);
 static gboolean     can_paste              (KzEmbed      *kzembed);
@@ -69,6 +85,15 @@ static gchar       *get_link_message       (KzEmbed      *kzembed);
 static gchar	   *ensure_title           (KzEmbed      *kzembed);
 static gboolean     selection_is_collapsed (KzEmbed      *kzembed);
 static gboolean     is_loading             (KzEmbed      *kzembed);
+static gboolean     get_lock               (KzEmbed      *kzembed);
+static void         set_lock               (KzEmbed      *kzembed,
+					    gboolean      lock);
+static gboolean	    get_allow_javascript   (KzEmbed      *kzembed);
+static void	    set_allow_javascript   (KzEmbed      *kzembed,
+    					    gboolean      allow);
+static gboolean	    get_allow_images	   (KzEmbed      *kzembed);
+static void	    set_allow_images	   (KzEmbed      *kzembed,
+					    gboolean      allow);
 
 static void	cb_title_changed   (WebKitWebView* web_view,
 				    WebKitWebFrame* web_frame,
@@ -117,7 +142,7 @@ kz_webkit_gtk_register_type (GTypeModule *module)
 	};
 
 	kz_type_webkit_gtk = g_type_module_register_type(module,
-						 WEBKIT_TYPE_WEB_VIEW,
+						 GTK_TYPE_SCROLLED_WINDOW,
 						 "KzWebKitGtk",
 						 &kz_webkit_gtk_info,
 						 (GTypeFlags)0);
@@ -140,12 +165,15 @@ kz_webkit_gtk_class_init (KzWebKitGtkClass *klass)
 	GObjectClass *object_class;
 	GtkWidgetClass *widget_class;
 
-	kz_webkit_gtk_parent_class = WEBKIT_WEB_VIEW_CLASS(g_type_class_peek_parent(klass));
+	kz_webkit_gtk_parent_class = GTK_SCROLLED_WINDOW_CLASS(g_type_class_peek_parent(klass));
 	object_class = G_OBJECT_CLASS(klass);
 	widget_class = GTK_WIDGET_CLASS(klass);
 
 	object_class->dispose = kz_webkit_gtk_dispose;
-
+#if 0
+	widget_class->button_press_event = button_press_event;
+	widget_class->button_release_event = button_release_event;
+#endif
 	g_type_class_add_private(object_class, sizeof(KzWebKitGtkPrivate));
 }
 
@@ -183,23 +211,20 @@ kz_webkit_gtk_iface_init (KzEmbedIFace *iface)
 	iface->go_forward             = go_forward;
 	iface->can_go_back            = can_go_back;
 	iface->can_go_forward         = can_go_forward;
-	iface->can_go_nav_link        = NULL;
+	iface->can_go_nav_link        = can_go_nav_link;
 	iface->go_nav_link            = NULL;
 	iface->append_nav_link        = NULL;
 	iface->set_nav_link           = NULL;
 	iface->set_nth_nav_link       = NULL;
 	iface->get_nav_link           = NULL;
-	iface->get_nth_nav_link       = NULL;
-	iface->get_nav_links          = NULL;
+	iface->get_nth_nav_link       = get_nth_nav_link;
+	iface->get_nav_links          = get_nav_links;
 	iface->go_history_index       = NULL;
 	iface->do_command             = NULL;
 	iface->can_do_command         = NULL;
-	iface->get_lock               = NULL;
-	iface->set_lock               = NULL;
+	iface->get_lock               = get_lock;
+	iface->set_lock               = set_lock;
 	iface->get_body_text          = NULL;
-#if 0
-	iface->get_selection_source   = NULL;
-#endif
 	iface->set_encoding           = NULL;
 	iface->get_encoding           = NULL;
 	iface->print                  = NULL;
@@ -220,14 +245,10 @@ kz_webkit_gtk_iface_init (KzEmbedIFace *iface)
 	iface->fine_scroll            = NULL;
 	iface->page_up                = NULL;
 	iface->page_down              = NULL; 
-	iface->get_allow_javascript   = NULL;
-	iface->set_allow_javascript   = NULL; 
-	iface->get_allow_images       = NULL;
-	iface->set_allow_images       = NULL;
-#if 0
-	iface->set_edit_mode          = NULL;
-	iface->set_vwebkit_gtkw_mode          = NULL;
-#endif
+	iface->get_allow_javascript   = get_allow_javascript;
+	iface->set_allow_javascript   = set_allow_javascript; 
+	iface->get_allow_images       = get_allow_images;
+	iface->set_allow_images       = set_allow_images;
 
 	iface->link_message           = NULL;
 	iface->js_status              = NULL;
@@ -266,18 +287,21 @@ kz_webkit_gtk_init (KzWebKitGtk *webkit)
 	priv->lock = FALSE;
 	priv->is_loading = FALSE;
 
-	g_signal_connect(webkit, "title-changed",
-			 G_CALLBACK(cb_title_changed), NULL);
-	g_signal_connect(webkit, "load-progress-changed",
-			 G_CALLBACK(cb_progress_changed), NULL);
-	g_signal_connect(webkit, "load-committed",
-			 G_CALLBACK(cb_load_committed), NULL);
-	g_signal_connect(webkit, "load-started",
-			 G_CALLBACK(cb_load_started), NULL);
-	g_signal_connect(webkit, "load-finished",
-			 G_CALLBACK(cb_load_finished), NULL);
-	g_signal_connect(webkit, "hovering-over-link",
-			 G_CALLBACK(cb_hover_link), NULL);
+	priv->web_view = WEBKIT_WEB_VIEW(webkit_web_view_new());
+	gtk_container_add(GTK_CONTAINER(webkit), GTK_WIDGET(priv->web_view));
+
+	g_signal_connect(priv->web_view, "title-changed",
+			 G_CALLBACK(cb_title_changed), webkit);
+	g_signal_connect(priv->web_view, "load-progress-changed",
+			 G_CALLBACK(cb_progress_changed), webkit);
+	g_signal_connect(priv->web_view, "load-committed",
+			 G_CALLBACK(cb_load_committed), webkit);
+	g_signal_connect(priv->web_view, "load-started",
+			 G_CALLBACK(cb_load_started), webkit);
+	g_signal_connect(priv->web_view, "load-finished",
+			 G_CALLBACK(cb_load_finished), webkit);
+	g_signal_connect(priv->web_view, "hovering-over-link",
+			 G_CALLBACK(cb_hover_link), webkit);
 	set_default_preferences(webkit);
 }
 
@@ -303,15 +327,67 @@ GtkWidget *
 kz_webkit_gtk_new (void)
 {
 	return GTK_WIDGET(g_object_new(KZ_TYPE_WEBKIT_GTK,
+				       "hadjustment", NULL,
+				       "vadjustment", NULL,
+				       "hscrollbar-policy", GTK_POLICY_AUTOMATIC,
+				       "vscrollbar-policy", GTK_POLICY_AUTOMATIC,
 				       NULL));
 }
+#if 0
+static KzEmbedEventMouse *
+create_kz_embed_event_mouse (GdkEventButton *event)
+{
+	KzEmbedEventMouse *kzevent;
 
+	kzevent = (KzEmbedEventMouse *) kz_embed_event_new(KZ_EMBED_EVENT_MOUSE);
+	if (event->state & GDK_SHIFT_MASK)
+		kzevent->modifier |= KZ_SHIFT_KEY;
+	if (event->state & GDK_CONTROL_MASK)
+		kzevent->modifier |= KZ_CTRL_KEY;
+	if (event->state & GDK_MOD1_MASK)
+		kzevent->modifier |= KZ_ALT_KEY;
+	if (event->state & GDK_META_MASK)
+		kzevent->modifier |= KZ_META_KEY;
+	kzevent->x = event->x;
+	kzevent->y = event->y;
+	kzevent->button = event->button;
+	kzevent->cinfo.context = KZ_CONTEXT_NONE;
+
+	return kzevent;
+}
+
+static gboolean
+button_press_event (GtkWidget *widget, GdkEventButton *event)
+{
+	KzEmbedEventMouse *kzevent;
+	gint ret = FALSE;
+
+	kzevent = create_kz_embed_event_mouse(event);
+	g_signal_emit_by_name(widget, "kz-dom-mouse-down", kzevent, &ret);
+	kz_embed_event_free((KzEmbedEvent *) kzevent);
+
+	return ret;
+}
+
+static gboolean
+button_release_event (GtkWidget *widget, GdkEventButton *event)
+{
+	KzEmbedEventMouse *kzevent;
+	gint ret = FALSE;
+
+	kzevent = create_kz_embed_event_mouse(event);
+	g_signal_emit_by_name(widget, "kz-dom-mouse-up", kzevent, &ret);
+	kz_embed_event_free((KzEmbedEvent *) kzevent);
+
+	return ret;
+}
+#endif
 static void
 load_url (KzEmbed *kzembed, const gchar  *url)
 {
 	g_return_if_fail(KZ_IS_WEBKIT_GTK(kzembed));
 
-	webkit_web_view_open(WEBKIT_WEB_VIEW(kzembed), url);
+	webkit_web_view_open(KZ_WEBKIT_GTK_GET_PRIVATE(kzembed)->web_view, url);
 }
 
 static void
@@ -319,7 +395,7 @@ reload (KzEmbed *kzembed, KzEmbedReloadFlag flags)
 {
 	g_return_if_fail(KZ_IS_WEBKIT_GTK(kzembed));
 
-	webkit_web_view_reload(WEBKIT_WEB_VIEW(kzembed));
+	webkit_web_view_reload(KZ_WEBKIT_GTK_GET_PRIVATE(kzembed)->web_view);
 }
 
 static void
@@ -327,7 +403,7 @@ stop_load (KzEmbed *kzembed)
 {
 	g_return_if_fail(KZ_IS_WEBKIT_GTK(kzembed));
 
-	webkit_web_view_stop_loading(WEBKIT_WEB_VIEW(kzembed));
+	webkit_web_view_stop_loading(KZ_WEBKIT_GTK_GET_PRIVATE(kzembed)->web_view);
 }
 
 static void
@@ -335,7 +411,7 @@ go_back (KzEmbed *kzembed)
 {
 	g_return_if_fail(KZ_IS_WEBKIT_GTK(kzembed));
 
-	webkit_web_view_go_back(WEBKIT_WEB_VIEW(kzembed));
+	webkit_web_view_go_back(KZ_WEBKIT_GTK_GET_PRIVATE(kzembed)->web_view);
 }
 
 static void
@@ -343,7 +419,7 @@ go_forward (KzEmbed *kzembed)
 {
 	g_return_if_fail(KZ_IS_WEBKIT_GTK(kzembed));
 
-	webkit_web_view_go_forward(WEBKIT_WEB_VIEW(kzembed));
+	webkit_web_view_go_forward(KZ_WEBKIT_GTK_GET_PRIVATE(kzembed)->web_view);
 }
 
 static gboolean
@@ -351,7 +427,7 @@ can_go_back (KzEmbed *kzembed)
 {
 	g_return_val_if_fail(KZ_IS_WEBKIT_GTK(kzembed), FALSE);
 
-	return webkit_web_view_can_go_back(WEBKIT_WEB_VIEW(kzembed));
+	return webkit_web_view_can_go_back(KZ_WEBKIT_GTK_GET_PRIVATE(kzembed)->web_view);
 }
 
 static gboolean
@@ -359,7 +435,7 @@ can_go_forward (KzEmbed *kzembed)
 {
 	g_return_val_if_fail(KZ_IS_WEBKIT_GTK(kzembed), FALSE);
 
-	return webkit_web_view_can_go_forward(WEBKIT_WEB_VIEW(kzembed));
+	return webkit_web_view_can_go_forward(KZ_WEBKIT_GTK_GET_PRIVATE(kzembed)->web_view);
 }
 
 static gboolean
@@ -367,7 +443,7 @@ can_cut_selection (KzEmbed *kzembed)
 {
 	g_return_val_if_fail(KZ_IS_WEBKIT_GTK(kzembed), FALSE);
 
-	return webkit_web_view_can_cut_clipboard(WEBKIT_WEB_VIEW(kzembed));
+	return webkit_web_view_can_cut_clipboard(KZ_WEBKIT_GTK_GET_PRIVATE(kzembed)->web_view);
 }
 
 static gboolean
@@ -375,7 +451,7 @@ can_copy_selection (KzEmbed *kzembed)
 {
 	g_return_val_if_fail(KZ_IS_WEBKIT_GTK(kzembed), FALSE);
 
-	return webkit_web_view_can_copy_clipboard(WEBKIT_WEB_VIEW(kzembed));
+	return webkit_web_view_can_copy_clipboard(KZ_WEBKIT_GTK_GET_PRIVATE(kzembed)->web_view);
 }
 
 static gboolean
@@ -383,7 +459,7 @@ can_paste (KzEmbed *kzembed)
 {
 	g_return_val_if_fail(KZ_IS_WEBKIT_GTK(kzembed), FALSE);
 
-	return webkit_web_view_can_paste_clipboard(WEBKIT_WEB_VIEW(kzembed));
+	return webkit_web_view_can_paste_clipboard(KZ_WEBKIT_GTK_GET_PRIVATE(kzembed)->web_view);
 }
 
 static void
@@ -391,7 +467,7 @@ cut_selection (KzEmbed *kzembed)
 {
 	g_return_if_fail(KZ_IS_WEBKIT_GTK(kzembed));
 
-	webkit_web_view_cut_clipboard(WEBKIT_WEB_VIEW(kzembed));
+	webkit_web_view_cut_clipboard(KZ_WEBKIT_GTK_GET_PRIVATE(kzembed)->web_view);
 }
 
 static void
@@ -399,7 +475,7 @@ copy_selection (KzEmbed *kzembed)
 {
 	g_return_if_fail(KZ_IS_WEBKIT_GTK(kzembed));
 
-	webkit_web_view_copy_clipboard(WEBKIT_WEB_VIEW(kzembed));
+	webkit_web_view_copy_clipboard(KZ_WEBKIT_GTK_GET_PRIVATE(kzembed)->web_view);
 }
 
 static void
@@ -407,7 +483,7 @@ paste (KzEmbed *kzembed)
 {
 	g_return_if_fail(KZ_IS_WEBKIT_GTK(kzembed));
 
-	webkit_web_view_paste_clipboard(WEBKIT_WEB_VIEW(kzembed));
+	webkit_web_view_paste_clipboard(KZ_WEBKIT_GTK_GET_PRIVATE(kzembed)->web_view);
 }
 
 static void
@@ -415,7 +491,7 @@ select_all (KzEmbed *kzembed)
 {
 	g_return_if_fail(KZ_IS_WEBKIT_GTK(kzembed));
 
-	webkit_web_view_select_all(WEBKIT_WEB_VIEW(kzembed));
+	webkit_web_view_select_all(KZ_WEBKIT_GTK_GET_PRIVATE(kzembed)->web_view);
 }
 
 static const gchar *
@@ -467,7 +543,7 @@ get_progress (KzEmbed *kzembed)
 static gboolean
 selection_is_collapsed (KzEmbed *kzembed)
 {
-	return webkit_web_view_has_selection(WEBKIT_WEB_VIEW(kzembed));
+	return webkit_web_view_has_selection(KZ_WEBKIT_GTK_GET_PRIVATE(kzembed)->web_view);
 }
 
 static gboolean
@@ -476,18 +552,104 @@ is_loading (KzEmbed *kzembed)
 	return KZ_WEBKIT_GTK_GET_PRIVATE(kzembed)->is_loading;
 }
 
+static gboolean
+get_lock (KzEmbed *kzembed)
+{
+	return KZ_WEBKIT_GTK_GET_PRIVATE(kzembed)->lock;
+}
+
+
+static void
+set_lock (KzEmbed *kzembed, gboolean lock)
+{
+	KZ_WEBKIT_GTK_GET_PRIVATE(kzembed)->lock = lock;
+}
+
+static gboolean
+get_allow_javascript (KzEmbed *kzembed)
+{
+	WebKitWebSettings *settings;
+	gboolean allow;
+
+	settings = webkit_web_view_get_settings(KZ_WEBKIT_GTK_GET_PRIVATE(kzembed)->web_view);
+	if (!settings)
+		return FALSE;
+
+	g_object_get(settings, "enable-scripts", &allow, NULL);
+
+	return allow;
+}
+
+static void
+set_allow_javascript (KzEmbed *kzembed, gboolean allow)
+{
+	WebKitWebSettings *settings;
+
+	settings = webkit_web_view_get_settings(KZ_WEBKIT_GTK_GET_PRIVATE(kzembed)->web_view);
+	if (!settings)
+		return;
+
+	g_object_set(settings, "enable-scripts", allow, NULL);
+}
+
+static gboolean
+get_allow_images (KzEmbed *kzembed)
+{
+	WebKitWebSettings *settings;
+	gboolean allow;
+
+	settings = webkit_web_view_get_settings(KZ_WEBKIT_GTK_GET_PRIVATE(kzembed)->web_view);
+	if (!settings)
+		return FALSE;
+
+	g_object_get(settings, "auto-load-images", &allow, NULL);
+
+	return allow;
+}
+
+static void
+set_allow_images (KzEmbed *kzembed, gboolean allow)
+{
+	WebKitWebSettings *settings;
+
+	settings = webkit_web_view_get_settings(KZ_WEBKIT_GTK_GET_PRIVATE(kzembed)->web_view);
+	if (!settings)
+		return;
+
+	g_object_set(settings, "auto-load-images", allow, NULL);
+}
+
+static gboolean
+can_go_nav_link (KzEmbed *kzembed, KzEmbedNavLink link)
+{
+	return FALSE;
+}
+
+static KzNavi *
+get_nth_nav_link (KzEmbed *kzembed, KzEmbedNavLink link,
+		  guint n)
+{
+	return NULL;
+}
+
+static GList *
+get_nav_links (KzEmbed *kzembed, KzEmbedNavLink link)
+{
+	return NULL;
+}
+
 static void
 cb_title_changed (WebKitWebView* web_view,
 		  WebKitWebFrame* web_frame,
 		  const gchar* title,
 		  gpointer data)
 {
-	KzWebKitGtkPrivate *priv = KZ_WEBKIT_GTK_GET_PRIVATE(web_view);
+	KzWebKitGtkPrivate *priv = KZ_WEBKIT_GTK_GET_PRIVATE(data);
 	if (priv->title)
 		g_free(priv->title);
 	priv->title = g_strdup(title);
 
-	g_signal_emit_by_name(web_view, "kz-title");
+	g_signal_emit_by_name(data, "kz-title");
 }
 
 static void
@@ -495,10 +657,10 @@ cb_progress_changed (WebKitWebView* web_view,
 		     gint progress,
 		     gpointer data)
 {
-	KzWebKitGtkPrivate *priv = KZ_WEBKIT_GTK_GET_PRIVATE(web_view);
+	KzWebKitGtkPrivate *priv = KZ_WEBKIT_GTK_GET_PRIVATE(data);
 	priv->progress = progress;
 
-	g_signal_emit_by_name(web_view, "kz-progress");
+	g_signal_emit_by_name(data, "kz-progress");
 }
 
 static void
@@ -506,21 +668,21 @@ cb_load_committed (WebKitWebView* web_view,
 	           WebKitWebFrame* frame,
 		   gpointer data)
 {
-	KzWebKitGtkPrivate *priv = KZ_WEBKIT_GTK_GET_PRIVATE(web_view);
+	KzWebKitGtkPrivate *priv = KZ_WEBKIT_GTK_GET_PRIVATE(data);
 	const gchar* location = webkit_web_frame_get_uri(frame);
 	if (priv->location)
 		g_free(priv->location);
 	priv->location = g_strdup(location);
-	g_signal_emit_by_name(web_view, "kz-location");
+	g_signal_emit_by_name(data, "kz-location");
 }
 
 static void
 cb_load_started (WebKitWebView* web_view,
-	          WebKitWebFrame* frame,
-		  gpointer data)
+	         WebKitWebFrame* frame,
+		 gpointer data)
 {
-	KZ_WEBKIT_GTK_GET_PRIVATE(web_view)->is_loading = TRUE;
-	g_signal_emit_by_name(web_view, "kz-net-start");
+	KZ_WEBKIT_GTK_GET_PRIVATE(data)->is_loading = TRUE;
+	g_signal_emit_by_name(data, "kz-net-start");
 }
 
 static void
@@ -528,8 +690,8 @@ cb_load_finished (WebKitWebView* web_view,
 	          WebKitWebFrame* frame,
 		  gpointer data)
 {
-	KZ_WEBKIT_GTK_GET_PRIVATE(web_view)->is_loading = FALSE;
-	g_signal_emit_by_name(web_view, "kz-net-stop");
+	KZ_WEBKIT_GTK_GET_PRIVATE(data)->is_loading = FALSE;
+	g_signal_emit_by_name(data, "kz-net-stop");
 }
 
 static void
@@ -538,13 +700,13 @@ cb_hover_link (WebKitWebView* web_view,
 	       const gchar *location,
 	       gpointer data)
 {
-	KzWebKitGtkPrivate *priv = KZ_WEBKIT_GTK_GET_PRIVATE(web_view);
+	KzWebKitGtkPrivate *priv = KZ_WEBKIT_GTK_GET_PRIVATE(data);
 
 	if (priv->link_message)
 		g_free(priv->link_message);
 	priv->link_message = g_strdup(location);
 
-	g_signal_emit_by_name(web_view, "kz-link-message");
+	g_signal_emit_by_name(data, "kz-link-message");
 }
 
 static void
@@ -649,7 +811,7 @@ set_font_preferences (KzProfile *profile, WebKitWebSettings *settings)
 					&value, strlen(value)+1,
 					KZ_PROFILE_VALUE_TYPE_STRING);
 			g_object_set(settings,
-				     "monospace-serif-font-family", value,
+				     "monospace-font-family", value,
 				     NULL);
 		}
 	}
@@ -675,7 +837,7 @@ set_default_preferences (KzWebKitGtk *webkit)
 	gchar value[1024];
 
 	WebKitWebSettings *settings;
-	settings = webkit_web_view_get_settings(WEBKIT_WEB_VIEW(webkit));
+	settings = webkit_web_view_get_settings(KZ_WEBKIT_GTK_GET_PRIVATE(webkit)->web_view);
 	if (!settings)
 		return;
 
