@@ -19,16 +19,18 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
+/* NOTE:temporary fix for declaration strcasestr */
+#define _GNU_SOURCE
+#include <string.h>
+
 #include <ctype.h>
 #include <glib/gi18n.h>
-#include <glib.h>
 #include <glib/gstdio.h>
 #include <estraier.h>
 #include <estmtdb.h>
 
 #include "kazehakase.h"
 #include "utils/utils.h"
-#include "glib-utils.h"
 #include "kz-search.h"
 #include "kz-search-common.h"
 #include "kz-module-impl.h"
@@ -227,7 +229,6 @@ ensure_open_db (KzHyperEstraierSearch *search)
 		open_db(search);
 }
 
-
 static void
 kz_hyper_estraier_search_init (KzHyperEstraierSearch *search)
 {
@@ -266,9 +267,9 @@ create_search_result_html (KzSearch *search, const gchar *text)
 	ESTCOND *cond;
 	CBLIST *highlights;
 	int *results, n_results, i;
-	gchar *except_word, *tmp;
+	gchar *except_word, *tmp, *utf8;
 	gchar **texts;
-	GString *html, *phrase, *desc_str;
+	GString *html, *phrase, *attr_uri_phrase, *desc_str;
 	gint num_summary = 128, max_results = 20, half_of_summary;
 	KzHyperEstraierSearch *he_search;
 
@@ -279,47 +280,93 @@ create_search_result_html (KzSearch *search, const gchar *text)
 	g_return_val_if_fail(he_search->db, NULL);
 
 	cond = est_cond_new();
-	texts = g_strsplit(text, " ", -1);
-
 	highlights = cblistopen();
-	for (i = 0; texts[i]; i++)
-	{
-		cblistpush(highlights, texts[i], -1);
-	}
-	tmp = g_strjoinv(" " ESTOPISECT " ", texts);
-	g_strfreev(texts);
-	phrase = g_string_new(tmp);
-	g_free(tmp);
-
+	
+	/* convert from kz_conf except keyword */
+	phrase = g_string_new(text);
 	except_word = KZ_CONF_GET_STR("History", "except_keyword");
 	if (except_word && *except_word)
 	{
 		texts = g_strsplit(except_word, ",", -1);
 		g_free(except_word);
-		i = 0;
-		while (texts[i])
-		{
-			phrase = g_string_append(phrase, " " ESTOPDIFF " ");
-			phrase = g_string_append(phrase, texts[i]);
-			i++;
-		}
+		tmp = g_strjoinv(" -", texts);
 		g_strfreev(texts);
+		g_string_append(phrase, " -");
+		g_string_append(phrase, tmp);
+		g_free(tmp);
+	}
+	tmp = g_utf8_normalize(phrase->str,-1, G_NORMALIZE_ALL_COMPOSE);
+	g_string_free(phrase, TRUE);
+	utf8 = g_utf8_strdown(tmp, -1);
+	g_free(tmp);
+	
+	/* start word split */
+	texts = g_strsplit(utf8, " ", -1);
+	g_free(utf8);
+	phrase = g_string_sized_new(0);
+
+	for (i = 0; texts[i]; i++)
+	{
+		tmp = texts[i];
+		guint flag = 0;
+		gint cond_i;
+		if(!tmp || !*tmp || g_unichar_isspace(*tmp)) continue;
+		/* extract supported condition [ALL KZ_HISTORY_SEARCH CODE] */
+		for(cond_i = 0; cond_i < KZ_SEARCH_FLAG_SIZE; cond_i++)
+		{
+			if(g_str_has_prefix(tmp, KZ_SEARCH_FLAGS[cond_i].exp))
+			{
+				flag |= KZ_SEARCH_FLAGS[cond_i].mask;
+				tmp += strlen(KZ_SEARCH_FLAGS[cond_i].exp);
+			}
+		}
+		/* write out for search engine expression [ENGINE SPECIFIC CODE] */
+		switch(flag & KZ_SEARCH_FLAG_GROUP_OPTION) {
+		case KZ_SEARCH_FLAG_MASK_SITE:
+			attr_uri_phrase = g_string_sized_new(0);
+			g_string_printf(attr_uri_phrase,
+					"%s %s %s",
+					ESTDATTRURI,
+					(flag & KZ_SEARCH_FLAG_MASK_NOT)?"!ISTRINC":"ISTRINC",
+					tmp);
+			est_cond_add_attr(cond, attr_uri_phrase->str);
+			g_string_free(attr_uri_phrase, TRUE);
+			break;
+		default:
+			if(flag & KZ_SEARCH_FLAG_MASK_NOT)
+			{
+				g_string_append(phrase, " " ESTOPDIFF " ");
+			}
+			else
+			{
+				g_string_append(phrase, " " ESTOPISECT " ");
+				cblistpush(highlights, tmp, -1);
+			}
+			g_string_append(phrase, tmp);
+		}
+	}
+	g_strfreev(texts);
+
+	if(strlen(phrase->str) > 0) { 
+		est_cond_set_phrase(cond, phrase->str);
 	}
-	est_cond_set_phrase(cond, phrase->str);
 	g_string_free(phrase, TRUE);
 
+	/* start actual search */
 	KZ_CONF_GET("History", "num_summary", num_summary, INT);
 	KZ_CONF_GET("History", "max_results", max_results, INT);
 	half_of_summary = num_summary / 2;
 
 	results = est_mtdb_search(he_search->db, cond, &n_results, NULL);
 
-	desc_str = g_string_sized_new(num_summary*2 - 1);		/* almost typical in num_summary*2 */
-	html = g_string_sized_new((num_summary*2+512)*max_results);	/* typical in num_summary*2*max_results */
+	/* almost in typical num_summary*2 */
+	desc_str = g_string_sized_new(num_summary*2 - 1);
+	/* in typical (num_summary*2+html_tags)*max_results */
+	html = g_string_sized_new((num_summary*2+512)*max_results);
 
 	g_string_append(html, DTD"\n");
 	g_string_append(html, "<html>\n");
-	g_string_append(html, HEAD);
+	g_string_append_printf(html, HEAD, text);
 	g_string_append(html, "<body>\n");
 
 	g_string_append_printf(html, "<h1>Search results for %s</h1>\n", text);
@@ -329,8 +376,7 @@ create_search_result_html (KzSearch *search, const gchar *text)
 		ESTDOC *doc;
 		const gchar *title, *date, *cache_link;
 		gchar *cache_str, *thumb_filename, *uri, *thumb_uri;
-		gchar *desc, **desc_highlight;
-		guint desc_len, desc_i;
+		gchar *desc, *p, *l;
 
 		doc = est_mtdb_get_doc(he_search->db, results[i], 0);
 		if (!doc)
@@ -348,7 +394,7 @@ create_search_result_html (KzSearch *search, const gchar *text)
 		else
 		{
 			cache_str = g_strdup("");
-		}		
+		}
 		uri = create_uri_from_filename(cache_link +
 					       strlen("file://") +
 					       he_search->cache_path_len +
@@ -368,24 +414,44 @@ create_search_result_html (KzSearch *search, const gchar *text)
 		desc = est_doc_make_snippet(doc, highlights, num_summary,
 					    half_of_summary, half_of_summary);
 		/* make highlight keyword */
-		//TODO:more fast that don't split
-		desc_highlight = g_strsplit_set(desc, "\n", 0);
-		free(desc);		/* don't g_free because born from estraier func */
-		desc_len = g_strv_length(desc_highlight);
 		desc_str->len = 0;	/* reset contain length */
-		for(desc_i = 0; desc_i < desc_len; desc_i++) {
-		    char *found = strchr(desc_highlight[desc_i], '\t');
-		    if (found) {
-			*found = '\0';
-			g_string_append(desc_str, "<b>");
-			g_string_append(desc_str, desc_highlight[desc_i]);
-			g_string_append(desc_str, "</b>");
-		    } else {
-			g_string_append(desc_str, desc_highlight[desc_i]);
-		    }
+		l = p = desc;
+		while (*p)
+		{
+			if (*p == '\n')
+			{
+				g_string_append_len(desc_str, l, p - l);
+				l = ++p;
+				continue;
+			}
+
+			if (*p == '\t')
+			{
+				g_string_append(desc_str, "<b>");
+				g_string_append_len(desc_str, l, p - l);
+				g_string_append(desc_str, "</b>");
+				while (*p)
+				{
+					if (*p == '\n')
+					{
+						l = ++p;
+						break;
+					}
+					p++;
+				}
+				if (*p == '\0')
+				{
+					l = NULL;
+					break;
+				}
+				continue;
+			}
+			p++;
 		}
-		g_strfreev(desc_highlight);
-		
+		if (p != l && l)
+			g_string_append_len(desc_str, l, p - l);
+		free(desc);		/* don't g_free because born from estraier func */
+
 		g_string_append_printf(html,
 				       CONTENT,
 				       uri,
@@ -412,7 +478,6 @@ create_search_result_html (KzSearch *search, const gchar *text)
 	return g_string_free(html, FALSE);
 }
 
-
 gchar *
 get_search_result_html (KzSearch *search, const gchar *text)
 {
@@ -432,7 +497,7 @@ get_document_encoding (const gchar *contents)
 	p = (gchar*)contents;
 	while ((p = strstr(p, "<meta ")))
 	{
-		gchar *end;
+		gchar *end, *quote_end;
 		p = strstr(p, "http-equiv=\"");
 		if (!p) break;
 
@@ -449,8 +514,8 @@ get_document_encoding (const gchar *contents)
 		if (!p) break;
 		p+=8;
 		end = strchr(p, ';');
-		if (!end)
-			end = strchr(p, '"');
+		quote_end = strchr(p, '"');
+		if(quote_end && quote_end < end) end = quote_end;
 		if (!end) break;
 
 		encoding = g_strndup(p, end - p);
@@ -462,7 +527,7 @@ get_document_encoding (const gchar *contents)
 
 
 /* Type and functions that used in gMmarkupParser */
-/* drop at the tiem 
+#if 0 /* drop at the tiem */
 typedef struct {
 	gint in_title;
 	gchar *title;
@@ -499,17 +564,18 @@ static void title_text(GMarkupParseContext *context, const gchar *text,
 		((title_parsing *) user_data)->in_title = 0;
 	}
 }
-drop at the time */
+#endif
 /**
  * create page title from html content string
- * currentlly called from only register_documents_in_path.
- * @parm contents utf-8 strings that contain html contents
+ * currentlly called from only register_documents_in_path().
+ * @param contents utf-8 strings that contain html contents
  * @return gchar* new allocated, should be g_free or NULL for failed parsing
  */
 static gchar *
 get_document_title(const gchar *contents)
 {
-	/* didn't work yet.
+#if 0
+	/* didn't work yet. */
 	GMarkupParser title_parser_funcs = {
 		title_start_element, title_end_element,
 		title_text, NULL, NULL
@@ -529,13 +595,13 @@ get_document_title(const gchar *contents)
 	g_markup_parse_context_free(title_parser);
 	printf("get title:%s\n", data.title);
 	return data.title;
-	
-	*/ 
+#endif 
 	/* simple parser */
 	//FIXME: parse correctly
 	gchar *start;
 	start = strcasestr(contents, "<title>");
-	if(start == NULL) {
+	if (start == NULL)
+	{
 	    //printf("not in title.\n");
 	    return NULL;
 	}
@@ -543,6 +609,51 @@ get_document_title(const gchar *contents)
 	return g_strndup(start, strstr(start, "<") - start);
 }
 
+/**
+ * get utf-8 contents string for given html file
+ * @param filepath file name to get document contents.
+ * @return gchar* newly allocated utf-8 string, or NULL failed.
+ */
+static gchar *
+get_utf8_contents(const char *filepath)
+{ 
+	gchar *contents = NULL;
+
+	if (g_file_get_contents(filepath, &contents, NULL, NULL))
+	{
+		gchar *encoding = get_document_encoding(contents);
+		if (!encoding)
+			encoding = g_strdup(est_enc_name(contents,
+							 strlen(contents),
+							 ESTLANGJA));
+
+		if (g_ascii_strcasecmp(encoding, "UTF-8") != 0)
+		{
+			gchar *utf8_contents, *upper_encoding;
+			upper_encoding = g_ascii_strup(encoding, -1);
+			utf8_contents = g_convert(contents, -1,
+						  "UTF-8", upper_encoding,
+						  NULL, NULL,
+						  NULL);
+			g_free(upper_encoding);
+			g_free(contents);
+			if (utf8_contents)
+			{
+				contents = utf8_contents;
+			}
+			else
+			{
+				g_warning("failed convert encoding. [enc:file] [%s:%s]\n",
+					  encoding, filepath);
+				contents = NULL;
+			}
+		}
+		g_free(encoding);
+	}
+
+	return contents;
+}
+
 gboolean
 register_document (KzSearch *search, const gchar *uri, const gchar *title, const gchar *contents, GTime mtime)
 {
@@ -585,16 +696,20 @@ register_document (KzSearch *search, const gchar *uri, const gchar *title, const
 	}
 
 	success = est_mtdb_put_doc(he_search->db, doc, ESTPDCLEAN) != 0;
-	if (!success) {
+	if (!success)
+	{
 		g_warning("register error: %s", est_err_msg(est_mtdb_error(he_search->db)));
 		g_warning("retry...");
 		est_mtdb_sync(he_search->db);
-		if(est_mtdb_put_doc(he_search->db, doc, 0)) {
+		if((success = est_mtdb_put_doc(he_search->db, doc, 0)))
+		{
 		    g_warning("succeed!");
-		} else {
+		}
+		else
+		{
 		    g_warning("register error: %s", est_err_msg(est_mtdb_error(he_search->db)));
 		    g_warning("drop %s,%s\n", ESTDATTRURI, est_doc_attr(doc, ESTDATTRURI));
-		} 
+		}
 	}
 
 	est_doc_delete(doc);
@@ -650,12 +765,11 @@ get_search_result_bookmark (KzSearch *search, const gchar *text)
 
 /**
  * register all documents in given path
- * @parm search this search class
- * @parm path path to the directory contains contents to register
+ * @param search this search class
+ * @param path path to the directory contains contents to register
  * @return void
  */
-//TODO:don't register image type
-//TODO:correct parse title (get_document_title())
+//TODO:correctly parse title (get_document_title())
 static void
 register_documents_in_path (KzSearch *search, const gchar *path)
 {
@@ -678,62 +792,33 @@ register_documents_in_path (KzSearch *search, const gchar *path)
 		else
 		{
 			gchar *uri, *title, *contents;
-			gchar *encoding = NULL;
 			GTime mtime;
 			struct stat st;
 
-			g_file_get_contents(new_path, &contents, NULL, NULL);
+			/* filter for time-stamp */
+			//TODO:history search result, optional
+			/* NOTE:string pointer compare is designed */
+			if (path == he_search->cache_path && strcmp(file, "time-stamp") == 0)
+				goto  END_NEW_PATH;
+
+			contents = get_utf8_contents(new_path);
+			if (!contents)
+				goto END_NEW_PATH;
+
 			g_stat(new_path, &st);
 			mtime = st.st_mtime;
+			title = get_document_title(contents);
 			uri = create_uri_from_filename(new_path +
 						       he_search->cache_path_len +
 						       1);
-			encoding = get_document_encoding(contents);
-			if (!encoding)
-				encoding = g_strdup(est_enc_name(contents,
-								 strlen(contents),
-								 ESTLANGJA));
+			register_document(search, uri, title, contents, mtime);
 
-			if (encoding && strcmp(encoding, "UTF-8"))
-			{
-				gchar *utf8_contents;
-				utf8_contents = g_convert(contents, -1,
-							  "UTF-8", encoding,
-							  NULL, NULL,
-							  NULL);
-
-				if (utf8_contents)
-				{
-					title = get_document_title(utf8_contents);
-					if(!title) {
-						// printf("fail title in %s\n", uri);
-						title = g_strdup(uri);
-					}
-					register_document(search,
-								    uri,
-								    title,
-								    utf8_contents,
-								    mtime);
-					g_free(utf8_contents);
-					g_free(title);
-				}
-			}
-			else {
-				title = get_document_title(contents);
-				if(!title) {
-					// printf("fail title in %s\n", uri);
-					title = g_strdup(uri);
-				}
-				register_document(search, uri, title,
-							    contents, mtime);
+			if (title)
 				g_free(title);
-			}
- 			if (encoding)
-				g_free(encoding);
 			g_free(uri);
-
 			g_free(contents);
 		}
+		END_NEW_PATH:
 		g_free(new_path);
 	}
 	g_dir_close (gd);
