@@ -34,9 +34,6 @@
 
 G_BEGIN_DECLS
 
-extern GtkActionEntry      kz_actions_popup[];
-extern const gint          kz_actions_popup_len;
-
 GtkActionGroup *kz_actions_popup_create_group (KzWindow      *kz);
 
 void            kz_actions_popup_menu_modal   (KzWindow      *kz,
