@@ -2059,7 +2059,7 @@ kz_actions_set_selection_sensitive (KzWindow *kz, KzEmbed *kzembed)
 
 	focus = gtk_window_get_focus(GTK_WINDOW(kz));
 
-#warning FIXME! /* should track all GtkEditable's event and Embed's selection */
+#warning FIXME! should track all GtkEditable's event and Embed's selection
 	if (kzembed && !kz_embed_selection_is_collapsed(kzembed))
 	{
 		KZ_WINDOW_SET_SENSITIVE(kz, "OpenSelectedLinks", TRUE);
