@@ -17,7 +17,19 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-bookmark-action.c,v 1.1 2003/11/11 23:44:28 makeinu Exp $
+ *  $Id: kz-bookmark-action.c 3189 2007-04-14 15:13:41Z kous $
  */
 
 #include "kz-bookmark-action.h"
+
+G_DEFINE_TYPE(KzBookmarkAction, kz_bookmark_action, GTK_TYPE_ACTION)
+
+static void
+kz_bookmark_action_class_init (KzBookmarkActionClass *klass)
+{
+}
+
+static void
+kz_bookmark_action_init (KzBookmarkAction *action)
+{
+}
