@@ -20,23 +20,28 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
+#ifdef HAVE_CONFIG_H
+# include <config.h>
+#endif /* HAVE_CONFIG_H */
+
 #include "kz-location-entry-action.h"
 
 #include <stdlib.h>
 #include <gdk/gdkkeysyms.h>
 #include <sys/types.h>
 #include <sys/stat.h>
-#include <unistd.h>
 #include <glib/gi18n.h>
 #include <glib/gstdio.h>
+#ifdef HAVE_UNISTD_H
+#  include <unistd.h>
+#endif
 
 #include "kazehakase.h"
 #include "utils/utils.h"
-#include "gobject-utils.h"
+#include "utils/glib-utils.h"
 #include "kz-bookmark.h"
 #include "kz-smart-bookmark.h"
 #include "kz-actions.h"
-#include "eggregex.h"
 
 #define KZ_LOCATION_ENTRY_ACTION_KEY "KzLocationEntryAction::Action"
 
@@ -46,23 +51,21 @@ enum {
 	PROP_KZ_BOOKMARK
 };
 
-static void kz_location_entry_action_class_init       (KzLocationEntryActionClass *class);
-static void kz_location_entry_action_init             (KzLocationEntryAction      *action);
-static void kz_location_entry_action_dispose          (GObject *obj);
-static void kz_location_entry_action_set_property     (GObject           *object,
-						       guint              prop_id,
-						       const GValue      *value,
-						       GParamSpec        *pspec);
-static void kz_location_entry_action_get_property     (GObject           *object,
-						       guint              prop_id,
-						       GValue            *value,
-						       GParamSpec        *pspec);
+static void dispose          (GObject *obj);
+static void set_property     (GObject           *object,
+                              guint              prop_id,
+                              const GValue      *value,
+                              GParamSpec        *pspec);
+static void get_property     (GObject           *object,
+                              guint              prop_id,
+                              GValue            *value,
+                              GParamSpec        *pspec);
 
-static void kz_location_entry_action_activate         (GtkAction         *action);
-static void kz_location_entry_action_connect_proxy    (GtkAction         *action,
-						       GtkWidget         *proxy);
-static void kz_location_entry_action_disconnect_proxy (GtkAction         *action,
-						       GtkWidget         *proxy);
+static void activate         (GtkAction         *action);
+static void connect_proxy    (GtkAction         *action,
+                              GtkWidget         *proxy);
+static void disconnect_proxy (GtkAction         *action,
+                              GtkWidget         *proxy);
 
 static void     kz_location_entry_action_history_changed (KzHistoryAction *action);
 static void     kz_location_entry_action_sync_history    (KzLocationEntryAction *action);
@@ -82,16 +85,7 @@ static void     cb_profile_global_changed     (KzProfile       *profile,
 					       const gchar     *key,
 					       const gchar     *old_value,
 					       GtkEntry        *entry);
-static KzHistoryActionClass *parent_class = NULL;
-
-
-KZ_OBJECT_GET_TYPE(kz_location_entry_action,
-		   "KzLocationEntryAction",
-		   KzLocationEntryAction,
-		   kz_location_entry_action_class_init,
-		   kz_location_entry_action_init,
-		   KZ_TYPE_HISTORY_ACTION)
-
+G_DEFINE_TYPE(KzLocationEntryAction, kz_location_entry_action, KZ_TYPE_HISTORY_ACTION)
 
 static void
 kz_location_entry_action_class_init (KzLocationEntryActionClass *klass)
@@ -100,18 +94,17 @@ kz_location_entry_action_class_init (KzLocationEntryActionClass *klass)
 	GtkActionClass *action_class;
 	KzHistoryActionClass *history_class;
 
-	parent_class  = g_type_class_peek_parent(klass);
 	object_class  = G_OBJECT_CLASS(klass);
 	action_class  = GTK_ACTION_CLASS(klass);
 	history_class = KZ_HISTORY_ACTION_CLASS(klass);
 
-	object_class->set_property     = kz_location_entry_action_set_property;
-	object_class->get_property     = kz_location_entry_action_get_property;
-	object_class->dispose          = kz_location_entry_action_dispose;
+	object_class->set_property     = set_property;
+	object_class->get_property     = get_property;
+	object_class->dispose          = dispose;
 
-	action_class->activate         = kz_location_entry_action_activate;
-	action_class->connect_proxy    = kz_location_entry_action_connect_proxy;
-	action_class->disconnect_proxy = kz_location_entry_action_disconnect_proxy;
+	action_class->activate         = activate;
+	action_class->connect_proxy    = connect_proxy;
+	action_class->disconnect_proxy = disconnect_proxy;
 
 	history_class->history_changed = kz_location_entry_action_history_changed;
 
@@ -147,15 +140,15 @@ kz_location_entry_action_init (KzLocationEntryAction *action)
 
 
 static void
-kz_location_entry_action_dispose (GObject *obj)
+dispose (GObject *obj)
 {
 	KzLocationEntryAction *action = KZ_LOCATION_ENTRY_ACTION(obj);
 
 	if (action->kz)
 	{
-		kz_profile_set_save_each_time(kz_global_profile, FALSE);
+		kz_profile_set_save_each_time(KZ_GET_GLOBAL_PROFILE, FALSE);
 		kz_location_entry_action_store_history(action);
-		kz_profile_set_save_each_time(kz_global_profile, TRUE);
+		kz_profile_set_save_each_time(KZ_GET_GLOBAL_PROFILE, TRUE);
 		g_object_unref(action->kz);
 		action->kz = NULL;
 	}
@@ -168,16 +161,16 @@ kz_location_entry_action_dispose (GObject *obj)
 		action->bookmark = NULL;
 	}
 
-	if (G_OBJECT_CLASS(parent_class)->dispose)
-		G_OBJECT_CLASS(parent_class)->dispose(obj);
+	if (G_OBJECT_CLASS(kz_location_entry_action_parent_class)->dispose)
+		G_OBJECT_CLASS(kz_location_entry_action_parent_class)->dispose(obj);
 }
 
 
 static void
-kz_location_entry_action_set_property (GObject         *object,
-				       guint            prop_id,
-				       const GValue    *value,
-				       GParamSpec      *pspec)
+set_property (GObject         *object,
+              guint            prop_id,
+              const GValue    *value,
+              GParamSpec      *pspec)
 {
 	KzLocationEntryAction *action = KZ_LOCATION_ENTRY_ACTION(object);
   
@@ -199,10 +192,10 @@ kz_location_entry_action_set_property (GObject         *object,
 
 
 static void
-kz_location_entry_action_get_property (GObject         *object,
-				       guint            prop_id,
-				       GValue          *value,
-				       GParamSpec      *pspec)
+get_property (GObject         *object,
+              guint            prop_id,
+              GValue          *value,
+              GParamSpec      *pspec)
 {
 	KzLocationEntryAction *action = KZ_LOCATION_ENTRY_ACTION(object);
 
@@ -222,7 +215,7 @@ kz_location_entry_action_get_property (GObject         *object,
 
 
 static void
-kz_location_entry_action_activate (GtkAction *action)
+activate (GtkAction *action)
 {
 	KzLocationEntryAction *entry_action;
 	const gchar *uri;
@@ -238,8 +231,8 @@ kz_location_entry_action_activate (GtkAction *action)
 	kz_location_entry_action_reset_history(entry_action);
 	
 	entry_action->activating = TRUE;
-	if (GTK_ACTION_CLASS(parent_class)->activate)
-		GTK_ACTION_CLASS(parent_class)->activate(action);
+	if (GTK_ACTION_CLASS(kz_location_entry_action_parent_class)->activate)
+		GTK_ACTION_CLASS(kz_location_entry_action_parent_class)->activate(action);
 	entry_action->activating = FALSE;
 
 
@@ -261,11 +254,11 @@ kz_location_entry_action_activate (GtkAction *action)
 
 
 static void
-kz_location_entry_action_connect_proxy (GtkAction *action, GtkWidget *proxy)
+connect_proxy (GtkAction *action, GtkWidget *proxy)
 {
 	GtkEntry *entry;
 
-	GTK_ACTION_CLASS (parent_class)->connect_proxy (action, proxy);
+	GTK_ACTION_CLASS (kz_location_entry_action_parent_class)->connect_proxy (action, proxy);
 
 	entry = kz_entry_action_get_entry_widget(KZ_ENTRY_ACTION(action), proxy);
 	if (entry)
@@ -284,14 +277,14 @@ kz_location_entry_action_connect_proxy (GtkAction *action, GtkWidget *proxy)
 				 G_CALLBACK(cb_entry_key_press), action);
 		g_signal_connect(entry, "populate-popup",
 				 G_CALLBACK(cb_entry_populate_popup), action);
-		g_signal_connect(kz_global_profile, "changed::Global",
+		g_signal_connect(KZ_GET_GLOBAL_PROFILE, "changed::Global",
 				 G_CALLBACK(cb_profile_global_changed), entry);
 	}
 }
 
 
 static void
-kz_location_entry_action_disconnect_proxy (GtkAction *action, GtkWidget *proxy)
+disconnect_proxy (GtkAction *action, GtkWidget *proxy)
 {
 	GtkEntry *entry;
 
@@ -311,7 +304,7 @@ kz_location_entry_action_disconnect_proxy (GtkAction *action, GtkWidget *proxy)
 			 G_CALLBACK(cb_entry_populate_popup),
 			 action);
 		g_signal_handlers_disconnect_by_func
-			(kz_global_profile,
+			(KZ_GET_GLOBAL_PROFILE,
 			 G_CALLBACK(cb_profile_global_changed),
 			 entry);
 	        g_object_set_data(G_OBJECT(entry),
@@ -319,7 +312,7 @@ kz_location_entry_action_disconnect_proxy (GtkAction *action, GtkWidget *proxy)
 			          NULL);
 	}
 
-	GTK_ACTION_CLASS (parent_class)->disconnect_proxy (action, proxy);
+	GTK_ACTION_CLASS (kz_location_entry_action_parent_class)->disconnect_proxy (action, proxy);
 }
 
 
@@ -330,8 +323,8 @@ kz_location_entry_action_history_changed (KzHistoryAction *action)
 
 	kz_location_entry_action_sync_history(KZ_LOCATION_ENTRY_ACTION(action));
 
-	if (KZ_HISTORY_ACTION_CLASS(parent_class)->history_changed)
-		KZ_HISTORY_ACTION_CLASS(parent_class)->history_changed(action);
+	if (KZ_HISTORY_ACTION_CLASS(kz_location_entry_action_parent_class)->history_changed)
+		KZ_HISTORY_ACTION_CLASS(kz_location_entry_action_parent_class)->history_changed(action);
 }
 
 
@@ -347,9 +340,9 @@ kz_location_entry_action_new (KzWindow *kz)
 			      "stock_id",    GTK_STOCK_NEW,
 			      "kz-window",   kz,
 			      NULL);
-	kz_profile_set_save_each_time(kz_global_profile, FALSE);
+	kz_profile_set_save_each_time(KZ_GET_GLOBAL_PROFILE, FALSE);
 	kz_location_entry_action_restore_history(action);
-	kz_profile_set_save_each_time(kz_global_profile, TRUE);
+	kz_profile_set_save_each_time(KZ_GET_GLOBAL_PROFILE, TRUE);
 
 	return action;
 }
@@ -360,16 +353,18 @@ kz_location_entry_action_store_history (KzLocationEntryAction *action)
 {
 	GList *list, *node;
 	gint i = 0;
+	KzProfile *profile;
 
 	g_return_if_fail(KZ_IS_LOCATION_ENTRY_ACTION(action));
-
-	list = kz_profile_enum_key(kz_global_profile, "LocationEntry", TRUE);
+ 
+ 	profile = KZ_GET_GLOBAL_PROFILE;
+	list = kz_profile_enum_key(profile, "LocationEntry", TRUE);
 	for (node = list; node; node = g_list_next(node))
 	{
 		const gchar *key = node->data;
 
 		if (key && *key && key_seems_sequential(key, "history"))
-			kz_profile_delete_key(kz_global_profile,
+			kz_profile_delete_key(profile,
 					      "LocationEntry", key);
 	}
 	g_list_free(list);
@@ -407,7 +402,7 @@ kz_location_entry_action_restore_history (KzLocationEntryAction *action)
 
 	text = g_strdup(kz_entry_action_get_text(KZ_ENTRY_ACTION(action)));
 
-	list = kz_profile_enum_key(kz_global_profile, "LocationEntry", TRUE);
+	list = kz_profile_enum_key(KZ_GET_GLOBAL_PROFILE, "LocationEntry", TRUE);
 	for (node = list; node; node = g_list_next(node))
 	{
 		const gchar *key = node->data;
@@ -456,7 +451,7 @@ kz_location_entry_action_sync_history (KzLocationEntryAction *action)
 	kz_location_entry_action_store_history
 		(KZ_LOCATION_ENTRY_ACTION(action));
 
-	list = kz_window_get_window_list();
+	list = KZ_GET_WINDOW_LIST;
 	for (node = list; node; node = g_list_next(node))
 	{
 		KzWindow *tmpkz = node->data;
@@ -501,16 +496,17 @@ static void
 get_file_path_from_uri(const gchar *uri, gchar **path, gchar **prefix)
 {
 	GError *error = NULL;
-	EggRegex *regex;
+	GRegex *regex;
+	GMatchInfo *match_info;
 
 	*path = NULL;
 	*prefix = NULL;
 
 	g_return_if_fail(uri);
 	
-	regex = egg_regex_new("^\\s*(file://|)(/.*)\\s*",
-			      EGG_REGEX_CASELESS | EGG_REGEX_EXTENDED,
-			      0, &error);
+	regex = g_regex_new("^\\s*(file://|)(/.*)\\s*",
+			    G_REGEX_CASELESS | G_REGEX_EXTENDED,
+			    0, &error);
 
 	if (error)
 	{
@@ -519,13 +515,14 @@ get_file_path_from_uri(const gchar *uri, gchar **path, gchar **prefix)
 		return;
 	}
 	
-	if (egg_regex_match(regex, uri, -1, 0) > 0)
+	if (g_regex_match(regex, uri, 0, &match_info))
 	{
-		*prefix = egg_regex_fetch(regex, uri, 1);
-		*path = egg_regex_fetch(regex, uri, 2);
+		*prefix = g_match_info_fetch(match_info, 1);
+		*path = g_match_info_fetch(match_info, 2);
 	}
-	
-	egg_regex_free(regex);
+
+	g_match_info_free(match_info);
+	g_regex_unref(regex);
 }
 
 static gboolean
