@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-actions-bookmark.c,v 1.34 2005/02/18 18:02:09 tyuyu Exp $
+ *  $Id: kz-actions-bookmark.c 2855 2007-03-14 03:26:31Z ikezoe $
  */
 
 #include "kz-actions-bookmark.h"
@@ -29,9 +29,6 @@
 #include "kz-bookmark-file.h"
 #include "utils.h"
 
-static GtkActionEntry kz_actions_bookmark[];
-static const gint     kz_actions_bookmark_len;
-
 
 static void
 act_new_window (GtkAction *action, KzBookmarkEditor *editor)
@@ -213,28 +210,27 @@ insert_other_browsers_bookmark(KzBookmarkEditor *editor, OTHER_BROWSERS_BOOKMARK
 	gchar *dir = NULL;
 	g_return_if_fail(KZ_IS_BOOKMARK_EDITOR(editor));
 
-	dir = g_build_filename (g_get_home_dir (),
-				other_browsers_bookmark_map[type].search_dir,
-				NULL);
+	dir = g_build_filename(g_get_home_dir(),
+			       other_browsers_bookmark_map[type].search_dir,
+			       NULL);
 	if(dir)
 	{
 		GSList *list, *node;
 
-		list = find_file  (dir,
-				   other_browsers_bookmark_map[type].search_name,
-				   other_browsers_bookmark_map[type].search_depth);
+		list = find_file(dir,
+				 other_browsers_bookmark_map[type].search_name,
+				 other_browsers_bookmark_map[type].search_depth);
 		for (node = list; node; node = g_slist_next(node))
 		{
-			if (g_file_test (node->data, G_FILE_TEST_IS_REGULAR))
+			if (g_file_test(node->data, G_FILE_TEST_IS_REGULAR))
 			{
 				KzBookmark *bookmark =
-					KZ_BOOKMARK(kz_bookmark_file_new (node->data,
-									  other_browsers_bookmark_map[type].description,
-									  NULL));
+					KZ_BOOKMARK(kz_bookmark_file_new(node->data,
+									 other_browsers_bookmark_map[type].description,
+									 NULL));
 				insert_bookmark_item(editor, bookmark);
 				g_object_unref(G_OBJECT(bookmark));
 
-#warning FIXME! Is this really needed?
 				kz_bookmark_file_load_start(KZ_BOOKMARK_FILE(bookmark));
 			}
 		}
@@ -352,10 +348,9 @@ act_show_hide_folder_view (GtkToggleAction *action, KzBookmarkEditor *editor)
 	g_return_if_fail(KZ_IS_BOOKMARK_EDITOR(editor));
 	g_return_if_fail(GTK_IS_WIDGET(editor->scrolledwin[0]));
 
-	if (gtk_toggle_action_get_active (action))
-		gtk_widget_show(editor->scrolledwin[0]);
-	else
-		gtk_widget_hide(editor->scrolledwin[0]);
+	g_object_set(editor->scrolledwin[0],
+		     "visible", gtk_toggle_action_get_active(action),
+		     NULL);
 }
 
 
@@ -366,10 +361,9 @@ act_show_hide_content_view (GtkToggleAction *action, KzBookmarkEditor *editor)
 	g_return_if_fail(KZ_IS_BOOKMARK_EDITOR(editor));
 	g_return_if_fail(GTK_IS_WIDGET(editor->content_view));
 
-	if (gtk_toggle_action_get_active (action))
-		gtk_widget_show(editor->content_view);
-	else
-		gtk_widget_hide(editor->content_view);
+	g_object_set(editor->content_view,
+		     "visible", gtk_toggle_action_get_active(action),
+		     NULL);
 }
 
 
