@@ -23,23 +23,14 @@
 #include "kz-bookmark-edit-win.h"
 
 #include <glib/gi18n.h>
-#include "gobject-utils.h"
 #include "kz-icons.h"
 #include "kz-bookmark-edit.h"
 
-static void kz_bookmark_edit_win_class_init (KzBookmarkEditWinClass *klass);
-static void kz_bookmark_edit_win_init       (KzBookmarkEditWin      *win);
-static void kz_bookmark_edit_win_dispose    (GObject                *object);
-static void kz_bookmark_edit_win_response   (GtkDialog              *dialog,
-					     gint                    arg);
-
-static GtkDialogClass *parent_class = NULL;
-
-
-KZ_OBJECT_GET_TYPE(kz_bookmark_edit_win, "KzBookmarkEditWin", KzBookmarkEditWin,
-		   kz_bookmark_edit_win_class_init, kz_bookmark_edit_win_init,
-		   GTK_TYPE_DIALOG)
+static void dispose    (GObject   *object);
+static void response   (GtkDialog *dialog,
+                        gint       arg);
 
+G_DEFINE_TYPE(KzBookmarkEditWin, kz_bookmark_edit_win, GTK_TYPE_DIALOG)
 
 static void
 kz_bookmark_edit_win_class_init (KzBookmarkEditWinClass *klass)
@@ -47,13 +38,12 @@ kz_bookmark_edit_win_class_init (KzBookmarkEditWinClass *klass)
 	GObjectClass *object_class;
 	GtkDialogClass *dialog_class;
 
-	parent_class = g_type_class_peek_parent(klass);
 	object_class = (GObjectClass *) klass;
 	dialog_class = (GtkDialogClass *) klass;
 
-	object_class->dispose  = kz_bookmark_edit_win_dispose;
+	object_class->dispose  = dispose;
 
-	dialog_class->response = kz_bookmark_edit_win_response;
+	dialog_class->response = response;
 }
 
 
@@ -81,19 +71,19 @@ kz_bookmark_edit_win_init (KzBookmarkEditWin *win)
 
 
 static void
-kz_bookmark_edit_win_dispose (GObject *object)
+dispose (GObject *object)
 {
 	KzBookmarkEditWin *win = KZ_BOOKMARK_EDIT_WIN(object);
 
 	win->bookmark_edit = NULL;
 
-	if (G_OBJECT_CLASS(parent_class)->dispose)
-		G_OBJECT_CLASS(parent_class)->dispose(object);
+	if (G_OBJECT_CLASS(kz_bookmark_edit_win_parent_class)->dispose)
+		G_OBJECT_CLASS(kz_bookmark_edit_win_parent_class)->dispose(object);
 }
 
 
 static void
-kz_bookmark_edit_win_response (GtkDialog *dialog, gint arg)
+response (GtkDialog *dialog, gint arg)
 {
 	switch (arg)
 	{
