@@ -18,13 +18,12 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-bookmark-edit.c,v 1.35 2005/04/28 13:40:55 ikezoe Exp $
+ *  $Id: kz-bookmark-edit.c 2637 2006-12-02 07:30:49Z ikezoe $
  */
 
 #include <glib/gi18n.h>
 #include "kz-bookmark-edit.h"
 #include "kz-smart-bookmark.h"
-#include "gobject-utils.h"
 #include "gtk-utils.h"
 #include "kz-thumbnail.h"
 #include "kz-bookmark-file.h"
@@ -51,12 +50,8 @@ struct _KzSmartBookmarkEdit
 	GtkListStore *store;
 };
 
-static GtkVBoxClass *parent_class = NULL;
 
-
-static void kz_bookmark_edit_class_init (KzBookmarkEditClass *klass);
-static void kz_bookmark_edit_init       (KzBookmarkEdit *edit);
-static void kz_bookmark_edit_dispose    (GObject        *object);
+static void dispose    (GObject        *object);
 
 static void kz_bookmark_edit_set_sensitive   (KzBookmarkEdit *edit);
 static void kz_bookmark_edit_sync_properties (KzBookmarkEdit *edit,
@@ -86,24 +81,16 @@ static void cb_xmlrpc_pass_entry_changed (GtkEditable    *editable,
 
 static GtkWidget *create_widget_for_smart_property (KzBookmarkEdit *edit);
 
-KZ_OBJECT_GET_TYPE(kz_bookmark_edit, "KzBookmarkEdit", KzBookmarkEdit,
-		   kz_bookmark_edit_class_init, kz_bookmark_edit_init,
-		   GTK_TYPE_VBOX)
+G_DEFINE_TYPE(KzBookmarkEdit, kz_bookmark_edit, GTK_TYPE_VBOX)
 
 static void
 kz_bookmark_edit_class_init (KzBookmarkEditClass *klass)
 {
 	GObjectClass *gobject_class;
-	GtkObjectClass *object_class;
-	GtkWidgetClass *widget_class;
-
-	parent_class = g_type_class_peek_parent (klass);
 
 	gobject_class = (GObjectClass *)   klass;
-	object_class  = (GtkObjectClass *) klass;
-	widget_class  = (GtkWidgetClass *) klass;
 
-	gobject_class->dispose = kz_bookmark_edit_dispose;
+	gobject_class->dispose = dispose;
 }
 
 
@@ -340,7 +327,7 @@ kz_bookmark_edit_init (KzBookmarkEdit *edit)
 
 
 static void
-kz_bookmark_edit_dispose (GObject *object)
+dispose (GObject *object)
 {
 	KzBookmarkEdit *edit = KZ_BOOKMARK_EDIT(object);
 
@@ -365,8 +352,8 @@ kz_bookmark_edit_dispose (GObject *object)
 		g_free(edit->smart);
 		edit->smart = NULL;
 	}
-	if (G_OBJECT_CLASS (parent_class)->dispose)
-		G_OBJECT_CLASS (parent_class)->dispose(object);
+	if (G_OBJECT_CLASS (kz_bookmark_edit_parent_class)->dispose)
+		G_OBJECT_CLASS (kz_bookmark_edit_parent_class)->dispose(object);
 }
 
 
