@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-bookmark-editor.c,v 1.42 2006/06/02 02:23:41 ikezoe Exp $
+ *  $Id: kz-bookmark-editor.c 3081 2007-03-28 03:53:51Z kous $
  */
 
 #include "kz-bookmark-editor.h"
@@ -26,7 +26,6 @@
 #include <glib/gi18n.h>
 
 #include "kazehakase.h"
-#include "gobject-utils.h"
 #include "kz-window.h"
 #include "kz-bookmark-edit.h"
 #include "kz-actions-bookmark.h"
@@ -42,21 +41,19 @@ enum {
 
 
 /* object class */
-static void     kz_bookmark_editor_class_init   (KzBookmarkEditorClass *klass);
-static void     kz_bookmark_editor_init         (KzBookmarkEditor *editor);
-static void     kz_bookmark_editor_dispose      (GObject          *object);
-static void     kz_bookmark_editor_set_property (GObject          *object,
-						 guint             prop_id,
-						 const GValue     *value,
-						 GParamSpec       *pspec);
-static void     kz_bookmark_editor_get_property (GObject          *object,
-						 guint             prop_id,
-						 GValue           *value,
-						 GParamSpec       *pspec);
+static void     dispose      (GObject          *object);
+static void     set_property (GObject          *object,
+                              guint             prop_id,
+                              const GValue     *value,
+                              GParamSpec       *pspec);
+static void     get_property (GObject          *object,
+                              guint             prop_id,
+                              GValue           *value,
+                              GParamSpec       *pspec);
 
 /* widget event */
-static gboolean kz_bookmark_editor_delete_event (GtkWidget        *widget,
-						 GdkEventAny      *event);
+static gboolean delete_event (GtkWidget        *widget,
+                              GdkEventAny      *event);
 
 /* private methods */
 static void     kz_bookmark_editor_set_folder_tree   (KzBookmarkEditor *editor);
@@ -77,13 +74,7 @@ static gboolean cb_bookmarks_view_button_press  (GtkWidget        *widget,
 						 GdkEventButton   *button,
 						 KzBookmarkEditor *editor);
 
-static GtkWindowClass *parent_class = NULL;
-
-
-KZ_OBJECT_GET_TYPE(kz_bookmark_editor, "KzBookmarkEditor", KzBookmarkEditor,
-		   kz_bookmark_editor_class_init, kz_bookmark_editor_init,
-		   GTK_TYPE_WINDOW)
-
+G_DEFINE_TYPE(KzBookmarkEditor, kz_bookmark_editor, GTK_TYPE_WINDOW)
 
 static void
 kz_bookmark_editor_class_init (KzBookmarkEditorClass *klass)
@@ -91,17 +82,15 @@ kz_bookmark_editor_class_init (KzBookmarkEditorClass *klass)
 	GObjectClass *gobject_class;
 	GtkWidgetClass *widget_class;
 
-	parent_class = g_type_class_peek_parent (klass);
-
 	gobject_class = (GObjectClass *)   klass;
 	widget_class  = (GtkWidgetClass *) klass;
 
-	gobject_class->dispose      = kz_bookmark_editor_dispose;
-	gobject_class->set_property = kz_bookmark_editor_set_property;
-	gobject_class->get_property = kz_bookmark_editor_get_property;
+	gobject_class->dispose      = dispose;
+	gobject_class->set_property = set_property;
+	gobject_class->get_property = get_property;
 
 	/* GtkWidget signals */
-	widget_class->delete_event = kz_bookmark_editor_delete_event;
+	widget_class->delete_event = delete_event;
 
 	g_object_class_install_property
 		(gobject_class,
@@ -134,6 +123,7 @@ kz_bookmark_editor_init (KzBookmarkEditor *editor)
 	GtkAccelGroup *accel_group;
 	GtkUIManager   *menu_merge;
 	GError *err = NULL;
+	gchar *ui_file_name;
 
 	g_object_set(G_OBJECT(editor), "allow-shrink", TRUE, NULL);
 
@@ -156,9 +146,10 @@ kz_bookmark_editor_init (KzBookmarkEditor *editor)
 	gtk_ui_manager_insert_action_group(menu_merge, actions, 0);
 	g_signal_connect(menu_merge, "add_widget",
 			 G_CALLBACK(cb_menu_merge_add_widget), main_vbox);
-	gtk_ui_manager_add_ui_from_file(menu_merge,
-					KZ_SYSCONFDIR"/kz-ui-bookmarks.xml",
-					&err);
+	ui_file_name = g_build_filename(KZ_GET_SYSTEM_CONFIG_DIR,
+					"kz-ui-bookmarks.xml", NULL);
+	gtk_ui_manager_add_ui_from_file(menu_merge, ui_file_name, &err);
+	g_free(ui_file_name);
 	if (err)
 	{
 		g_warning("%s", err->message);
@@ -261,7 +252,7 @@ kz_bookmark_editor_init (KzBookmarkEditor *editor)
 
 
 static void
-kz_bookmark_editor_dispose (GObject *object)
+dispose (GObject *object)
 {
 	KzBookmarkEditor *editor = KZ_BOOKMARK_EDITOR(object);
 
@@ -279,16 +270,16 @@ kz_bookmark_editor_dispose (GObject *object)
 		g_object_unref(editor->action_group);
 	editor->action_group = NULL;
 
-	if (G_OBJECT_CLASS (parent_class)->dispose)
-		G_OBJECT_CLASS (parent_class)->dispose(object);
+	if (G_OBJECT_CLASS (kz_bookmark_editor_parent_class)->dispose)
+		G_OBJECT_CLASS (kz_bookmark_editor_parent_class)->dispose(object);
 }
 
 
 static void
-kz_bookmark_editor_set_property (GObject         *object,
-				 guint            prop_id,
-				 const GValue    *value,
-				 GParamSpec      *pspec)
+set_property (GObject         *object,
+              guint            prop_id,
+              const GValue    *value,
+              GParamSpec      *pspec)
 {
 	KzBookmarkEditor *editor = KZ_BOOKMARK_EDITOR(object);
   
@@ -312,10 +303,10 @@ kz_bookmark_editor_set_property (GObject         *object,
 
 
 static void
-kz_bookmark_editor_get_property (GObject         *object,
-				 guint            prop_id,
-				 GValue          *value,
-				 GParamSpec      *pspec)
+get_property (GObject         *object,
+              guint            prop_id,
+              GValue          *value,
+              GParamSpec      *pspec)
 {
 	KzBookmarkEditor *editor = KZ_BOOKMARK_EDITOR(object);
 
@@ -332,7 +323,7 @@ kz_bookmark_editor_get_property (GObject         *object,
 
 
 static gboolean
-kz_bookmark_editor_delete_event (GtkWidget *widget, GdkEventAny *event)
+delete_event (GtkWidget *widget, GdkEventAny *event)
 {
 	KzBookmarkEditor *editor;
 
@@ -734,7 +725,7 @@ cb_bookmarks_view_button_press (GtkWidget *widget, GdkEventButton *event,
 	kz = gtk_window_get_transient_for(GTK_WINDOW(editor));
 	if (!KZ_IS_WINDOW(kz))
 	{
-		const GList *list = kz_window_get_window_list();
+		const GList *list = KZ_GET_WINDOW_LIST;
 		if (list)
 			kz = list->data;
 		else
