@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-bookmark-file.c,v 1.19 2005/07/20 04:50:48 ikezoe Exp $
+ *  $Id: kz-bookmark-file.c 3198 2007-04-15 12:42:36Z kous $
  */
 
 #include "kz-bookmark-file.h"
@@ -26,10 +26,8 @@
 #include <string.h>
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
-#include "gobject-utils.h"
 #include "glib-utils.h"
 #include "utils.h"
-#include "eggregex.h"
 
 #include "kz-io.h"
 #include "kz-xmlrpc.h"
@@ -48,6 +46,7 @@ enum {
 	SAVE_START_SIGNAL,
 	SAVE_COMPLETED_SIGNAL,
 	ERROR_SIGNAL,
+	UPDATE_SIGNAL,
 	LAST_SIGNAL
 };
 
@@ -72,17 +71,15 @@ enum {
 		file_types = g_list_append(file_types, type);		\
 }
 
-static void kz_bookmark_file_class_init   (KzBookmarkFileClass *klass);
-static void kz_bookmark_file_init         (KzBookmarkFile      *bookmark_file);
-static void kz_bookmark_file_dispose      (GObject             *object);
-static void kz_bookmark_file_set_property (GObject             *object,
-				           guint                prop_id,
-				           const GValue        *value,
-				           GParamSpec          *pspec);
-static void kz_bookmark_file_get_property (GObject             *object,
-				           guint                prop_id,
-				           GValue              *value,
-				           GParamSpec          *pspec);
+static void dispose      (GObject             *object);
+static void set_property (GObject             *object,
+	                  guint                prop_id,
+	                  const GValue        *value,
+	                  GParamSpec          *pspec);
+static void get_property (GObject             *object,
+                          guint                prop_id,
+                          GValue              *value,
+                          GParamSpec          *pspec);
 
 static void kz_bookmark_file_set_state    (KzBookmarkFile      *bookmark_file,
 					   KzBookmarkFileState  state);
@@ -100,7 +97,6 @@ static KzBookmarkFileType *
             kz_bookmark_file_detect_file_type  (KzBookmarkFile *bookmark_file,
 					        gchar          *buf);
 
-static KzBookmarkClass *parent_class = NULL;
 static gint kz_bookmark_file_signals[LAST_SIGNAL] = {0};
 
 static GList *file_types = NULL;
@@ -117,10 +113,7 @@ static GQuark io_quark                = 0;
 static GQuark io_signal_id_quark      = 0;
 static GQuark p_last_modified_quark   = 0;
 
-
-KZ_OBJECT_GET_TYPE(kz_bookmark_file, "KzBookmarkFile", KzBookmarkFile,
-		   kz_bookmark_file_class_init, kz_bookmark_file_init,
-		   KZ_TYPE_BOOKMARK)
+G_DEFINE_TYPE(KzBookmarkFile, kz_bookmark_file, KZ_TYPE_BOOKMARK)
 
 static void
 kz_bookmark_file_class_init (KzBookmarkFileClass *klass)
@@ -137,17 +130,17 @@ kz_bookmark_file_class_init (KzBookmarkFileClass *klass)
 		ADD_BOOKMARK_FILE_TYPE(kz_hinadi_get_file_types);
 	}
 
-	parent_class = g_type_class_peek_parent (klass);
 	object_class = (GObjectClass *) klass;
 
-	object_class->dispose      = kz_bookmark_file_dispose;
-	object_class->set_property = kz_bookmark_file_set_property;
-	object_class->get_property = kz_bookmark_file_get_property;
+	object_class->dispose      = dispose;
+	object_class->set_property = set_property;
+	object_class->get_property = get_property;
 
 	klass->load_start         = NULL;
 	klass->load_completed     = NULL;
 	klass->save_start         = NULL;
 	klass->save_completed     = NULL;
+	klass->update		  = NULL;
 
 	g_object_class_install_property(
 		object_class,
@@ -281,6 +274,16 @@ kz_bookmark_file_class_init (KzBookmarkFileClass *klass)
 			       g_cclosure_marshal_VOID__STRING,
 			       G_TYPE_NONE, 1, G_TYPE_STRING);
 
+	kz_bookmark_file_signals[UPDATE_SIGNAL]
+		= g_signal_new("update",
+			       G_TYPE_FROM_CLASS (klass),
+			       G_SIGNAL_RUN_LAST,
+			       G_STRUCT_OFFSET (KzBookmarkFileClass,
+						update),
+			       NULL, NULL,
+			       g_cclosure_marshal_VOID__VOID,
+			       G_TYPE_NONE, 0);
+
 	location_quark        = g_quark_from_string("KzBookmarkFile::BookmarkFileLocation");
 	file_type_quark       = g_quark_from_string("KzBookmarkFile::FileType");
 	interval_quark        = g_quark_from_string("KzBookmarkFile::Interval");
@@ -302,7 +305,7 @@ kz_bookmark_file_init (KzBookmarkFile *bookmark_file)
 
 
 static void
-kz_bookmark_file_dispose (GObject *object)
+dispose (GObject *object)
 {
 	guint timer_id, io_id;
 	KzIO *io;
@@ -334,8 +337,8 @@ kz_bookmark_file_dispose (GObject *object)
 	g_object_set_qdata(object, io_signal_id_quark,
 			   GUINT_TO_POINTER(io_id));
 
-	if (G_OBJECT_CLASS (parent_class)->dispose)
-		G_OBJECT_CLASS (parent_class)->dispose(object);
+	if (G_OBJECT_CLASS (kz_bookmark_file_parent_class)->dispose)
+		G_OBJECT_CLASS (kz_bookmark_file_parent_class)->dispose(object);
 }
 
 
@@ -346,10 +349,10 @@ kz_bookmark_file_dispose (GObject *object)
 }
 
 static void
-kz_bookmark_file_set_property (GObject *object,
-			       guint prop_id,
-			       const GValue *value,
-			       GParamSpec *pspec)
+set_property (GObject *object,
+              guint prop_id,
+              const GValue *value,
+              GParamSpec *pspec)
 {
 	KzBookmarkFile *bookmark_file = KZ_BOOKMARK_FILE(object);
 
@@ -440,10 +443,10 @@ kz_bookmark_file_set_property (GObject *object,
 
 
 static void
-kz_bookmark_file_get_property (GObject *object,
-		               guint prop_id,
-		               GValue *value,
-		               GParamSpec *pspec)
+get_property (GObject *object,
+              guint prop_id,
+              GValue *value,
+              GParamSpec *pspec)
 {
 	KzBookmarkFile *bookmark_file = KZ_BOOKMARK_FILE(object);
 	gchar *str;
@@ -756,7 +759,6 @@ kz_bookmark_file_save_stop (KzBookmarkFile *bookmark_file)
 	g_warning("kz_bookmark_file_save_stop() is not implemented yet.");
 }
 
-#warning! FIXME! this is available only for local bookmark_file.
 void
 kz_bookmark_file_load (KzBookmarkFile *bookmark_file)
 {
@@ -863,12 +865,20 @@ ERROR:
 
 	if (error)
 	{
+		gchar *message;
+		if (error->message)
+			message = g_strdup_printf("Load failed: %s",
+						  error->message);
+		else
+			message = g_strdup("Load failed");
+
 		g_signal_emit(bookmark_file,
 			      kz_bookmark_file_signals[ERROR_SIGNAL],
 			      0,
-			      "Load failed");
+			      message);
+		g_free(message);
 	}
-	else 
+	else
 	{
 		g_signal_emit(bookmark_file,
 			      kz_bookmark_file_signals[LOAD_COMPLETED_SIGNAL],
@@ -1145,3 +1155,18 @@ kz_bookmark_file_is_update (KzBookmarkFile *bookmark_file)
 	return last_time < time ? TRUE : FALSE;
 }
 
+void
+kz_bookmark_file_initialize (KzBookmarkFile *bookmark_file)
+{
+	KzBookmarkFileType *type;
+
+	type = kz_bookmark_file_detect_file_type(bookmark_file, NULL);
+	if (type && type->from_string)
+	{
+		if (!kz_bookmark_file_get_file_type(bookmark_file))
+			kz_bookmark_file_set_file_type(bookmark_file, type->file_type);
+		type->from_string(bookmark_file, NULL, 0, NULL);
+	}
+
+}
+
