@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-bookmark-menu-item.c 3156 2007-04-09 01:07:21Z ikezoe $
+ *  $Id: kz-bookmark-menu-item.c 3482 2008-03-12 09:47:55Z pal_gene $
  */
 
 #include "kz-bookmark-menu-item.h"
@@ -215,15 +215,24 @@ activate (GtkMenuItem *item)
 	const gchar *uri;
 	KzBookmarkMenuItem *bitem;
 	KzBookmarkBaseMenuItem *parent;
-
+	gboolean open_new;
+	
 	parent = KZ_BOOKMARK_BASE_MENU_ITEM(item);
 	bitem = KZ_BOOKMARK_MENU_ITEM(item);
 
 	if (!bitem->is_releasing_button)
 	{
 		uri = kz_bookmark_get_link(parent->bookmark);
-
-		kz_window_load_url(parent->kz, uri);
+		
+		KZ_CONF_GET("Global", "always_open_new", open_new, BOOL);
+		if (open_new)
+		{
+			kz_window_open_new_tab(parent->kz, uri);
+		}
+		else
+		{
+			kz_window_load_url(parent->kz, uri);
+		}
 	}
 	bitem->is_releasing_button = FALSE;
 }
