@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-bookmark.c,v 1.80 2006/04/23 14:42:25 kous Exp $
+ *  $Id: kz-bookmark.c 3054 2007-03-27 07:38:50Z kous $
  */
 
 #include "kz-bookmark.h"
@@ -26,11 +26,9 @@
 #include <string.h>
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
-#include "gobject-utils.h"
 #include "glib-utils.h"
 #include "kz-marshalers.h"
 #include "utils.h"
-#include "eggregex.h"
 #include "kz-bookmark-file.h"
 #include "kz-bookmarks-enum-types.h"
 
@@ -39,6 +37,8 @@ enum {
 	REMOVE_CHILD_SIGNAL,
 	MOVE_CHILD_SIGNAL,
 	CHILDREN_REORDERED_SIGNAL,
+	GET_CHILDREN_SIGNAL,
+	HAS_CHILDREN_SIGNAL,
 	LAST_SIGNAL
 };
 
@@ -61,25 +61,24 @@ enum {
 };
 
 
-static void kz_bookmark_class_init   (KzBookmarkClass *klass);
-static void kz_bookmark_init         (KzBookmark      *bookmark);
-static void kz_bookmark_dispose      (GObject         *object);
-static void kz_bookmark_set_property (GObject         *object,
-				      guint            prop_id,
-				      const GValue    *value,
-				      GParamSpec      *pspec);
-static void kz_bookmark_get_property (GObject         *object,
-				      guint            prop_id,
-				      GValue          *value,
-				      GParamSpec      *pspec);
+static void dispose      (GObject         *object);
+static void set_property (GObject         *object,
+                          guint            prop_id,
+                          const GValue    *value,
+                          GParamSpec      *pspec);
+static void get_property (GObject         *object,
+                          guint            prop_id,
+                          GValue          *value,
+                          GParamSpec      *pspec);
 
 static void kz_bookmark_real_insert_child (KzBookmark *bookmark,
 					   KzBookmark *child,
 					   KzBookmark *sibling);
 static void kz_bookmark_real_remove_child (KzBookmark *bookmark,
 					   KzBookmark *child);
+static GList   *kz_bookmark_real_get_children (KzBookmark *bookmark);
+static gboolean kz_bookmark_real_has_children (KzBookmark *bookmark);
 
-static GObjectClass *parent_class = NULL;
 static gint kz_bookmark_signals[LAST_SIGNAL] = {0};
 
 static GQuark id_quark                = 0;
@@ -97,28 +96,26 @@ static GQuark lock_quark              = 0;
 static GQuark auto_refresh_quark      = 0;
 static GQuark javascript_quark        = 0;
 
-
-KZ_OBJECT_GET_TYPE(kz_bookmark, "KzBookmark", KzBookmark,
-		   kz_bookmark_class_init, kz_bookmark_init,
-		   G_TYPE_OBJECT)
-
+G_DEFINE_TYPE(KzBookmark, kz_bookmark, G_TYPE_OBJECT)
 
 static void
 kz_bookmark_class_init (KzBookmarkClass *klass)
 {
 	GObjectClass *object_class;
 
-	parent_class = g_type_class_peek_parent (klass);
+	kz_bookmark_parent_class = g_type_class_peek_parent (klass);
 	object_class = (GObjectClass *) klass;
 
-	object_class->dispose      = kz_bookmark_dispose;
-	object_class->set_property = kz_bookmark_set_property;
-	object_class->get_property = kz_bookmark_get_property;
+	object_class->dispose      = dispose;
+	object_class->set_property = set_property;
+	object_class->get_property = get_property;
 
 	klass->insert_child       = kz_bookmark_real_insert_child;
 	klass->remove_child       = kz_bookmark_real_remove_child;
 	klass->move_child         = NULL; /* kz_bookmark_real_move_child; */
 	klass->children_reordered = NULL;
+	klass->get_children       = kz_bookmark_real_get_children;
+	klass->has_children       = kz_bookmark_real_has_children;
 
 	g_object_class_install_property(
 		object_class,
@@ -299,6 +296,24 @@ kz_bookmark_class_init (KzBookmarkClass *klass)
 				g_cclosure_marshal_VOID__VOID,
 				G_TYPE_NONE, 0);
 
+	kz_bookmark_signals[GET_CHILDREN_SIGNAL]
+		= g_signal_new ("get-children",
+				G_TYPE_FROM_CLASS (klass),
+				G_SIGNAL_RUN_LAST,
+				G_STRUCT_OFFSET (KzBookmarkClass, get_children),
+				NULL, NULL,
+				_kz_marshal_POINTER__VOID,
+				G_TYPE_POINTER, 0);
+
+	kz_bookmark_signals[HAS_CHILDREN_SIGNAL]
+		= g_signal_new ("has-children",
+				G_TYPE_FROM_CLASS (klass),
+				G_SIGNAL_RUN_LAST,
+				G_STRUCT_OFFSET (KzBookmarkClass, has_children),
+				NULL, NULL,
+				_kz_marshal_BOOLEAN__VOID,
+				G_TYPE_BOOLEAN, 0);
+
 	/* FIXME! add other properties */
 	/*
 	 * candidates:
@@ -332,7 +347,7 @@ kz_bookmark_init (KzBookmark *bookmark)
 
 
 static void
-kz_bookmark_dispose (GObject *object)
+dispose (GObject *object)
 {
 	KzBookmark *bookmark;
 	
@@ -340,8 +355,8 @@ kz_bookmark_dispose (GObject *object)
 
 	kz_bookmark_remove_all(bookmark);
 
-	if (G_OBJECT_CLASS (parent_class)->dispose)
-		G_OBJECT_CLASS (parent_class)->dispose(object);
+	if (G_OBJECT_CLASS (kz_bookmark_parent_class)->dispose)
+		G_OBJECT_CLASS (kz_bookmark_parent_class)->dispose(object);
 }
 
 
@@ -352,10 +367,10 @@ kz_bookmark_dispose (GObject *object)
 }
 
 static void
-kz_bookmark_set_property (GObject *object,
-			  guint prop_id,
-			  const GValue *value,
-			  GParamSpec *pspec)
+set_property (GObject *object,
+              guint prop_id,
+              const GValue *value,
+              GParamSpec *pspec)
 {
 	KzBookmark *bookmark = KZ_BOOKMARK(object);
 
@@ -428,10 +443,10 @@ kz_bookmark_set_property (GObject *object,
 
 
 static void
-kz_bookmark_get_property (GObject *object,
-		     guint prop_id,
-		     GValue *value,
-		     GParamSpec *pspec)
+get_property (GObject *object,
+              guint prop_id,
+              GValue *value,
+              GParamSpec *pspec)
 {
 	KzBookmark *bookmark = KZ_BOOKMARK(object);
 	gchar *str;
@@ -842,10 +857,10 @@ kz_bookmark_real_remove_child (KzBookmark *bookmark, KzBookmark *child)
 	if (!g_list_find(list, child)) return;
 
 	list = g_list_remove(list, child);
-	g_object_unref(child);
 	g_object_set_qdata(G_OBJECT(bookmark), children_quark, list);
 
-	g_object_set_qdata(G_OBJECT(child), parent_quark, NULL);	
+	g_object_set_qdata(G_OBJECT(child), parent_quark, NULL);
+	g_object_unref(child);
 }
 
 
@@ -865,9 +880,8 @@ kz_bookmark_remove_all (KzBookmark *bookmark)
 
 	children = g_object_get_qdata(G_OBJECT(bookmark), children_quark);
 	children = g_list_copy(children);
-	children = g_list_last(children);
 
-	node = children;
+	node = g_list_last(children);
 	while (node)
 	{
 		KzBookmark *child = node->data;
@@ -907,13 +921,11 @@ kz_bookmark_get_parent_file (KzBookmark *bookmark)
 }
 
 
-GList *
-kz_bookmark_get_children (KzBookmark *bookmark)
+static GList *
+kz_bookmark_real_get_children (KzBookmark *bookmark)
 {
 	GList *list;
 
-	g_return_val_if_fail(KZ_IS_BOOKMARK(bookmark), NULL);
-
 	list =  g_object_get_qdata(G_OBJECT(bookmark), children_quark);
 
 	if (list)
@@ -922,14 +934,25 @@ kz_bookmark_get_children (KzBookmark *bookmark)
 	return NULL;
 }
 
+GList *
+kz_bookmark_get_children (KzBookmark *bookmark)
+{
+	GList *result;
 
-gboolean
-kz_bookmark_has_children (KzBookmark  *bookmark)
+	g_return_val_if_fail(KZ_IS_BOOKMARK(bookmark), NULL);
+
+	g_signal_emit(bookmark,
+		      kz_bookmark_signals[GET_CHILDREN_SIGNAL], 0,
+		      &result);
+	return result;
+}
+
+
+static gboolean
+kz_bookmark_real_has_children (KzBookmark  *bookmark)
 {
 	GList *list;
 
-	g_return_val_if_fail(KZ_IS_BOOKMARK(bookmark), FALSE);
-
 	list =  g_object_get_qdata(G_OBJECT(bookmark), children_quark);
 
 	if (list)
@@ -938,6 +961,18 @@ kz_bookmark_has_children (KzBookmark  *bookmark)
 		return FALSE;
 }
 
+gboolean
+kz_bookmark_has_children (KzBookmark *bookmark)
+{
+	gboolean result;
+
+	g_return_val_if_fail(KZ_IS_BOOKMARK(bookmark), FALSE);
+
+	g_signal_emit(bookmark,
+		      kz_bookmark_signals[HAS_CHILDREN_SIGNAL], 0,
+		      &result);
+	return result;
+}
 
 KzBookmark *
 kz_bookmark_next (KzBookmark *bookmark)
