@@ -17,14 +17,14 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-bookmarks-view.c,v 1.31 2005/09/11 01:02:43 kous Exp $
+ *  $Id: kz-bookmarks-view.c 2714 2006-12-31 01:59:41Z ikezoe $
  */
 
 #include "kz-bookmarks-view.h"
 #include <glib/gi18n.h>
 #include <string.h>
 
-#include "gobject-utils.h"
+#include "kazehakase.h"
 #include "kz-bookmark-file.h"
 #include "kz-smart-bookmark.h"
 #include "kz-favicon.h"
@@ -59,9 +59,7 @@ struct _KzBookmarksViewPrivate
 #define KZ_BOOKMARKS_VIEW_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), KZ_TYPE_BOOKMARKS_VIEW, KzBookmarksViewPrivate))
 
 
-static void     kz_bookmarks_view_class_init (KzBookmarksViewClass *klass);
-static void     kz_bookmarks_view_init       (KzBookmarksView      *view);
-static void     kz_bookmarks_view_dispose    (GObject              *object);
+static void     dispose    (GObject              *object);
 
 static void     connect_bookmark_signals     (KzBookmarksView *view,
 					      KzBookmark *bookmark);
@@ -114,52 +112,17 @@ static GtkTargetEntry dnd_types[] = {
 };
 static const gint dnd_types_num = G_N_ELEMENTS(dnd_types);
 
-
-static GtkTreeViewClass *parent_class = NULL;
-
-
-KZ_OBJECT_GET_TYPE(kz_bookmarks_view, "KzBookmarksView", KzBookmarksView,
-		   kz_bookmarks_view_class_init, kz_bookmarks_view_init,
-		   GTK_TYPE_TREE_VIEW)
-
+G_DEFINE_TYPE(KzBookmarksView, kz_bookmarks_view, GTK_TYPE_TREE_VIEW)
 
 static void
 kz_bookmarks_view_class_init (KzBookmarksViewClass *klass)
 {
 	GObjectClass *gobject_class;
-	GtkWidgetClass *widget_class;
-
-	parent_class = g_type_class_peek_parent (klass);
 
 	gobject_class = (GObjectClass *)   klass;
-	widget_class  = (GtkWidgetClass *) klass;
 
-	gobject_class->dispose      = kz_bookmarks_view_dispose;
-#if 0
-	gobject_class->set_property = kz_bookmarks_view_set_property;
-	gobject_class->get_property = kz_bookmarks_view_get_property;
+	gobject_class->dispose      = dispose;
 
-	g_object_class_install_property
-		(gobject_class,
-		 PROP_ROOT_FOLDER,
-		 g_param_spec_object (
-			 "root-folder",
-			 _("Root Folder"),
-			 _("The root bookmark folder to show"),
-			 KZ_TYPE_BOOKMARK,
-			 G_PARAM_READWRITE));
-
-	g_object_class_install_property(
-		gobject_class,
-		PROP_TREE_MODE,
-		g_param_spec_boolean(
-			"tree-mode",
-			_("Tree mode"),
-			_("Whether use tree mode or not "
-			  "for bookmark view"),
-			TRUE,
-			G_PARAM_READWRITE));
-#endif
 	g_type_class_add_private (gobject_class, sizeof(KzBookmarksViewPrivate));
 }
 
@@ -178,7 +141,7 @@ kz_bookmarks_view_init (KzBookmarksView *view)
 
 
 static void
-kz_bookmarks_view_dispose (GObject *object)
+dispose (GObject *object)
 {
 	KzBookmarksView *view = KZ_BOOKMARKS_VIEW(object);
 
@@ -189,8 +152,8 @@ kz_bookmarks_view_dispose (GObject *object)
 		view->root_folder = NULL;
 	}
 
-	if (G_OBJECT_CLASS(parent_class)->dispose)
-		G_OBJECT_CLASS (parent_class)->dispose(object);
+	if (G_OBJECT_CLASS(kz_bookmarks_view_parent_class)->dispose)
+		G_OBJECT_CLASS (kz_bookmarks_view_parent_class)->dispose(object);
 }
 
 
@@ -543,7 +506,7 @@ insert_bookmark(KzBookmarksView *view,
 		image = gtk_image_new_from_stock(icon,
 						 GTK_ICON_SIZE_MENU);
 		g_object_ref(G_OBJECT(image));
-		gtk_object_sink(GTK_OBJECT(image));
+		g_object_ref_sink(G_OBJECT(image));
 		favicon = gtk_widget_render_icon(image, icon,
 						 GTK_ICON_SIZE_MENU,
 						 NULL);
@@ -556,7 +519,7 @@ insert_bookmark(KzBookmarksView *view,
 		image = gtk_image_new_from_stock(KZ_STOCK_SMART_BOOKMARK,
 						 GTK_ICON_SIZE_MENU);
 		g_object_ref(G_OBJECT(image));
-		gtk_object_sink(GTK_OBJECT(image));
+		g_object_ref_sink(G_OBJECT(image));
 		favicon = gtk_widget_render_icon(image, KZ_STOCK_SMART_BOOKMARK,
 						 GTK_ICON_SIZE_MENU,
 						 NULL);
@@ -568,7 +531,7 @@ insert_bookmark(KzBookmarksView *view,
 	}
 	else
 	{
-		KzFavicon *kz_favicon = kz_favicon_get_instance();
+		KzFavicon *kz_favicon = KZ_GET_FAVICON;
 
 		favicon = kz_favicon_get_pixbuf(kz_favicon, uri,
 						GTK_ICON_SIZE_MENU);
@@ -579,13 +542,12 @@ insert_bookmark(KzBookmarksView *view,
 			image = gtk_image_new_from_stock(KZ_STOCK_BOOKMARK,
 							 GTK_ICON_SIZE_MENU);
 			g_object_ref(G_OBJECT(image));
-			gtk_object_sink(GTK_OBJECT(image));
+			g_object_ref_sink(G_OBJECT(image));
 			favicon = gtk_widget_render_icon(image, KZ_STOCK_BOOKMARK,
 							 GTK_ICON_SIZE_MENU,
 							 NULL);
 			g_object_unref(image);
 		}
-		g_object_unref(kz_favicon);
 	}
 
 	if (priv->editable)
