@@ -22,6 +22,8 @@
 #define __USE_XOPEN
 #include <time.h>
 
+#include "kz-missing.h"
+
 #include "kz-hinadi.h"
 
 
@@ -35,12 +37,12 @@ static gboolean kz_hinadi_parse_from_string (KzBookmarkFile *rbookmark,
 
 static KzBookmarkFileType hinadi_file_type =
 {
-	priority_hint: 0,
-	file_type:     "hina-di",
-	is_supported:  kz_hinadi_is_supported,
-	init:          NULL,
-	from_string:   kz_hinadi_parse_from_string,
-	to_string:     NULL,
+	/* .priority_hint = */ 0,
+	/* .file_type     = */ "hina-di",
+	/* .init          = */ NULL,
+	/* .is_supported  = */ kz_hinadi_is_supported,
+	/* .from_string   = */ kz_hinadi_parse_from_string,
+	/* .to_string     = */ NULL,
 };
 
 
