@@ -17,42 +17,27 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-root-bookmark.c,v 1.14 2005/11/24 06:41:51 ikezoe Exp $
+ *  $Id: kz-root-bookmark.c 2748 2007-01-02 01:51:43Z ikezoe $
  */
 
 #include "kz-root-bookmark.h"
 
 #include <glib/gi18n.h>
-#include "gobject-utils.h"
 #include "kz-bookmark-file.h"
+#include "kz-session.h"
 
+static void     dispose     (GObject *object);
 
-static void     kz_root_bookmark_class_init  (KzRootBookmarkClass *klass);
-static void     kz_root_bookmark_init        (KzRootBookmark *bookmark);
-static GObject *kz_root_bookmark_constructor (GType           type,
-					      guint           n_props,
-					      GObjectConstructParam *props);
-static void     kz_root_bookmark_dispose     (GObject *object);
-
-
-static KzBookmarkClass *parent_class;
-
-
-KZ_OBJECT_GET_TYPE(kz_root_bookmark, "KzRootBookmark", KzRootBookmark,
-		   kz_root_bookmark_class_init, kz_root_bookmark_init,
-		   KZ_TYPE_BOOKMARK)
-
+G_DEFINE_TYPE(KzRootBookmark, kz_root_bookmark, KZ_TYPE_BOOKMARK)
 
 static void
 kz_root_bookmark_class_init (KzRootBookmarkClass *klass)
 {
 	GObjectClass *object_class;
 
-	parent_class = g_type_class_peek_parent(klass);
 	object_class = (GObjectClass *) klass;
 
-	object_class->constructor = kz_root_bookmark_constructor;
-	object_class->dispose     = kz_root_bookmark_dispose;
+	object_class->dispose     = dispose;
 }
 
 
@@ -63,39 +48,19 @@ kz_root_bookmark_init (KzRootBookmark *root)
 	root->clip            = KZ_BOOKMARK(kz_bookmark_file_new(NULL, NULL, NULL));
 	root->bookmark_bars   = kz_bookmark_pure_folder_new();
 	root->history         = kz_history_new(NULL);
-	root->sessions        = kz_bookmark_pure_folder_new();
-	root->current_session = KZ_BOOKMARK(kz_bookmark_file_new(NULL, NULL, NULL));
 	root->tab_groups      = kz_bookmark_pure_folder_new();
 	root->smarts          = NULL;
+	root->current_session = NULL;
 
 	kz_bookmark_set_title(root->menu,                 "Bookmark Menu");
 	kz_bookmark_set_title(root->bookmark_bars,        "Bookmark Bars");
 	kz_bookmark_set_title(KZ_BOOKMARK(root->history), "History");
-	kz_bookmark_set_title(root->sessions,             "Sessions");
-	kz_bookmark_set_title(root->current_session,      "Current Session");
 	kz_bookmark_set_title(root->tab_groups,           "Tab Groups");
 }
 
 
-static GObject *
-kz_root_bookmark_constructor (GType type, guint n_props,
-			      GObjectConstructParam *props)
-{
-	KzRootBookmark *root;
-
-	GObject *object;
-	GObjectClass *klass = G_OBJECT_CLASS(parent_class);
-
-	object = klass->constructor(type, n_props, props);
-
-	root = KZ_ROOT_BOOKMARK(object);
-
-	return object;
-}
-
-
 static void
-kz_root_bookmark_dispose (GObject *object)
+dispose (GObject *object)
 {
 	KzRootBookmark *root;
 
@@ -121,11 +86,6 @@ kz_root_bookmark_dispose (GObject *object)
 		g_object_unref(G_OBJECT(root->history));
 		root->history = NULL;
 	}
-	if (root->sessions)
-	{
-		g_object_unref(G_OBJECT(root->sessions));
-		root->sessions = NULL;
-	}
 	if (root->current_session)
 	{
 		g_object_unref(G_OBJECT(root->current_session));
@@ -142,8 +102,8 @@ kz_root_bookmark_dispose (GObject *object)
 		root->smarts = NULL;
 	}
 
-	if (G_OBJECT_CLASS (parent_class)->dispose)
-		G_OBJECT_CLASS (parent_class)->dispose(object);
+	if (G_OBJECT_CLASS (kz_root_bookmark_parent_class)->dispose)
+		G_OBJECT_CLASS (kz_root_bookmark_parent_class)->dispose(object);
 }
 
 
@@ -164,9 +124,8 @@ kz_root_bookmark_new (const gchar *menu_file,  const gchar *sys_menu_file,
 		kz_bookmark_append(KZ_BOOKMARK(root), root->clip);
 	if (root->bookmark_bars)
 		kz_bookmark_append(KZ_BOOKMARK(root), root->bookmark_bars);
-/*
+	/*
 	kz_bookmark_append(KZ_BOOKMARK(root), KZ_BOOKMARK(root->history));
-	kz_bookmark_append(KZ_BOOKMARK(root), root->sessions);
 	kz_bookmark_append(KZ_BOOKMARK(root), root->windows);
 	kz_bookmark_append(KZ_BOOKMARK(root), root->tab_groups);
 	*/
@@ -341,16 +300,8 @@ void
 kz_root_bookmark_add_current_session_file (KzRootBookmark *root,
 					   const gchar *file)
 {
-	KzBookmarkFile *current_session;
-
 	g_return_if_fail(KZ_IS_ROOT_BOOKMARK(root));
 	g_return_if_fail(file && *file);
-	g_return_if_fail(root->current_session);
-
-	/* FIXME! Check permission */
-	current_session = kz_bookmark_file_create_new(file,
-					  _("Current Session"),
-					  "XBEL");
 
 	if (root->current_session)
 	{
@@ -358,15 +309,7 @@ kz_root_bookmark_add_current_session_file (KzRootBookmark *root,
 		root->current_session = NULL;
 	}
 
-	if (current_session)
-	{
-		root->current_session = KZ_BOOKMARK(current_session);
-		/*	
-		kz_bookmark_insert_before(KZ_BOOKMARK(root),
-					  current_session, root->bookmark_bars);
-		g_object_unref(current_session);
-		*/
-	}
+	root->current_session = kz_session_new(file, _("Current Session"));
 }
 
 
