@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-smart-bookmark.c 2876 2007-03-16 05:17:34Z ikezoe $
+ *  $Id: kz-smart-bookmark.c 3227 2007-07-21 12:51:42Z kous $
  */
 
 #include "kz-smart-bookmark.h"
@@ -249,6 +249,7 @@ kz_smart_bookmark_get_smart_uri (KzSmartBookmark *bookmark, const gchar *text)
 	GList *smart_list, *node;
 	KzSmartBookmarkProperty *match = NULL;
 	GRegex *regex;
+	GMatchInfo *match_info = NULL;
 	GError *error = NULL;
 
 	g_return_val_if_fail(KZ_IS_BOOKMARK(bookmark), NULL);
@@ -287,14 +288,15 @@ kz_smart_bookmark_get_smart_uri (KzSmartBookmark *bookmark, const gchar *text)
 			return g_strdup(text);
 		}
 
-		ret = g_regex_match(regex, text, 0);
+		ret = g_regex_match(regex, text, 0, &match_info);
+		g_regex_unref(regex);
 
-		if (ret)		
+		if (ret)
 		{
 			match = prop;
 			break;
 		}
-		g_regex_free(regex);
+		g_match_info_free(match_info);
 	}
 
 	if(match)
@@ -307,7 +309,7 @@ kz_smart_bookmark_get_smart_uri (KzSmartBookmark *bookmark, const gchar *text)
 		guint i, n = 0;
 		GString *str;
 
-		strings = g_regex_fetch_all(regex, text);
+		strings = g_match_info_fetch_all(match_info);
 	
 		if (strings)
 		{
@@ -352,7 +354,7 @@ kz_smart_bookmark_get_smart_uri (KzSmartBookmark *bookmark, const gchar *text)
 		smart_uri = g_strndup(str->str, str->len);	
 		g_string_free(str, TRUE);
 
-		g_regex_free(regex);
+		g_match_info_free(match_info);
 	}
 	else
 	{
