@@ -43,12 +43,12 @@ static void     kz_w3mbookmark_init              (KzBookmark  *bookmark);
 */
 static KzBookmarkFileType w3mbookmark_file_type =
 {
-	priority_hint: 0,
-	file_type:     "W3MBOOKMARK",
-	init:          NULL,
-	is_supported:  kz_w3mbookmark_is_supported,
-	from_string:   kz_w3mbookmark_parse_from_string,
-	to_string:     NULL,
+	/* .priority_hint = */ 0,
+	/* .file_type     = */ "W3MBOOKMARK",
+	/* .init          = */ NULL,
+	/* .is_supported  = */ kz_w3mbookmark_is_supported,
+	/* .from_string   = */ kz_w3mbookmark_parse_from_string,
+	/* .to_string     = */ NULL,
 };
 
 
