@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-xbel.c 3100 2007-03-30 00:14:13Z kous $
+ *  $Id: kz-xbel.c 3267 2007-10-04 05:17:39Z ikezoe $
  */
 
 #include "kazehakase.h"
@@ -333,73 +333,73 @@ parse_metadata_node (KzBookmark *bookmark, KzXMLNode *parent)
 		{
 			KzXMLAttr *attr = a_node->data;
 
-			if (g_str_has_prefix(attr->name, "kz:update_interval"))
+			if (!strcmp(attr->name, "kz:update_interval"))
 			{
 				interval = atoi(attr->value);
 				kz_bookmark_file_set_interval(KZ_BOOKMARK_FILE(bookmark), interval);
 			}
-			else if (g_str_has_prefix(attr->name, "kz:smart_regex"))
+			else if (!strcmp(attr->name, "kz:smart_regex"))
 			{
 				smart_regex = attr->value;
 			}
-			else if (g_str_has_prefix(attr->name, "kz:smart_uri"))
+			else if (!strcmp(attr->name, "kz:smart_uri"))
 			{
 				smart_uri = attr->value;
 			}
-			else if (g_str_has_prefix(attr->name, "kz:smart_encode"))
+			else if (!strcmp(attr->name, "kz:smart_encode"))
 			{
 				smart_encode = attr->value;
 			}
-			else if (g_str_has_prefix(attr->name, "kz:smart_urlencode"))
+			else if (!strcmp(attr->name, "kz:smart_urlencode"))
 			{
 				urlencode = TRUE;
 			}
-			else if (g_str_has_prefix(attr->name, "kz:smart_history") && !smart_history)
+			else if (!strcmp(attr->name, "kz:smart_history") && !smart_history)
 			{
 				smart_history = KZ_BOOKMARK(kz_bookmark_file_new(attr->value,
 							    NULL, NULL));
 				is_smart_history = TRUE;
 			}
-			else if (g_str_has_prefix(attr->name, "kz:xmlrpc"))
+			else if (!strcmp(attr->name, "kz:xmlrpc"))
 			{
 				kz_bookmark_file_set_xmlrpc(KZ_BOOKMARK_FILE(bookmark), attr->value);
 			}
-			else if (g_str_has_prefix(attr->name, "kz:xmlrpc_user"))
+			else if (!strcmp(attr->name, "kz:xmlrpc_user"))
 			{
 				kz_bookmark_file_set_xmlrpc_user(KZ_BOOKMARK_FILE(bookmark), attr->value);
 			}
-			else if (g_str_has_prefix(attr->name, "kz:xmlrpc_pass"))
+			else if (!strcmp(attr->name, "kz:xmlrpc_pass"))
 			{
 				kz_bookmark_file_set_xmlrpc_pass(KZ_BOOKMARK_FILE(bookmark), attr->value);
 			}
-			else if (g_str_has_prefix(attr->name, "kz:smart_xmlrpc"))
+			else if (!strcmp(attr->name, "kz:smart_xmlrpc"))
 			{
 				kz_bookmark_file_set_xmlrpc(KZ_BOOKMARK_FILE(smart_history), attr->value);
 			}
-			else if (g_str_has_prefix(attr->name, "kz:smart_xmlrpc_user"))
+			else if (!strcmp(attr->name, "kz:smart_xmlrpc_user"))
 			{
 				kz_bookmark_file_set_xmlrpc_user(KZ_BOOKMARK_FILE(smart_history), attr->value);
 			}
-			else if (g_str_has_prefix(attr->name, "kz:smart_xmlrpc_pass"))
+			else if (!strcmp(attr->name, "kz:smart_xmlrpc_pass"))
 			{
 				kz_bookmark_file_set_xmlrpc_pass(KZ_BOOKMARK_FILE(smart_history), attr->value);
 			}
-			else if (g_str_has_prefix(attr->name, "kz:current_position"))
+			else if (!strcmp(attr->name, "kz:current_position"))
 			{
 				guint pos = (guint)atoi(attr->value);
 				kz_bookmark_set_current(bookmark, pos);
 			}
-			else if (g_str_has_prefix(attr->name, "kz:lock"))
+			else if (!strcmp(attr->name, "kz:lock"))
 			{
 				if (!strcmp(attr->value, "yes"))
 					kz_bookmark_set_lock(bookmark, TRUE);
 			}
-			else if (g_str_has_prefix(attr->name, "kz:auto_refresh"))
+			else if (!strcmp(attr->name, "kz:auto_refresh"))
 			{
 				if (!strcmp(attr->value, "yes"))
 					kz_bookmark_set_auto_refresh(bookmark, TRUE);
 			}
-			else if (g_str_has_prefix(attr->name, "kz:javascript"))
+			else if (!strcmp(attr->name, "kz:javascript"))
 			{
 				if (!strcmp(attr->value, "yes"))
 					kz_bookmark_set_javascript(bookmark, TRUE);
