@@ -28,8 +28,8 @@
 #include <stdio.h>
 #include <gdk/gdkkeysyms.h>
 #include <glib/gi18n.h>
+#include <string.h>
 
-#include "gobject-utils.h"
 #include "kz-icons.h"
 
 #define EMBED_MAX_BUTTONS 3
@@ -101,43 +101,33 @@ static const DialogDescription DialogTable[] = {
 	  INCLUDE_CHECKBOX,       GTK_STOCK_DIALOG_QUESTION }   // UNIVERSAL
 };
 
-static void     kz_prompt_dialog_class_init         (KzPromptDialogClass *klass);
-static void     kz_prompt_dialog_init               (KzPromptDialog  *prompt);
-static GObject *kz_prompt_dialog_constructor        (GType           type,
-						     guint           n_props,
-						     GObjectConstructParam *props);
-static void     kz_prompt_dialog_dispose            (GObject        *object);
-static void     kz_prompt_dialog_set_property       (GObject       *object,
-						     guint          prop_id,
-						     const GValue  *value,
-						     GParamSpec    *pspec);
-static void     kz_prompt_dialog_get_property       (GObject       *object,
-						     guint          prop_id,
-						     GValue        *value,
-						     GParamSpec    *pspec);
+static GObject *constructor        (GType           type,
+				    guint           n_props,
+				    GObjectConstructParam *props);
+static void     dispose            (GObject        *object);
+static void     set_property       (GObject       *object,
+				    guint          prop_id,
+				    const GValue  *value,
+				    GParamSpec    *pspec);
+static void     get_property       (GObject       *object,
+				    guint          prop_id,
+				    GValue        *value,
+				    GParamSpec    *pspec);
 static void     kz_prompt_dialog_save_dialog_values (KzPromptDialog *prompt);
 
-static GtkDialogClass *parent_class = NULL;
-
-
-KZ_OBJECT_GET_TYPE(kz_prompt_dialog, "KzPromptDialog", KzPromptDialog,
-		   kz_prompt_dialog_class_init, kz_prompt_dialog_init,
-		   GTK_TYPE_DIALOG)
+G_DEFINE_TYPE(KzPromptDialog, kz_prompt_dialog, GTK_TYPE_DIALOG)
 
 static void
 kz_prompt_dialog_class_init (KzPromptDialogClass *klass)
 {
 	GObjectClass *gobject_class;
 
-	parent_class = g_type_class_peek_parent (klass);
-
 	gobject_class = (GObjectClass *) klass;
 
-	/* GtkObject signals */
-	gobject_class->constructor  = kz_prompt_dialog_constructor;
-	gobject_class->dispose      = kz_prompt_dialog_dispose;
-	gobject_class->set_property = kz_prompt_dialog_set_property;
-	gobject_class->get_property = kz_prompt_dialog_get_property;
+	gobject_class->constructor  = constructor;
+	gobject_class->dispose      = dispose;
+	gobject_class->set_property = set_property;
+	gobject_class->get_property = get_property;
 
 	g_object_class_install_property
 		(gobject_class,
@@ -228,14 +218,14 @@ kz_prompt_dialog_init (KzPromptDialog *prompt)
 
 
 static GObject*
-kz_prompt_dialog_constructor (GType                  type,
-			      guint                  n_props,
-			      GObjectConstructParam *props)
+constructor (GType                  type,
+	     guint                  n_props,
+	     GObjectConstructParam *props)
 {
 	KzPromptDialog *prompt;
 	KzPromptDialogPrivate *priv;
 	GObject *object;
-	GObjectClass *klass = G_OBJECT_CLASS(parent_class);
+	GObjectClass *klass = G_OBJECT_CLASS(kz_prompt_dialog_parent_class);
 	gint prompt_type;
 	int widgetFlags;
 
@@ -308,7 +298,6 @@ kz_prompt_dialog_constructor (GType                  type,
 		gtk_box_pack_start(GTK_BOX(priv->content_vbox), priv->text_field, FALSE, FALSE, 0);
 	}
 
-	// Add a checkbox
 	if (widgetFlags & INCLUDE_CHECKBOX)
 	{
 		priv->check_box = gtk_check_button_new_with_label(NULL);
@@ -316,10 +305,8 @@ kz_prompt_dialog_constructor (GType                  type,
 		gtk_box_pack_start(GTK_BOX(priv->content_vbox), priv->check_box, FALSE, FALSE, 0);
 	}
 
-	// Add a dropdown menu
 	if (prompt_type == TYPE_SELECT) 
 	{
-		// Build up a GtkMenu containing the items
 		priv->combo_box = gtk_combo_box_new_text();
 
 		gtk_box_pack_start(GTK_BOX(priv->content_vbox), priv->combo_box, FALSE, FALSE, 0);
@@ -331,12 +318,12 @@ kz_prompt_dialog_constructor (GType                  type,
 	}
 	else 
 	{
-		// Create standard ok and cancel buttons
+		GtkWidget* okButton;
 		if (widgetFlags & INCLUDE_CANCEL)
 			gtk_dialog_add_button(GTK_DIALOG(prompt), GTK_STOCK_CANCEL,
 					GTK_RESPONSE_CANCEL);
 
-		GtkWidget* okButton = gtk_dialog_add_button(GTK_DIALOG(prompt),
+		okButton = gtk_dialog_add_button(GTK_DIALOG(prompt),
 				GTK_STOCK_OK,
 				GTK_RESPONSE_ACCEPT);
 		gtk_widget_grab_default(okButton);
@@ -347,7 +334,7 @@ kz_prompt_dialog_constructor (GType                  type,
 
 
 static void
-kz_prompt_dialog_dispose (GObject *object)
+dispose (GObject *object)
 {
 	KzPromptDialogPrivate *priv = KZ_PROMPT_DIALOG_GET_PRIVATE (object);
 
@@ -366,26 +353,30 @@ kz_prompt_dialog_dispose (GObject *object)
 	priv->pass         = NULL;
 	priv->parent_window = NULL;
 
-	if (G_OBJECT_CLASS (parent_class)->dispose)
-		G_OBJECT_CLASS (parent_class)->dispose(object);
+	if (G_OBJECT_CLASS (kz_prompt_dialog_parent_class)->dispose)
+		G_OBJECT_CLASS (kz_prompt_dialog_parent_class)->dispose(object);
 }
 
 
 static void
-kz_prompt_dialog_set_property (GObject         *object,
-			       guint            prop_id,
-			       const GValue    *value,
-			       GParamSpec      *pspec)
+set_property (GObject         *object,
+	      guint            prop_id,
+	      const GValue    *value,
+	      GParamSpec      *pspec)
 {
 	KzPromptDialogPrivate *priv = KZ_PROMPT_DIALOG_GET_PRIVATE (object);
-  
+
 	switch (prop_id)
 	{
 	case PROP_PROMPT_TYPE:
 		priv->prompt_type = g_value_get_int(value);
 		break;
 	case PROP_PARENT_WINDOW:
-		priv->parent_window = g_object_ref(g_value_get_object(value));
+		if (priv->parent_window)
+			g_object_unref(priv->parent_window);
+		priv->parent_window = g_value_get_object(value);
+		if (priv->parent_window)
+			g_object_ref(priv->parent_window);
 		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -395,10 +386,10 @@ kz_prompt_dialog_set_property (GObject         *object,
 
 
 static void
-kz_prompt_dialog_get_property (GObject         *object,
-			       guint            prop_id,
-			       GValue          *value,
-			       GParamSpec      *pspec)
+get_property (GObject         *object,
+	      guint            prop_id,
+	      GValue          *value,
+	      GParamSpec      *pspec)
 {
 	KzPromptDialogPrivate *priv = KZ_PROMPT_DIALOG_GET_PRIVATE (object);
 
