@@ -924,18 +924,6 @@ kz_embed_get_body_text (KzEmbed *kzembed)
 }
 
 
-#if 0
-gchar *
-kz_embed_get_selection_source (KzEmbed *kzembed)
-{
-	g_return_val_if_fail(KZ_IS_EMBED(kzembed), NULL);
-	g_return_val_if_fail(KZ_EMBED_GET_IFACE(kzembed)->get_selection_source, NULL);
-
-	return KZ_EMBED_GET_IFACE(kzembed)->get_selection_source(kzembed);
-}
-#endif
-
-
 void
 kz_embed_set_encoding (KzEmbed *kzembed, const char *encoding)
 {
@@ -1112,28 +1100,6 @@ kz_embed_get_last_modified (KzEmbed *kzembed)
 }
 
 
-#if 0
-void
-kz_embed_set_edit_mode (KzEmbed *kzembed)
-{
-	g_return_if_fail(KZ_IS_EMBED(kzembed));
-	g_return_if_fail(KZ_EMBED_GET_IFACE(kzembed)->set_edit_mode);
-
-	KZ_EMBED_GET_IFACE(kzembed)->set_edit_mode(kzembed);
-}
-
-
-void
-kz_embed_set_view_mode (KzEmbed *kzembed)
-{
-	g_return_if_fail(KZ_IS_EMBED(kzembed));
-	g_return_if_fail(KZ_EMBED_GET_IFACE(kzembed)->set_view_mode);
-
-	KZ_EMBED_GET_IFACE(kzembed)->set_view_mode(kzembed);
-}
-#endif
-
-
 void
 kz_embed_fine_scroll (KzEmbed *kzembed, 
 		      int horiz, int vert)
