@@ -410,9 +410,7 @@ void		kz_embed_set_lock		(KzEmbed       *kzembed,
 						 gboolean	lock);
 
 gchar	       *kz_embed_get_body_text		(KzEmbed       *kzembed);
-#if 0
-gchar	       *kz_embed_get_selection_source	(KzEmbed       *kzembed);
-#endif
+
 void		kz_embed_set_encoding		(KzEmbed       *kzembed,
 						 const char    *encoding);
 void		kz_embed_get_encoding		(KzEmbed       *kzembed,
@@ -455,11 +453,6 @@ void		kz_embed_get_history		(KzEmbed       *kzembed,
 
 guint		kz_embed_get_last_modified	(KzEmbed       *kzembed);	
 
-
-#if 0
-void		kz_embed_set_edit_mode		(KzEmbed       *kzembed);
-void		kz_embed_set_view_mode		(KzEmbed       *kzembed);
-#endif
 void            kz_embed_fine_scroll            (KzEmbed       *kzembed,
 						 int            horiz,
 						 int            vert);
