@@ -7,7 +7,7 @@
 #include <glib-object.h>
 
 G_BEGIN_DECLS
-/* enumerations from "kazehakase.h" */
+/* enumerations from "kz-app.h" */
 GType kz_ui_level_get_type (void);
 #define KZ_TYPE_UI_LEVEL (kz_ui_level_get_type())
 /* enumerations from "kz-embed.h" */
@@ -37,6 +37,9 @@ GType kz_prefs_win_response_get_type (void);
 /* enumerations from "kz-xml.h" */
 GType kz_xml_node_type_get_type (void);
 #define KZ_TYPE_XML_NODE_TYPE (kz_xml_node_type_get_type())
+/* enumerations from "kz-notebook.h" */
+GType kz_notebook_close_condition_get_type (void);
+#define KZ_TYPE_NOTEBOOK_CLOSE_CONDITION (kz_notebook_close_condition_get_type())
 /* enumerations from "kz-langinfo.h" */
 GType language_group_get_type (void);
 #define KZ_TYPE_GROUP (language_group_get_type())
