@@ -1,7 +1,7 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 
 /*
- *  Copyright (C) 2006 Kouhei Sutou
+ *  Copyright (C) 2006-2007 Kouhei Sutou
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -28,13 +28,29 @@
 
 G_BEGIN_DECLS
 
-typedef void (*KzExtInitFunc)  (void);
-typedef void (*KzExtSetupFunc) (KzWindow *window);
-typedef void (*KzExtExitFunc)  (gboolean success);
+#define KZ_TYPE_EXT		(kz_ext_get_type())
+#define KZ_EXT(o)		(G_TYPE_CHECK_INSTANCE_CAST((o), KZ_TYPE_EXT, KzExt))
+#define KZ_IS_EXT(o)		(G_TYPE_CHECK_INSTANCE_TYPE((o), KZ_TYPE_EXT))
+#define KZ_EXT_GET_IFACE(o)	(G_TYPE_INSTANCE_GET_INTERFACE((o), KZ_TYPE_EXT, KzExtIFace))
 
-void	 kz_ext_init		(void);
-void	 kz_ext_setup		(KzWindow *kz);
-void	 kz_ext_exit		(void);
+typedef struct _KzExt      KzExt;
+typedef struct _KzExtIFace KzExtIFace;
+
+struct _KzExtIFace {
+	GTypeInterface g_iface;
+
+	/* vtable */
+	void	(*init)		(KzExt		*ext,
+				 gpointer	 initial_address);
+	void	(*setup)	(KzExt		*ext,
+				 KzWindow	*window);
+};
+
+GType		kz_ext_get_type		(void) G_GNUC_CONST;
+
+void		kz_ext_init		(gpointer	 initial_address);
+void		kz_ext_setup		(KzWindow 	*window);
+void		kz_ext_exit		(void);
 
 G_END_DECLS
 
