@@ -1,3 +1,5 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
+
 /*
  *  Copyright (C) 2003 Takuro Ashie
  *
@@ -15,9 +17,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-icons.c,v 1.10 2005/07/13 03:58:36 ikezoe Exp $
+ *  $Id: kz-icons.c 3081 2007-03-28 03:53:51Z kous $
  */
 
+#include "kazehakase.h"
 #include "kz-icons.h"
 
 #include <gtk/gtk.h>
@@ -34,21 +37,18 @@ void
 kz_icons_init (void)
 {
 	GtkIconFactory *factory;
-	static gchar *dirname = NULL;
 	GDir *dir;
 	GError *error = NULL;
 	const gchar *entry;
+	gchar *kz_icon_file_name;
 
-	if (!dirname)
-		dirname = g_build_filename(KZ_DATADIR, "icons", NULL);
-
-	dir = g_dir_open(dirname, 0, &error);
+	dir = g_dir_open(KZ_GET_SYSTEM_ICONS_DIR, 0, &error);
 	if (error)
 	{
-		g_warning("%s", error->message);
+		g_warning("can't open icon directory: %s", error->message);
 		g_error_free(error);
+		return;
 	}
-	if (!dir) return;
 
 	factory = gtk_icon_factory_new();
 	gtk_icon_factory_add_default(factory);
@@ -81,7 +81,8 @@ kz_icons_init (void)
 		icon_name[namelen] = '\0';
 
 		/* load icon file */
-		filename = g_build_filename(dirname, entry, NULL);
+		filename = g_build_filename(KZ_GET_SYSTEM_ICONS_DIR, entry,
+                                            NULL);
 		pixbuf = gdk_pixbuf_new_from_file(filename, NULL);
 		g_free (filename);
 
@@ -101,8 +102,10 @@ kz_icons_init (void)
 	/*
 	 * regist kazehakase icon
 	 */
-	kz_icon = gdk_pixbuf_new_from_file
-			(DATADIR "/pixmaps/kazehakase-icon.png", NULL);
+	kz_icon_file_name = g_build_filename(KZ_GET_SYSTEM_PIXMAPS_DIR,
+					     "kazehakase-icon.png", NULL);
+	kz_icon = gdk_pixbuf_new_from_file(kz_icon_file_name, NULL);
+	g_free(kz_icon_file_name);
 	if (kz_icon)
 	{
 		GtkIconSet *icon_set;
