@@ -3,34 +3,27 @@
 #include <string.h>
 #include <glib/gi18n.h>
 
-#include "gobject-utils.h"
 #include "kz-navi.h"
 #include "kazehakase.h"
 #include "bookmarks/kz-bookmark.h"
 #include "bookmarks/kz-bookmark-file.h"
 
-static void kz_navi_class_init   (KzNaviClass  *klass);
-static void kz_navi_init         (KzNavi       *navi);
-static void kz_navi_dispose      (GObject      *object);
+static void dispose      (GObject      *object);
 
 static void cb_navi_load_completed (KzBookmark *bookmark, gpointer data);
 static void cb_navi_load_error     (KzBookmark *bookmark, gpointer data);
 
-static GObjectClass *parent_class = NULL;
-
-KZ_OBJECT_GET_TYPE(kz_navi, "KzNavi", KzNavi,
-                   kz_navi_class_init, kz_navi_init,
-                   G_TYPE_OBJECT)
+G_DEFINE_TYPE(KzNavi, kz_navi, G_TYPE_OBJECT)
 
 static void
 kz_navi_class_init (KzNaviClass *klass)
 {
 	GObjectClass *object_class;
 
-	parent_class = g_type_class_peek_parent(klass);
+	kz_navi_parent_class = g_type_class_peek_parent(klass);
 	object_class = (GObjectClass *)klass;
 
-	object_class->dispose = kz_navi_dispose;
+	object_class->dispose = dispose;
 }
 
 static void
@@ -61,7 +54,7 @@ kz_navi_new_with_info (const gchar *name, const gchar *uri,
 }
 
 static void
-kz_navi_dispose (GObject *object)
+dispose (GObject *object)
 {
 	KzNavi *navi = KZ_NAVI(object);
 
@@ -75,8 +68,8 @@ kz_navi_dispose (GObject *object)
 	navi->title = NULL;
 	navi->type = NULL;
 	
-	if (G_OBJECT_CLASS (parent_class)->dispose)
-		(*G_OBJECT_CLASS (parent_class)->dispose) (object);
+	if (G_OBJECT_CLASS (kz_navi_parent_class)->dispose)
+		(*G_OBJECT_CLASS (kz_navi_parent_class)->dispose) (object);
 }
 
 static void 
@@ -126,7 +119,7 @@ kz_navi_add_bookmark (KzNavi *navi)
 	g_return_if_fail(navi);
 	g_return_if_fail(navi->uri);
 
-	bars = kz_bookmark_get_children(kz_bookmarks->bookmark_bars);
+	bars = kz_bookmark_get_children(KZ_GET_BAR_BOOKMARK);
 	g_return_if_fail(bars);
 	
 	folder = bars->data;
