@@ -27,28 +27,13 @@
 #include "kz-notebook.h"
 #include "kz-actions.h"
 
+static const gpointer KZ_NOTEBOOK_GROUP = "KzNotebookGroup";
+
 enum {
 	PROP_0,
 	PROP_KZ_WINDOW
 };
 
-enum {
-	TARGET_KAZEHAKASE_TAB,
-	TARGET_NETSCAPE_URL,
-	TARGET_TEXT_URI_LIST,
-	TARGET_TEXT_PLAIN,
-	TARGET_STRING
-};
-
-static GtkTargetEntry url_drag_types [] =
-{
-        { "_KAZEHAKASE_TAB", 0, TARGET_KAZEHAKASE_TAB},
-        { "_NETSCAPE_URL",   0, TARGET_NETSCAPE_URL},
-	{ "text/uri-list",   0, TARGET_TEXT_URI_LIST},
-	{ "text/plain",      0, TARGET_TEXT_PLAIN},
-	{ "STRING",          0, TARGET_STRING}
-};
-
 typedef struct _KzNotebookPrivate	KzNotebookPrivate;
 struct _KzNotebookPrivate
 {
@@ -57,6 +42,9 @@ struct _KzNotebookPrivate
 	/* tabs */
 	GList *open_hist;
 	GList *view_hist;
+	GNode *tab_tree;
+
+	GtkWidget *dragged_page;
 };
 
 #define KZ_NOTEBOOK_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), KZ_TYPE_NOTEBOOK, KzNotebookPrivate))
@@ -74,6 +62,10 @@ static void     get_property (GObject         *object,
 static gboolean scroll_event (GtkWidget       *widget,
 			      GdkEventScroll  *event);
 
+static void	drag_begin    (GtkWidget *widget,
+			       GdkDragContext *context);
+static void	drag_end      (GtkWidget *widget,
+			       GdkDragContext *context);
 static void     drag_data_received
 			     (GtkWidget *widget,
 			      GdkDragContext *context,
@@ -82,10 +74,19 @@ static void     drag_data_received
 			      guint info,
 			      guint time);
 
+static void     cb_page_added(GtkNotebook *notebook,
+			      GtkWidget   *child,
+			      guint 	   page_num,
+			      gpointer     data);
 static void     switch_page  (GtkNotebook     *notebook,
 			      GtkNotebookPage *page,
 			      guint 	   page_num);
 
+static void	cb_page_reordered (GtkNotebook *notebook,
+				   GtkWidget   *child,
+				   guint        page_num,
+				   gpointer     data);
+
 G_DEFINE_TYPE (KzNotebook, kz_notebook, GTK_TYPE_NOTEBOOK)
 
 static void
@@ -105,6 +106,8 @@ kz_notebook_class_init (KzNotebookClass *klass)
 	gobject_class->get_property = get_property;
 
 	widget_class->scroll_event       = scroll_event;
+	widget_class->drag_begin         = drag_begin;
+	widget_class->drag_end           = drag_end;
 	widget_class->drag_data_received = drag_data_received;
 
 	notebook_class->switch_page = switch_page;
@@ -122,7 +125,6 @@ kz_notebook_class_init (KzNotebookClass *klass)
 	g_type_class_add_private (gobject_class, sizeof(KzNotebookPrivate));
 }
 
-
 static void
 kz_notebook_init (KzNotebook *notebook)
 {
@@ -132,10 +134,15 @@ kz_notebook_init (KzNotebook *notebook)
 	priv->open_hist = NULL;
 	priv->view_hist = NULL;
 
-	gtk_drag_dest_set(GTK_WIDGET(notebook),
-			  GTK_DEST_DEFAULT_ALL,
-			  url_drag_types, G_N_ELEMENTS(url_drag_types),
-			  GDK_ACTION_MOVE);
+	priv->dragged_page = NULL;
+
+	priv->tab_tree = g_node_new(NULL);
+
+	g_signal_connect(notebook, "page-reordered", 
+			 G_CALLBACK(cb_page_reordered), NULL);
+	g_signal_connect(notebook, "page-added", 
+			 G_CALLBACK(cb_page_added), NULL);
+
 }
 
 
@@ -183,6 +190,7 @@ kz_notebook_new (KzWindow *kz)
 				"kz-window", kz,
 				"scrollable", TRUE,
 				"show-tabs", TRUE,
+				"group", KZ_NOTEBOOK_GROUP,
 				NULL);
 	
 	return GTK_WIDGET(notebook);
@@ -209,6 +217,16 @@ dispose (GObject *object)
 		g_list_free(priv->view_hist);
 		priv->view_hist = NULL;
 	}
+	if (priv->dragged_page)
+	{
+		g_object_unref(priv->dragged_page);
+		priv->dragged_page = NULL;
+	}
+	if (priv->tab_tree)
+	{
+		g_node_destroy(priv->tab_tree);
+		priv->tab_tree = NULL;
+	}
 
 	if (G_OBJECT_CLASS(kz_notebook_parent_class)->dispose)
 		G_OBJECT_CLASS(kz_notebook_parent_class)->dispose(object);
@@ -217,79 +235,79 @@ dispose (GObject *object)
 static gboolean
 scroll_event (GtkWidget *widget, GdkEventScroll *event)
 {
+	GtkWidget* originator;
+	GtkWidget *current;
+	
+	current = gtk_notebook_get_nth_page(GTK_NOTEBOOK(widget),
+					    gtk_notebook_get_current_page(GTK_NOTEBOOK(widget)));
+	originator = gtk_get_event_widget ((GdkEvent *)event);
+
+	/* ignore scroll events from the content of the page */
+	if (!originator || gtk_widget_is_ancestor (originator, current) || originator == current)
+		return FALSE;
+
 	return kz_notebook_scroll_tab(KZ_NOTEBOOK(widget), event->direction);
 }
 
+static void
+drag_begin (GtkWidget *widget, GdkDragContext *context)
+{
+	gint current_page_num;
+	GtkWidget *current_page;
+	KzNotebookPrivate *priv = KZ_NOTEBOOK_GET_PRIVATE(widget);
+
+	current_page_num = gtk_notebook_get_current_page(GTK_NOTEBOOK(widget));
+
+	if (current_page_num < 0)
+		return;
+
+	current_page = gtk_notebook_get_nth_page(GTK_NOTEBOOK(widget), current_page_num);
+	if (current_page)
+		priv->dragged_page = g_object_ref(current_page);
+
+	if (GTK_WIDGET_CLASS(kz_notebook_parent_class)->drag_begin)
+		GTK_WIDGET_CLASS(kz_notebook_parent_class)->drag_begin(widget, context);
+}
+
+static void
+drag_end (GtkWidget *widget, GdkDragContext *context)
+{
+	KzNotebookPrivate *priv = KZ_NOTEBOOK_GET_PRIVATE(widget);
+
+	if (priv->dragged_page)
+		g_object_unref(priv->dragged_page);
+	priv->dragged_page = NULL;
+
+	if (GTK_WIDGET_CLASS(kz_notebook_parent_class)->drag_end)
+		GTK_WIDGET_CLASS(kz_notebook_parent_class)->drag_end(widget, context);
+}
+
 static void
 drag_data_received (GtkWidget *widget,
                     GdkDragContext *context,
                     gint x, gint y,
-                    GtkSelectionData *data,
+                    GtkSelectionData *seldata,
                     guint info,
                     guint time)
 {
-	KzWindow *kz;
-	g_return_if_fail(KZ_IS_WINDOW(widget));
-
-	kz = KZ_NOTEBOOK_GET_PRIVATE(widget)->kz;
-	switch (info)
+	if (seldata->target == gdk_atom_intern_static_string("GTK_NOTEBOOK_TAB"))
 	{
-	case TARGET_KAZEHAKASE_TAB:
-	{
-		GtkWidget *src_widget;
-		KzWindow *src_kz;
-		KzTabLabel *src_kztab;
+		GtkWidget *src_notebook;
+		GtkWidget **child;
+		KzWindow *src_window, *dest_window;
 
-		src_widget = gtk_drag_get_source_widget(context);
-
-		if (!KZ_IS_TAB_LABEL(src_widget)) return;
-		src_kztab = KZ_TAB_LABEL(src_widget);
-
-		src_kz = KZ_WINDOW(kz_app_get_window_from_tab(kz_app, GTK_WIDGET(src_kztab->kzembed)));
-		if (kz == src_kz)
-		{
-			gint n;
-
-			n = gtk_notebook_get_n_pages(GTK_NOTEBOOK(kz->notebook));
-			kz_window_reorder_tab(kz, GTK_WIDGET(src_kztab->kzembed),
-					      n - 1);
-			kz_actions_set_sensitive
-				(kz, KZ_EMBED(KZ_WINDOW_CURRENT_PAGE(kz)));
-			kz_actions_set_tab_sensitive
-				(kz, KZ_EMBED(KZ_WINDOW_CURRENT_PAGE(kz)));
-		}
-		else
-		{
-			kz_window_move_tab(kz, GTK_WIDGET(src_kztab->kzembed));
-		}
-
-		break;
+		child = (void*) seldata->data;
+		src_notebook = gtk_drag_get_source_widget(context);
+		src_window = KZ_NOTEBOOK_GET_PRIVATE(src_notebook)->kz;
+		dest_window = KZ_NOTEBOOK_GET_PRIVATE(widget)->kz;
+		kz_window_move_tab(src_window, dest_window, *child);
+		gtk_drag_finish(context, TRUE, TRUE, time);
 	}
 
-	case TARGET_NETSCAPE_URL:
-	case TARGET_TEXT_URI_LIST:
-	case TARGET_TEXT_PLAIN:
-	case TARGET_STRING:
-	{
-		gchar *string, **strings;
-
-		if (data->length < 0) return;
-		string = g_alloca (data->length + 1);
-
-		memcpy (string, data->data, data->length);
-		string[data->length] = '\0';
-
-		strings = g_strsplit(string, "\n", 2);
-		kz_window_open_new_tab(kz, strings[0]);
-		g_strfreev(strings);
-		break;
-
-	}
-	default:
-		break;
-	}
+	gtk_drag_finish(context, FALSE, FALSE, time);
 }
 
+
 static gboolean
 idle_focus_location_entry(gpointer data)
 {
@@ -325,7 +343,7 @@ switch_page (GtkNotebook *notebook, GtkNotebookPage *page, guint page_num)
 	tab = KZ_TAB_LABEL(gtk_notebook_get_tab_label(notebook, GTK_WIDGET(kzembed)));
 	g_return_if_fail(tab);
 
-	if(kz_tab_label_get_state(tab) == KZ_TAB_LABEL_STATE_LOADED)
+	if (kz_tab_label_get_state(tab) == KZ_TAB_LABEL_STATE_LOADED)
 	{
 		const gchar *location;
 		gboolean focus;
@@ -343,6 +361,39 @@ switch_page (GtkNotebook *notebook, GtkNotebookPage *page, guint page_num)
 		GTK_NOTEBOOK_CLASS(kz_notebook_parent_class)->switch_page(notebook, page, page_num);
 }
 
+static void
+cb_page_added (GtkNotebook *notebook, GtkWidget *child, guint page_num, gpointer data)
+{
+	gtk_notebook_set_tab_reorderable(GTK_NOTEBOOK(notebook), child, TRUE);
+	gtk_notebook_set_tab_detachable(GTK_NOTEBOOK(notebook), child, TRUE);
+}
+
+static void
+cb_page_reordered (GtkNotebook *notebook,
+		   GtkWidget   *child,
+		   guint        page_num,
+		   gpointer     data)
+{
+	KzTabLabel *kztab, *sibtab = NULL;
+	KzBookmark *sib_bookmark = NULL;
+	GtkWidget *sibchild = NULL;
+	KzWindow *kz = KZ_NOTEBOOK_GET_PRIVATE(notebook)->kz;
+
+	sibchild = gtk_notebook_get_nth_page(notebook, page_num + 1);
+	if (sibchild)
+		sibtab = KZ_TAB_LABEL(gtk_notebook_get_tab_label(notebook, sibchild));
+	if (sibtab)
+		sib_bookmark = sibtab->history;
+
+	kztab = KZ_TAB_LABEL(gtk_notebook_get_tab_label(notebook, child));
+	g_object_ref(kztab->history);
+	kz_bookmark_remove(kz->tabs, kztab->history);
+	kz_bookmark_insert_before(kz->tabs, 
+				  kztab->history,
+				  sib_bookmark);
+	g_object_unref(kztab->history);
+}
+
 static gint 
 get_insert_tab_position (KzNotebook *notebook)
 {
@@ -399,40 +450,78 @@ get_insert_tab_position (KzNotebook *notebook)
 	return pos;
 }
 
-KzTabLabel *
+gint
 kz_notebook_open_new_tab_at_pos (KzNotebook *notebook, KzEmbed *embed, KzTabLabel *label, gint pos)
 {
-	GtkWidget *sibembed;
-	KzTabLabel *sibtab = NULL;
 	KzNotebookPrivate *priv = KZ_NOTEBOOK_GET_PRIVATE(notebook);
+	gint inserted_pos;
+
+	inserted_pos = gtk_notebook_insert_page(GTK_NOTEBOOK(notebook),
+						GTK_WIDGET(embed),
+						GTK_WIDGET(label),
+						pos);
 
-	gtk_notebook_insert_page(GTK_NOTEBOOK(notebook),
-			GTK_WIDGET(embed),
-			GTK_WIDGET(label),
-			pos);
 	/* add to this notebook's history */
 	priv->open_hist = g_list_prepend(priv->open_hist, embed);
 
-	if(pos >= 0)
-	{
-		sibembed = gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook), pos);
-		sibtab = KZ_TAB_LABEL(gtk_notebook_get_tab_label(GTK_NOTEBOOK(notebook),
-				      sibembed));
-	}
-	return sibtab;
+	return inserted_pos;
 }
 
-KzTabLabel *
+gint
 kz_notebook_open_new_tab (KzNotebook *notebook, KzEmbed *embed, KzTabLabel *label)
 {
 	gint pos;
-	KzTabLabel *sibtab = NULL;
+	GNode *node;
+	KzNotebookPrivate *priv = KZ_NOTEBOOK_GET_PRIVATE(notebook);
 
 	pos = get_insert_tab_position(notebook);
 
-	sibtab = kz_notebook_open_new_tab_at_pos(notebook, embed, label, pos);
+	pos = kz_notebook_open_new_tab_at_pos(notebook, embed, label, pos);
 
-	return sibtab;
+	/* insret node */
+	node = g_node_new(embed);
+	g_node_append(priv->tab_tree, node);
+
+	return pos;
+}
+
+gint
+kz_notebook_open_new_tab_with_parent (KzNotebook *notebook, KzEmbed *embed, KzTabLabel *label, KzEmbed *parent)
+{
+	gint pos;
+	GNode *node, *parent_node;
+	KzNotebookPrivate *priv = KZ_NOTEBOOK_GET_PRIVATE(notebook);
+
+	pos = get_insert_tab_position(notebook);
+
+	pos = kz_notebook_open_new_tab_at_pos(notebook, embed, label, pos);
+	
+	/* insret node */
+	node = g_node_new(embed);
+	parent_node = g_node_find(priv->tab_tree,
+				  G_IN_ORDER, G_TRAVERSE_ALL, parent);
+	if (parent_node)
+		g_node_append(parent_node, node);
+	else
+		g_node_append(priv->tab_tree, node);
+
+	return pos;
+}
+
+gint
+kz_notebook_prepend_new_tab (KzNotebook *notebook, KzEmbed *embed, KzTabLabel *label)
+{
+	gint pos;
+	GNode *node;
+	KzNotebookPrivate *priv = KZ_NOTEBOOK_GET_PRIVATE(notebook);
+
+	pos = kz_notebook_open_new_tab_at_pos(notebook, embed, label, -1);
+
+	/* insret node */
+	node = g_node_new(embed);
+	g_node_append(priv->tab_tree, node);
+
+	return pos;
 }
 
 gboolean
@@ -443,6 +532,7 @@ kz_notebook_close_tab (KzNotebook *notebook, GtkWidget *widget)
 	GtkWidget *next = NULL;
 	KzNotebookPrivate *priv = KZ_NOTEBOOK_GET_PRIVATE(notebook);
 	KzWindow *kz = priv->kz;
+	GNode *node, *child;
 	GtkWidget *current = gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook),
 						       gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook)));
 	kztab = KZ_TAB_LABEL(gtk_notebook_get_tab_label(GTK_NOTEBOOK(notebook),
@@ -505,10 +595,29 @@ kz_notebook_close_tab (KzNotebook *notebook, GtkWidget *widget)
 
 CLOSE_TAB:
 	priv->view_hist = g_list_remove(priv->view_hist, widget);
+	node = g_node_find(priv->tab_tree,
+			   G_IN_ORDER, G_TRAVERSE_ALL, widget);
+	if (node)
+	{
+		/* move children */
+		child = g_node_first_child(node);
+		while (child)
+		{
+			GNode *next = g_node_next_sibling(child);
+			g_node_unlink(child);
+			g_node_append(priv->tab_tree, child);
+			child = next;
+		}
+
+		g_node_destroy(node);
+	}
 	gtk_widget_destroy(widget);
 
 	if (kz && gtk_notebook_get_n_pages(GTK_NOTEBOOK(notebook)) == 0)
+	{
 		gtk_window_set_title(GTK_WINDOW(kz), _("Kazehakase"));
+		kz_window_set_location_entry_text(kz, "");
+	}
 	return TRUE;
 }
 
@@ -555,6 +664,7 @@ kz_notebook_move_tab (KzNotebook *src_notebook, KzNotebook *dest_notebook, GtkWi
 {
 	KzTabLabel *new_kztab;
 	KzNotebookPrivate *dest_priv, *src_priv;
+	GNode *node, *child;
 
 	/* create new tab label */
 	dest_priv = KZ_NOTEBOOK_GET_PRIVATE(dest_notebook);
@@ -577,35 +687,33 @@ kz_notebook_move_tab (KzNotebook *src_notebook, KzNotebook *dest_notebook, GtkWi
 						widget);
 	dest_priv->open_hist = g_list_prepend(dest_priv->open_hist,
 					      widget);
-	return TRUE;
-}
-
-GtkWidget *
-kz_notebook_reorder_tab (KzNotebook *notebook, GtkWidget *widget, gint pos)
-{
-	gint n_pages, cur_pos, sib_pos = pos;
-	GtkWidget *sibtab = NULL;
-
-	n_pages = gtk_notebook_get_n_pages(GTK_NOTEBOOK(notebook));
-	g_return_val_if_fail(pos >= 0 && pos < n_pages, NULL);
-
-	cur_pos = gtk_notebook_page_num(GTK_NOTEBOOK(notebook), widget);
-	if (cur_pos == pos)
-		return NULL;
-
-	if (cur_pos < pos)
-		sib_pos = sib_pos + 1;
-
-	if (sib_pos < n_pages)
+	/* move tab tree */
+	node = g_node_find(src_priv->tab_tree,
+			   G_IN_ORDER, G_TRAVERSE_ALL, widget);
+	if (node)
 	{
-		sibtab = gtk_notebook_get_tab_label(GTK_NOTEBOOK(notebook),
-					gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook), sib_pos));
+		/* move children */
+		child = g_node_first_child(node);
+		while (child)
+		{
+			GNode *next = g_node_next_sibling(child);
+			g_node_unlink(child);
+			g_node_append(src_priv->tab_tree,
+				      child);
+			child = next;
+		}
+
+		/* move node */
+		g_node_unlink(node);
+		if (!dest_priv->tab_tree)
+			dest_priv->tab_tree = g_node_new(NULL);
+		g_node_append(dest_priv->tab_tree, node);
 	}
-
-	gtk_notebook_reorder_child (GTK_NOTEBOOK(notebook),
-				    widget, pos);
-
-	return sibtab;
+	else
+	{
+		g_warning("KzWindow: cannot find tab node!");
+	}
+	return TRUE;
 }
 
 void
@@ -717,3 +825,61 @@ kz_notebook_get_n_pages (KzNotebook *notebook)
 
 	return gtk_notebook_get_n_pages(GTK_NOTEBOOK(notebook));
 }
+
+KzEmbed *
+kz_notebook_get_sibling_embed (KzNotebook *notebook, KzEmbed *embed)
+{
+	gint pos;
+	GtkWidget *sibembed;
+
+	g_return_val_if_fail(KZ_IS_NOTEBOOK(notebook), NULL);
+	g_return_val_if_fail(KZ_IS_EMBED(embed), NULL);
+
+	pos = gtk_notebook_page_num(GTK_NOTEBOOK(notebook), GTK_WIDGET(embed));
+	if (pos < 0)
+		return NULL;
+	pos++;
+	if (pos >= gtk_notebook_get_n_pages(GTK_NOTEBOOK(notebook)))
+		return NULL;
+
+	sibembed = gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook), pos);
+
+	if (sibembed)
+		return KZ_EMBED(sibembed);
+	else
+		return NULL;
+}
+
+KzTabLabel *
+kz_notebook_get_sibling_tab_label (KzNotebook *notebook, KzTabLabel *label)
+{
+	KzEmbed *sibembed;
+	GtkWidget *widget;
+
+	g_return_val_if_fail(KZ_IS_NOTEBOOK(notebook), NULL);
+	g_return_val_if_fail(KZ_IS_TAB_LABEL(label), NULL);
+	g_return_val_if_fail(KZ_IS_EMBED(label->kzembed), NULL);
+
+	sibembed = kz_notebook_get_sibling_embed(notebook, label->kzembed);
+	if (!sibembed)
+		return NULL;
+
+	widget = gtk_notebook_get_tab_label(GTK_NOTEBOOK(notebook), GTK_WIDGET(sibembed));
+	if (widget)
+		return KZ_TAB_LABEL(widget);
+	else
+		return NULL;
+}
+
+GtkWidget *
+kz_notebook_get_dragged_page (KzNotebook *notebook)
+{
+	return KZ_NOTEBOOK_GET_PRIVATE(notebook)->dragged_page;
+}
+
+GNode *
+kz_notebook_get_tree (KzNotebook *notebook)
+{
+	return KZ_NOTEBOOK_GET_PRIVATE(notebook)->tab_tree;
+}
+
