@@ -32,7 +32,6 @@
 #include "egg-pixbuf-thumbnail.h"
 #include "kz-bookmark.h"
 #include "kz-embed.h"
-#include "gobject-utils.h"
 #include "glib-utils.h"
 #include "utils.h"
 #include "kz-marshalers.h"
@@ -59,43 +58,37 @@ enum {
 	LAST_SIGNAL
 };
 
-static void        kz_popup_tablist_class_init             (KzPopupTablistClass *klass);
-static void        kz_popup_tablist_init                   (KzPopupTablist *popup);
-static void        kz_popup_tablist_dispose                (GObject *object);
+static void        dispose                (GObject *object);
 
-static void        kz_popup_tablist_set_property           (GObject *object,
-							    guint prop_id,
-							    const GValue *value,
-							    GParamSpec *pspec);
-static void        kz_popup_tablist_get_property           (GObject *object,
-							    guint prop_id,
-							    GValue *value,
-							    GParamSpec *pspec);
+static void        set_property           (GObject *object,
+                                           guint prop_id,
+                                           const GValue *value,
+                                           GParamSpec *pspec);
+static void        get_property           (GObject *object,
+                                           guint prop_id,
+                                           GValue *value,
+                                           GParamSpec *pspec);
 
 static void        cb_thumbnail_activate                   (KzThumbnailsView *view, 
 							    KzBookmark *bookmark,
 							    gint index,
 							    KzPopupTablist *popup);
 
-static GtkWindowClass *parent_class = NULL;
-
 static gint kz_popup_tablist_signals[LAST_SIGNAL] = {0};
 
-KZ_OBJECT_GET_TYPE(kz_popup_tablist, "KzPopupTablist", KzPopupTablist,
-		   kz_popup_tablist_class_init, kz_popup_tablist_init,
-		   GTK_TYPE_WINDOW)
+G_DEFINE_TYPE(KzPopupTablist, kz_popup_tablist, GTK_TYPE_WINDOW)
 
 static void
 kz_popup_tablist_class_init (KzPopupTablistClass *klass)
 {
 	GObjectClass *object_class;
 
-	parent_class = g_type_class_peek_parent (klass);
+	kz_popup_tablist_parent_class = g_type_class_peek_parent (klass);
 	object_class = (GObjectClass *) klass;
 
-	object_class->dispose      = kz_popup_tablist_dispose;
-	object_class->set_property = kz_popup_tablist_set_property;
-	object_class->get_property = kz_popup_tablist_get_property;
+	object_class->dispose      = dispose;
+	object_class->set_property = set_property;
+	object_class->get_property = get_property;
 	
 	g_object_class_install_property
 		(object_class,
@@ -141,7 +134,7 @@ kz_popup_tablist_init (KzPopupTablist *popup)
 }
 
 static void
-kz_popup_tablist_dispose (GObject *object)
+dispose (GObject *object)
 {
 	KzPopupTablist *popup = KZ_POPUP_TABLIST (object);
 	KzPopupTablistPriv *priv = KZ_POPUP_TABLIST_GET_PRIVATE (popup);
@@ -152,16 +145,16 @@ kz_popup_tablist_dispose (GObject *object)
 		priv->kz = NULL;
 	}
 
-	if (G_OBJECT_CLASS (parent_class)->dispose)
-		G_OBJECT_CLASS (parent_class)->dispose(object);
+	if (G_OBJECT_CLASS (kz_popup_tablist_parent_class)->dispose)
+		G_OBJECT_CLASS (kz_popup_tablist_parent_class)->dispose(object);
 }
 
 
 static void
-kz_popup_tablist_set_property (GObject *object,
-			       guint prop_id,
-			       const GValue *value,
-			       GParamSpec *pspec)
+set_property (GObject *object,
+              guint prop_id,
+              const GValue *value,
+              GParamSpec *pspec)
 {
 	KzPopupTablistPriv *priv = KZ_POPUP_TABLIST_GET_PRIVATE(object);
   
@@ -178,10 +171,10 @@ kz_popup_tablist_set_property (GObject *object,
 
 
 static void
-kz_popup_tablist_get_property (GObject *object,
-			       guint prop_id,
-			       GValue *value,
-			       GParamSpec *pspec)
+get_property (GObject *object,
+              guint prop_id,
+              GValue *value,
+              GParamSpec *pspec)
 {
 	KzPopupTablistPriv *priv = KZ_POPUP_TABLIST_GET_PRIVATE(object);
 
@@ -200,7 +193,7 @@ kz_popup_tablist_get_property (GObject *object,
 GtkWidget *
 kz_popup_tablist_new (KzWindow *kz)
 {
-	return g_object_new (KZ_TYPE_POPUP_TABLIST, 
+	return g_object_new (KZ_TYPE_POPUP_TABLIST,
 			     "type", GTK_WINDOW_POPUP,
 			     "kz-window", kz,
 			     NULL);
@@ -214,14 +207,16 @@ kz_popup_tablist_show(KzPopupTablist *popup, KzBookmark* tabs)
 	GList *list;
 	gint length, width;
 
-	if(priv->now_shown)
+	if (priv->now_shown)
 		return;
+
 	view = kz_thumbnails_view_new();
 
-	kz_thumbnails_view_set_mode(KZ_THUMBNAILS_VIEW(view), KZ_THUMBNAILS_VIEW_PLANE);
+	kz_thumbnails_view_set_mode(KZ_THUMBNAILS_VIEW(view),
+				    KZ_THUMBNAILS_VIEW_PLANE);
 	gtk_widget_show(view);
 
-	if(priv->view)
+	if (priv->view)
 	{
 		gtk_container_remove(GTK_CONTAINER(priv->popup_frame),
 				     priv->view);
