@@ -718,19 +718,25 @@ cb_tree_cursor_changed (GtkTreeView *treeview, gpointer data)
 
 	g_return_if_fail(KZ_IS_PREFS_WIN(data));
 
+	selection = gtk_tree_view_get_selection(treeview);
+	if (!selection)
+		return;
+	if (!gtk_tree_selection_get_selected(selection, &model, &iter))
+	{
+		model = gtk_tree_view_get_model(treeview);
+		if (!gtk_tree_model_get_iter_first(model, &iter))
+			return;
+	}
+	gtk_tree_model_get(model, &iter,
+			   COLUMN_PRIV_DATA, &priv,
+			   COLUMN_TERMINATOR);
+
+	g_return_if_fail(priv);
+	g_return_if_fail(priv->entry);
+
 	win = KZ_PREFS_WIN(data);
 
-	selection = gtk_tree_view_get_selection (treeview);
-	gtk_tree_selection_get_selected (selection, &model, &iter);
-
-	gtk_tree_model_get (model, &iter,
-			    COLUMN_PRIV_DATA, &priv,
-			    COLUMN_TERMINATOR);
-
-	g_return_if_fail (priv);
-	g_return_if_fail (priv->entry);
-
-	kz_prefs_win_set_page (win, priv->entry->path);
+	kz_prefs_win_set_page(win, priv->entry->path);
 }
 
 
