@@ -41,7 +41,6 @@
 #include <stdio.h>
 #include <string.h>
 #include <glib/gstdio.h>
-#include "gobject-utils.h"
 #include "glib-utils.h"
 #include "kz-marshalers.h"
 
@@ -55,31 +54,20 @@ enum {
 	LAST_SIGNAL
 };
 
-
-static void kz_profile_class_init (KzProfileClass *klass);
-static void kz_profile_init       (KzProfile      *profile);
-static void kz_profile_dispose    (GObject        *object);
-
-
-static GObjectClass *parent_class = NULL;
+static void dispose    (GObject        *object);
 
 static gint kz_profile_signals[LAST_SIGNAL] = {0};
 
-
-KZ_OBJECT_GET_TYPE(kz_profile, "KzProfile", KzProfile,
-		   kz_profile_class_init, kz_profile_init,
-		   G_TYPE_OBJECT)
-
+G_DEFINE_TYPE(KzProfile, kz_profile, G_TYPE_OBJECT)
 
 static void
 kz_profile_class_init (KzProfileClass *klass)
 {
 	GObjectClass *object_class;
 
-	parent_class = g_type_class_peek_parent (klass);
 	object_class = (GObjectClass *) klass;
 
-	object_class->dispose = kz_profile_dispose;
+	object_class->dispose = dispose;
 
 	klass->section_added   = NULL;
 	klass->section_deleted = NULL;
@@ -153,7 +141,7 @@ kz_profile_init (KzProfile *profile)
 
 
 static void
-kz_profile_dispose (GObject *object)
+dispose (GObject *object)
 {
 	KzProfile *profile = KZ_PROFILE(object);
 	KzProfileList *p, *q;
@@ -190,8 +178,8 @@ kz_profile_dispose (GObject *object)
 	}
 	profile->sublist = NULL;
 
-	if (G_OBJECT_CLASS (parent_class)->dispose)
-		G_OBJECT_CLASS (parent_class)->dispose(object);
+	if (G_OBJECT_CLASS (kz_profile_parent_class)->dispose)
+		G_OBJECT_CLASS (kz_profile_parent_class)->dispose(object);
 }
 
 
@@ -916,8 +904,9 @@ kz_profile_delete_section (KzProfile *profile, const gchar *section)
  * key,key
  * RET,TRUE:normal exit,FALSE:error
  */
-gboolean kz_profile_delete_key (KzProfile *profile,
-				const gchar *section, const gchar *key)
+gboolean
+kz_profile_delete_key (KzProfile *profile,
+		       const gchar *section, const gchar *key)
 {
 	gboolean result = FALSE;
 	KzProfileList *p,*q;
