@@ -69,6 +69,7 @@ struct KzProfile_Tag
 {
 	GObject parent;
 
+	gboolean save_eachtime;
 	gboolean edit;
 	gchar *file, *subfile;
 	KzProfileList *list, *sublist;
@@ -236,6 +237,9 @@ GList *kz_profile_enum_key (KzProfile *profile,
 			    const gchar *section,
 			    gboolean users_only);
 
+void   kz_profile_set_save_each_time (KzProfile *profile,
+    				      gboolean save);
+
 G_END_DECLS
 
 #endif /* __KZ_PROFILE_H__ */
