@@ -20,7 +20,6 @@
 
 #include "kazehakase.h"
 #include "kz-proxy-item.h"
-#include "gobject-utils.h"
 #include <glib/gi18n.h>
 
 enum {
@@ -36,38 +35,31 @@ enum {
 	PROP_NO_PROXIES_ON,
 };
 
-static void kz_proxy_item_class_init	(KzProxyItemClass *klass);
-static void kz_proxy_item_init		(KzProxyItem *proxy_item);
-static void kz_proxy_item_dispose	(GObject *object);
-static void kz_proxy_item_set_property	(GObject *object,
-					 guint prop_id,
-					 const GValue *value,
-					 GParamSpec *pspec);
-static void kz_proxy_item_get_property	(GObject *object,
-					 guint prop_id,
-					 GValue *value,
-					 GParamSpec *pspec);
+static void dispose	 (GObject *object);
+static void set_property (GObject *object,
+                          guint prop_id,
+                          const GValue *value,
+                          GParamSpec *pspec);
+static void get_property (GObject *object,
+                          guint prop_id,
+                          GValue *value,
+                          GParamSpec *pspec);
 
 static gchar *no_proxies_on_default = "127.0.0.1, localhost";
 static guint  proxy_port_default = 0;
 
-static GObjectClass *parent_class = NULL;
-
-KZ_OBJECT_GET_TYPE(kz_proxy_item, "KzProxyItem", KzProxyItem,
-                   kz_proxy_item_class_init, kz_proxy_item_init,
-                   G_TYPE_OBJECT)
+G_DEFINE_TYPE(KzProxyItem, kz_proxy_item, G_TYPE_OBJECT)
 
 static void
 kz_proxy_item_class_init (KzProxyItemClass *klass)
 {
         GObjectClass *gobject_class;
 
-        parent_class = g_type_class_peek_parent (klass);
         gobject_class = (GObjectClass *) klass;
-        gobject_class->dispose = kz_proxy_item_dispose;
+        gobject_class->dispose = dispose;
 
-	gobject_class->set_property = kz_proxy_item_set_property;
-	gobject_class->get_property = kz_proxy_item_get_property;
+	gobject_class->set_property = set_property;
+	gobject_class->get_property = get_property;
 
 	g_object_class_install_property(
 		gobject_class,
@@ -178,7 +170,7 @@ kz_proxy_item_init (KzProxyItem *proxy_item)
 }
 
 static void
-kz_proxy_item_dispose (GObject *object)
+dispose (GObject *object)
 {
 	KzProxyItem *item = KZ_PROXY_ITEM(object);
 
@@ -189,8 +181,8 @@ kz_proxy_item_dispose (GObject *object)
 	if (item->no_proxies_on != no_proxies_on_default)
 		g_free(item->no_proxies_on);
 
-	if (G_OBJECT_CLASS (parent_class)->dispose)
-		G_OBJECT_CLASS (parent_class)->dispose(object);
+	if (G_OBJECT_CLASS (kz_proxy_item_parent_class)->dispose)
+		G_OBJECT_CLASS (kz_proxy_item_parent_class)->dispose(object);
 
 }
 
@@ -203,10 +195,10 @@ kz_proxy_item_new (void)
 }
 
 static void
-kz_proxy_item_set_property (GObject *object,
-			    guint prop_id,
-			    const GValue *value,
-			    GParamSpec *pspec)
+set_property (GObject *object,
+              guint prop_id,
+              const GValue *value,
+              GParamSpec *pspec)
 {
 	KzProxyItem *item = KZ_PROXY_ITEM(object);
 
@@ -246,10 +238,10 @@ kz_proxy_item_set_property (GObject *object,
 }
 
 static void
-kz_proxy_item_get_property (GObject *object,
-			    guint prop_id,
-			    GValue *value,
-			    GParamSpec *pspec)
+get_property (GObject *object,
+              guint prop_id,
+              GValue *value,
+              GParamSpec *pspec)
 {
 	KzProxyItem *item = KZ_PROXY_ITEM(object);
 
@@ -289,7 +281,7 @@ kz_proxy_item_get_property (GObject *object,
 }
 
 #define KZ_CONF_PROXY_GET(s, k, v, t)                   \
-	kz_profile_get_value(kz_proxy,                  \
+	kz_profile_get_value(KZ_GET_PROXY,              \
 			     s, k, &(v), sizeof(v),     \
 			     KZ_PROFILE_VALUE_TYPE_##t)
 
@@ -354,7 +346,7 @@ kz_proxy_get_list (void)
 {
 	GList *list, *node, *r;
 
-	list = kz_profile_enum_section(kz_proxy);
+	list = kz_profile_enum_section(KZ_GET_PROXY);
 	r = NULL;
 	for (node = list; node; node = g_list_next(node))
 		r = g_list_append(r, kz_proxy_find(node->data));
