@@ -67,13 +67,13 @@ struct _KzSidebarEntry
 	gint         priority_hint;
 	const gchar *label;
 	const gchar *icon; /* icon stock */
-	GtkWidget   *(*create) (KzSidebar *kz);
+	GtkWidget   *(*create) (KzSidebarEntry *entry, KzSidebar *kz);
 };
 
 GType	          kz_sidebar_get_type           (void) G_GNUC_CONST;
 GtkWidget        *kz_sidebar_new                (KzWindow *kz);
-gboolean          Kz_sidebar_append_item        (KzSidebarEntry *item);
-const gchar      *kz_sidebar_get_current        (KzSidebar *Sidebar);
+void              kz_sidebar_append_entry       (KzSidebarEntry *entry);
+const gchar      *kz_sidebar_get_current        (KzSidebar *sidebar);
 gboolean          kz_sidebar_set_current        (KzSidebar *sidebar,
 						 const gchar *label);
 
