@@ -53,12 +53,14 @@ struct _KzStatusbarPrivate
 	guint status_link_message;
 	guint status_gesture;
 	guint status_search;
+	guint status_text_copy;
 };
 #define KZ_STATUSBAR_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), KZ_TYPE_STATUSBAR, KzStatusbarPrivate))
 
 #define STATUS_LINK_MESSAGE "INTERNAL_LINK_MESSAGE"
 #define STATUS_GESTURE "INTERNAL_GESTURE"
 #define STATUS_SEARCH "INTERNAL_SEARCH"
+#define STATUS_TEXT_COPY "INTERNAL_TEXT_COPY"
 
 static GObject *constructor (GType type,
                              guint n_props,
@@ -170,6 +172,9 @@ kz_statusbar_init (KzStatusbar *bar)
 	priv->status_search =
 		gtk_statusbar_get_context_id(GTK_STATUSBAR(priv->statusbar),
 					     STATUS_SEARCH);
+	priv->status_text_copy =
+		gtk_statusbar_get_context_id(GTK_STATUSBAR(priv->statusbar),
+					     STATUS_TEXT_COPY);
 
 	/* status bar */
 	gtk_statusbar_set_has_resize_grip(GTK_STATUSBAR(priv->statusbar),
@@ -344,6 +349,18 @@ kz_statusbar_set_gesture_text (KzStatusbar *bar, const gchar *text)
 }
 
 
+void
+kz_statusbar_set_copied_text (KzStatusbar *bar, const gchar *text)
+{
+	KzStatusbarPrivate *priv;
+
+	g_return_if_fail(KZ_IS_STATUSBAR(bar));
+	
+	priv = KZ_STATUSBAR_GET_PRIVATE (bar);
+
+	kz_statusbar_set_text(bar, text, priv->status_text_copy);
+}
+
 void
 kz_statusbar_set_focus_to_find_area (KzStatusbar *bar)
 {
