@@ -594,6 +594,7 @@ static void
 realize (GtkWidget *widget)
 {
 	KzTabLabel *kztab = KZ_TAB_LABEL(widget);
+	KzTabLabelPrivate *priv = KZ_TAB_LABEL_GET_PRIVATE(widget);
 
 	if (GTK_WIDGET_CLASS (kz_tab_label_parent_class)->realize)
 		GTK_WIDGET_CLASS (kz_tab_label_parent_class)->realize(widget);
@@ -605,6 +606,8 @@ realize (GtkWidget *widget)
 
 	if (kz_embed_is_loading(kztab->kzembed))
 		kz_tab_label_set_state (kztab, KZ_TAB_LABEL_STATE_LOADING);
+
+	priv->javascript = kz_embed_get_allow_javascript(kztab->kzembed);
 }
 
 static gboolean
