@@ -62,8 +62,6 @@ struct _KzTabLabel
 	GtkWidget       *label;
 	GtkWidget       *close_button;
 	GtkWidget       *lock_button;
-
-	GtkTooltips     *tooltips;
 	GdkBitmap       *mask;
 	GdkPixbuf       *favicon_pixbuf;
 	GdkPixmap       *circle;
@@ -102,13 +100,13 @@ void             kz_tab_label_set_lock          (KzTabLabel *kztab,
 						 gboolean    lock);
 gboolean         kz_tab_label_get_auto_refresh  (KzTabLabel *kztab);
 void             kz_tab_label_set_auto_refresh  (KzTabLabel *kztab,
-						 gboolean auto_refresh);
-gboolean         kz_tab_label_get_javascript  (KzTabLabel *kztab);
-void             kz_tab_label_set_javascript  (KzTabLabel *kztab,
-						 gboolean javascript);
+						 gboolean    auto_refresh);
+gboolean         kz_tab_label_get_javascript    (KzTabLabel *kztab);
+void             kz_tab_label_set_javascript    (KzTabLabel *kztab,
+						 gboolean    javascript);
 
-void
-kz_tab_label_set_history (KzTabLabel *kztab, KzBookmark *history);
+void		 kz_tab_label_set_history       (KzTabLabel *kztab,
+						 KzBookmark *history);
 G_END_DECLS
 
 #endif /* __KZ_TAB_LABEL_H__ */
