@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-xml.c 3408 2008-02-27 11:02:13Z ikezoe $
+ *  $Id: kz-xml.c 3484 2008-03-14 03:21:32Z ikezoe $
  */
 
 #include "kz-xml.h"
@@ -348,7 +348,7 @@ kz_xml_node_new(KzXML *xml, KzXMLNodeType type)
 	g_return_val_if_fail(type > KZ_XML_NODE_INVALID &&
 			     type < KZ_XML_N_NODE_TYPES,
 			     NULL);
-	node = g_new0(KzXMLNode, 1);
+	node = g_slice_new0(KzXMLNode);
 	node->type        = type;
 	node->content     = NULL;
 	node->parent      = NULL;
@@ -380,7 +380,7 @@ kz_xml_node_new(KzXML *xml, KzXMLNodeType type)
 	}
 	case KZ_XML_NODE_ELEMENT:
 	{
-		KzXMLElement *element = g_new0(KzXMLElement, 1);
+		KzXMLElement *element = g_slice_new0(KzXMLElement);
 		element->name  = NULL;
 		element->attrs = NULL;
 		node->content = element;
@@ -436,14 +436,14 @@ kz_xml_node_unref(KzXMLNode *node)
 		g_free(element->name);
 		g_list_foreach(element->attrs, (GFunc)kz_xml_attr_free, NULL);
 		g_list_free(element->attrs);
-		g_free(element);
+		g_slice_free(KzXMLElement, element);
 	}
 	else if (node->type != KZ_XML_NODE_DOC_ROOT)
 	{
 		g_free(node->content);
 	}
 
-	g_free(node);
+	g_slice_free(KzXMLNode, node);
 }
 
 
@@ -452,7 +452,7 @@ kz_xml_attr_free (KzXMLAttr *attr)
 {
 	g_free(attr->name);
 	g_free(attr->value);
-	g_free(attr);
+	g_slice_free(KzXMLAttr, attr);
 }
 
 
@@ -675,15 +675,13 @@ kz_xml_node_set_attr (KzXMLNode *node, const gchar *name, const gchar *value)
 			g_warning("Attribute %s is duplicated!", attr->name);
 			element->attrs
 				= g_list_remove(element->attrs, attr);
-			g_free(attr->name);
-			g_free(attr->value);
-			g_free(attr);
+			kz_xml_attr_free(attr);
 		}
 	}
 
 	if (!found)
 	{
-		attr = g_new0(KzXMLAttr, 1);
+		attr = g_slice_new0(KzXMLAttr);
 		attr->name  = g_strdup(name);
 		attr->value = g_strdup(value);
 		element->attrs = g_list_append(element->attrs, attr);
