@@ -26,13 +26,15 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <errno.h>
-#include <unistd.h>
-#include <stdio.h>
 #include <fcntl.h>
 
 #include <stdlib.h>
 #include <string.h>
 
+#ifdef HAVE_UNISTD_H
+#  include <unistd.h>
+#endif
+
 /* #include <glib/gi18n.h> */
 
 #define GDK_PIXBUF_ENABLE_BACKEND
@@ -41,6 +43,7 @@
 #include "eggmd5.h"
 #include "egg-pixbuf-thumbnail.h"
 #include <glib/gi18n.h>
+#include <glib/gstdio.h>
 
 /* FIXME: #include "gdk-pixbuf-private.h" */
 
@@ -80,17 +83,18 @@
 #define THUMB_SOFTWARE_VALUE	"GdkPixbuf"
 
 
-#define SIZE_TO_DIR(size) ({\
-  const gchar *__r; \
-  if (size == EGG_PIXBUF_THUMB_NORMAL) \
-    __r = NORMAL_DIR_NAME; \
-  else if (size == EGG_PIXBUF_THUMB_LARGE) \
-    __r = LARGE_DIR_NAME; \
-  else \
-    __r = NULL; \
-  __r; \
-})
-
+static const gchar *
+size_to_dir (size) 
+{
+  const gchar *__r;
+  if (size == EGG_PIXBUF_THUMB_NORMAL)
+    __r = NORMAL_DIR_NAME;
+  else if (size == EGG_PIXBUF_THUMB_LARGE)
+    __r = LARGE_DIR_NAME;
+  else
+    __r = NULL;
+  return __r;
+}
 
 static gboolean ensure_thumbnail_dirs (GError **error);
 
@@ -265,7 +269,7 @@ egg_pixbuf_get_thumbnail_for_file (const gchar         *filename,
   g_return_val_if_fail (size == EGG_PIXBUF_THUMB_NORMAL || size == EGG_PIXBUF_THUMB_LARGE, NULL);
   g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
 
-  if (stat (filename, &st) < 0)
+  if (g_stat (filename, &st) < 0)
     {
       gchar *utf8_filename;
 
@@ -276,7 +280,8 @@ egg_pixbuf_get_thumbnail_for_file (const gchar         *filename,
       return NULL;
     }
 
-  if (!S_ISREG (st.st_mode) && !S_ISLNK (st.st_mode))
+  if (!g_file_test(filename, G_FILE_TEST_IS_REGULAR) &&
+      !g_file_test(filename, G_FILE_TEST_IS_SYMLINK))
     return NULL;
 
   uri = g_strconcat ("file://", filename, NULL);
@@ -662,6 +667,7 @@ egg_pixbuf_has_failed_thumbnail (const gchar  *uri,
   g_free (md5);
   filename = g_build_filename (g_get_home_dir (), ".thumbnails", FAIL_DIR_NAME,
 			       APP_DIR_NAME, basename, NULL);
+  g_free (basename);
   thumb = gdk_pixbuf_new_from_file (filename, NULL);
   g_free (filename);
 
@@ -981,7 +987,7 @@ egg_pixbuf_set_thumb_size (GdkPixbuf          *thumbnail,
   g_return_val_if_fail (GDK_IS_PIXBUF (thumbnail), FALSE);
   g_return_val_if_fail (size == EGG_PIXBUF_THUMB_NORMAL || size == EGG_PIXBUF_THUMB_LARGE, FALSE);
 
-  return gdk_pixbuf_set_option (thumbnail, THUMB_SIZE_KEY, SIZE_TO_DIR (size));
+  return gdk_pixbuf_set_option (thumbnail, THUMB_SIZE_KEY, size_to_dir(size));
 }
 
 
@@ -1557,7 +1563,8 @@ egg_pixbuf_get_thumb_filename (const gchar        *uri,
 
   md5 = egg_str_get_md5_str (uri);
   basename = g_strconcat (md5, ".png", NULL);
-  filename = g_build_filename (home_dir, ".thumbnails", SIZE_TO_DIR (size), basename, NULL);
+  filename = g_build_filename (home_dir, ".thumbnails", size_to_dir(size), basename, NULL);
+  g_free (md5);
   g_free (basename);
 
   return filename;
@@ -1567,7 +1574,7 @@ egg_pixbuf_get_thumb_filename (const gchar        *uri,
 static gboolean
 ensure_one_dir (const gchar *path, GError **error)
 {
-  if (!g_file_test (path, G_FILE_TEST_IS_DIR) && mkdir (path, 0700) < 0)
+  if (!g_file_test (path, G_FILE_TEST_IS_DIR) && g_mkdir (path, 0700) < 0)
     {
       gchar *utf8_path;
 
