@@ -29,6 +29,10 @@
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
 
+#ifndef G_OS_WIN32
+#include <signal.h>
+#endif
+
 #include "kazehakase.h"
 #include "kz-window.h"
 #include "kz-ext.h"
@@ -52,7 +56,9 @@ static GOptionContext *context;
 static GOptionGroup *main_group;
 
 static void activate_action(const gchar *text);
-
+#ifndef G_OS_WIN32
+static void kz_sighandle_exit(int signum);
+#endif
 /******************************************************************************
  *                                                                            *
  *                       arguments parser                                     *
@@ -406,6 +412,22 @@ check_kazehakase_process (int argc, char *argv[])
 	return window;
 }
 
+#ifndef G_OS_WIN32
+/**
+ * Signal handler for safe termination from external signal
+ * @param signum signal number, will be SIGINT or SIGTERM
+ */
+/* TODO:should handle more about other signum? */
+static void kz_sighandle_exit(int signum)
+{
+	g_warning("Start terminate ...");
+	struct sigaction act;
+	memset(&act, 0, sizeof(struct sigaction));
+	act.sa_handler = SIG_IGN;
+	sigaction(signum, &act, NULL);
+	gtk_main_quit();
+}
+#endif
 
 /******************************************************************************
  *                                                                            *
@@ -483,6 +505,16 @@ main (int argc, char *argv[])
 		return 0;   /* found kazehakase process */
 	}
 
+	/* signal handler for safe termination */
+	/* TODO: need win32 version? */
+#ifndef G_OS_WIN32
+	struct sigaction act;
+	memset(&act, 0, sizeof(struct sigaction));
+	act.sa_handler = kz_sighandle_exit;
+	sigaction(SIGINT,	&act, NULL);
+	sigaction(SIGTERM,	&act, NULL);
+#endif
+
  	kz_app = kz_app_new(argc, argv);
 	kz_app_init_dependencies(kz_app, &initial_address);
 
