@@ -871,9 +871,9 @@ gnet_inetaddr_new_list_async (const gchar* hostname, gint port,
 	if ((ialist = gnet_gethostbyname(hostname)) != NULL)
 	  {
 	    GList* i;
-	    char* buf;
+	    guchar* buf;
 	    int buflen = 0;
-	    char* bufp;
+	    guchar* bufp;
 	    int rv;
 
 	    /* Calculate size needed for buffer.  The buffer is a list
@@ -1601,7 +1601,7 @@ gnet_inetaddr_get_name_async_cb (GIOChannel* iochannel,
   if (condition & G_IO_IN)
     {
       int rv;
-      char* buf;
+      guchar* buf;
       int length;
 
       buf = &state->buffer[state->len];
