@@ -27,7 +27,6 @@
 #include <string.h>
 #include <glib/gi18n.h>
 
-#include "gobject-utils.h"
 #include "kz-io.h"
 #include "kz-http.h"
 #include "kz-file.h"
@@ -50,17 +49,15 @@ enum {
 	PROP_FILESIZE
 };
 
-static void kz_io_class_init      (KzIOClass *klass);
-static void kz_io_init            (KzIO *io);
-static void kz_io_set_property    (GObject *object,
-				   guint prop_id,
-				   const GValue *value,
-				   GParamSpec *pspec);
-static void kz_io_get_property    (GObject *object,
-				   guint prop_id,
-				   GValue *value,
-				   GParamSpec *pspec);
-static void kz_io_dispose         (GObject *object);
+static void set_property    (GObject *object,
+                             guint prop_id,
+                             const GValue *value,
+                             GParamSpec *pspec);
+static void get_property    (GObject *object,
+                             guint prop_id,
+                             GValue *value,
+                             GParamSpec *pspec);
+static void dispose         (GObject *object);
 
 static void     kz_io_set_mode        (KzIO *io, KzIOMode mode); /* read or write mode */
 static void     kz_io_set_buffer_mode (KzIO *io);
@@ -125,29 +122,23 @@ kz_io_mode_type_get_type (void)
 	return etype;
 }
 
-
-static GObjectClass *parent_class = NULL;
 static gint kz_io_signals[IO_LAST_SIGNAL] = {0};
 
 static GQuark error_quark     = 0;
 
 /* static GQuark redirect_quark  = 0; */
-
-KZ_OBJECT_GET_TYPE(kz_io, "KzIO", KzIO,
-		   kz_io_class_init, kz_io_init,
-		   G_TYPE_OBJECT)
+G_DEFINE_TYPE(KzIO, kz_io, G_TYPE_OBJECT)
 
 static void
 kz_io_class_init (KzIOClass *klass)
 {
 	GObjectClass *object_class;
 
-	parent_class = g_type_class_peek_parent (klass);
 	object_class = (GObjectClass *) klass;
 
-	object_class->dispose      = kz_io_dispose;
-	object_class->set_property = kz_io_set_property;
-	object_class->get_property = kz_io_get_property;
+	object_class->dispose      = dispose;
+	object_class->set_property = set_property;
+	object_class->get_property = get_property;
 	
 	klass->io_progress         = NULL;
 	klass->io_completed        = NULL;
@@ -252,7 +243,7 @@ kz_io_init (KzIO *io)
 
 
 void
-kz_io_dispose (GObject *object)
+dispose (GObject *object)
 {
 	KzIO *io;
 	KzIOPrivate *priv = KZ_IO_GET_PRIVATE (object);
@@ -285,16 +276,16 @@ kz_io_dispose (GObject *object)
 	priv->buffer    = NULL;
 	priv->error     = NULL;
 
-	if (G_OBJECT_CLASS (parent_class)->dispose)
-		G_OBJECT_CLASS (parent_class)->dispose(object);
+	if (G_OBJECT_CLASS (kz_io_parent_class)->dispose)
+		G_OBJECT_CLASS (kz_io_parent_class)->dispose(object);
 }
 
 
 static void
-kz_io_set_property (GObject *object,
-		    guint prop_id,
-		    const GValue *value,
-		    GParamSpec *pspec)
+set_property (GObject *object,
+              guint prop_id,
+              const GValue *value,
+              GParamSpec *pspec)
 {
 	KzIOPrivate *priv = KZ_IO_GET_PRIVATE (object);
 
@@ -321,10 +312,10 @@ kz_io_set_property (GObject *object,
 
 
 static void
-kz_io_get_property (GObject *object,
-		    guint prop_id,
-		    GValue *value,
-		    GParamSpec *pspec)
+get_property (GObject *object,
+              guint prop_id,
+              GValue *value,
+              GParamSpec *pspec)
 {
 	KzIOPrivate *priv = KZ_IO_GET_PRIVATE (object);
 
@@ -354,6 +345,8 @@ kz_io_new (const gchar *uri)
 {
 	KzIO *io = NULL;
 
+	if (!uri) return NULL;
+
 	/* FIXME! I think this code is something wrong. */
 	if (g_str_has_prefix(uri, "http://"))
 	{
@@ -479,37 +472,29 @@ cb_io_in(GIOChannel *iochannel, GIOCondition condition,
 	switch (iostatus)
 	{
 	 case G_IO_STATUS_EOF:
+		if(priv->localfile)
 		{
-			if(priv->localfile)
-			{
-				g_io_channel_flush(priv->localfileio, NULL);
-			}
-			g_signal_emit(io,
-				      kz_io_signals[IO_COMPLETED_SIGNAL],
-				      0, NULL);
-			return FALSE;
+			g_io_channel_flush(priv->localfileio, NULL);
 		}
+		g_signal_emit(io,
+			      kz_io_signals[IO_COMPLETED_SIGNAL],
+			      0, NULL);
+		return FALSE;
 	 case G_IO_STATUS_NORMAL:
-		{
-			return TRUE;
-		}
+		return TRUE;
 	 case G_IO_STATUS_AGAIN :
+		if(priv->localfile)
 		{
-			if(priv->localfile)
-			{
-				g_io_channel_flush(priv->localfileio, NULL);
-				g_io_channel_unref(priv->localfileio);
-				priv->localfileio = NULL;
-			}
+			g_io_channel_flush(priv->localfileio, NULL);
+			g_io_channel_unref(priv->localfileio);
+			priv->localfileio = NULL;
+		}
 
-			kz_io_start(io);
-			return FALSE;
-		}
+		kz_io_start(io);
+		return FALSE;
 	 default:
-		{
-			io_error(io);
-			return FALSE;
-		}
+		io_error(io);
+		return FALSE;
 	}
 }
 
@@ -544,22 +529,16 @@ cb_io_out(GIOChannel *iochannel, GIOCondition condition,
 	switch (iostatus)
 	{
 	 case G_IO_STATUS_EOF:
-		{
-			g_io_channel_flush(iochannel, NULL);		
-			g_signal_emit(io,
-				      kz_io_signals[IO_COMPLETED_SIGNAL],
-				      0, NULL);
-			return FALSE;
-		}
+		g_io_channel_flush(iochannel, NULL);		
+		g_signal_emit(io,
+			      kz_io_signals[IO_COMPLETED_SIGNAL],
+			      0, NULL);
+		return FALSE;
 	 case G_IO_STATUS_NORMAL:
-		{
-			return TRUE;
-		}
+		return TRUE;
 	 default:
-		{
-			io_error(io);
-			return FALSE;
-		}
+		io_error(io);
+		return FALSE;
 	}
 }
 
@@ -590,18 +569,14 @@ real_start (KzIO *io)
 static void 
 io_set_iochannel(KzIO *io)
 {
-	GIOStatus iostatus;
 	KzIOPrivate *priv = KZ_IO_GET_PRIVATE (io);
 
 	g_io_channel_set_buffered(io->iochannel, TRUE);
 
 	if (kz_io_get_mode(io) == KZ_IO_READ)
 	{
-		iostatus = g_io_channel_set_flags(io->iochannel,
-						  G_IO_FLAG_NONBLOCK,
-						  NULL);
-		if (iostatus != G_IO_STATUS_NORMAL)
-			io_error(io);
+		GIOStatus iostatus;
+		g_io_channel_set_flags(io->iochannel, G_IO_FLAG_NONBLOCK, NULL);
 
 		priv->source_id = g_io_add_watch(io->iochannel,
 			       G_IO_IN | G_IO_PRI | G_IO_ERR | G_IO_HUP,
