@@ -22,7 +22,8 @@
 
 #include <string.h>
 #include <glib/gi18n.h>
-#include "mozilla-prefs.h"
+#include "kz-embed-prefs.h"
+#include "kz-embed.h"
 #include "kazehakase.h"
 #include "gtk-utils.h"
 
@@ -50,11 +51,11 @@ static void       prefs_font_response (GtkWidget *widget, gint response);
 
 static KzPrefsWinPageEntry prefs_entry =
 {
-	path:          N_("/Font"),
-	priority_hint: 0,
-	ui_level:      KZ_UI_LEVEL_ALL,
-	create:        prefs_font_create,
-	response:      prefs_font_response,
+	/* .path          = */ N_("/Font"),
+	/* .priority_hint = */ 0,
+	/* .ui_level      = */ KZ_UI_LEVEL_ALL,
+	/* .create        = */ prefs_font_create,
+	/* .response      = */ prefs_font_response,
 };
 
 
@@ -216,14 +217,17 @@ font_combo_set (GtkComboBox *combo,
 	gchar *default_font = NULL;
 	GtkListStore *store;
 	gint select = 0, i = 0;
+	KzEmbedPrefs *embed_prefs = KZ_EMBED_PREFS(kz_embed_new("gecko"));
 
 	/* remove old list */
 	store = GTK_LIST_STORE(gtk_combo_box_get_model(combo));
 	gtk_list_store_clear(store);
 	
-	mozilla_prefs_get_font_list(lang, type, 
-				    &fonts, &all_fonts,
-				    &default_font);
+	kz_embed_prefs_get_font_list(embed_prefs, lang, type, 
+				     &fonts, &all_fonts,
+				     &default_font);
+
+	gtk_widget_destroy(GTK_WIDGET(embed_prefs));
 
 	if (!fonts) return;
 
@@ -277,11 +281,11 @@ font_spin_set (GtkSpinButton *spin,
 	g_return_if_fail(type && *type);
 	g_return_if_fail(lang && *lang);
 
-	g_snprintf(key, keysize, "font.%s.%s", type, lang);
+	g_snprintf(key, keysize, "%s_%s", type, lang);
 
 	if (size)
 		use_size = size;
-	else if (!mozilla_prefs_get_int(key, &use_size))
+	else if (!KZ_CONF_GET("Font", key, use_size, INT))
 		use_size = 0;
 
 	if (use_size)
@@ -340,11 +344,11 @@ font_prefs_reset (KzPrefsFont *prefsui)
 			       lang, "monospace", pref->monospace);
 
 		font_spin_set(prefsui->variable_size_spin,
-			      "size.variable", lang, pref->variable_size);
+			      "size_variable", lang, pref->variable_size);
 		font_spin_set(prefsui->fixed_size_spin,
-			      "size.fixed", lang, pref->fixed_size);
+			      "size_fixed", lang, pref->fixed_size);
 		font_spin_set(prefsui->min_size_spin,
-			      "min-size.variable", lang, pref->min_size);
+			      "min-size_variable", lang, pref->min_size);
 	}
 	else
 	{
@@ -750,7 +754,7 @@ prefs_font_create (void)
 
 	gtk_label_set_mnemonic_widget(GTK_LABEL(label), spin);
 
-	mozilla_prefs_get_string("font.default", &str);
+	str = KZ_CONF_GET_STR("Font", "default");
 	GTKUTIL_SET_DEFAULT_HISTORY(prefsui->propotional_menu,
 			    	    str,
 			    	    font_styles, n_font_styles, style);
@@ -759,7 +763,7 @@ prefs_font_create (void)
 		g_free(str);
 		str =NULL;
 	}
-	mozilla_prefs_get_string("font.language.group", &str);
+	str = KZ_CONF_GET_STR("Font", "language_group");
 	GTKUTIL_SET_DEFAULT_HISTORY(prefsui->lang_option_menu,
 			    	    str,
 			    	    fonts_language, n_fonts_languages, code);
@@ -794,58 +798,58 @@ apply_font_prefs (KzPrefsFont *prefsui)
 
 		if (pref->serif)
 		{
-			g_snprintf(key, keysize, "font.name.serif.%s",
+			g_snprintf(key, keysize, "name_serif_%s",
 				   pref->lang);
-			mozilla_prefs_set_string(key, pref->serif);
+			KZ_CONF_SET_STR("Font", key, pref->serif);
 		}
 
 		if (pref->sans_serif)
 		{
-			g_snprintf(key, keysize, "font.name.sans-serif.%s",
+			g_snprintf(key, keysize, "name_sans-serif_%s",
 				   pref->lang);
-			mozilla_prefs_set_string(key, pref->sans_serif);
+			KZ_CONF_SET_STR("Font", key, pref->sans_serif);
 		}
 
 		if (pref->monospace)
 		{
-			g_snprintf(key, keysize, "font.name.monospace.%s",
+			g_snprintf(key, keysize, "name_monospace_%s",
 				   pref->lang);
-			mozilla_prefs_set_string(key, pref->monospace);
+			KZ_CONF_SET_STR("Font", key, pref->monospace);
 		}
 
 		if (pref->variable_size)
 		{
-			g_snprintf(key, keysize, "font.size.variable.%s",
+			g_snprintf(key, keysize, "size_variable_%s",
 				   pref->lang);
-			mozilla_prefs_set_int(key, pref->variable_size);
+			KZ_CONF_SET("Font", key, pref->variable_size, INT);
 		}
 
 		if (pref->fixed_size)
 		{
-			g_snprintf(key, keysize, "font.size.fixed.%s",
+			g_snprintf(key, keysize, "size_fixed_%s",
 				   pref->lang);
-			mozilla_prefs_set_int(key, pref->fixed_size);
+			KZ_CONF_SET("Font", key, pref->fixed_size, INT);
 		}
 
 		if (pref->min_size)
 		{
-			g_snprintf(key, keysize, "font.min-size.variable.%s",
+			g_snprintf(key, keysize, "min-size_variable_%s",
 				   pref->lang);
-			mozilla_prefs_set_int(key, pref->min_size);
-			g_snprintf(key, keysize, "font.min-size.fixed.%s",
+			KZ_CONF_SET("Font", key, pref->min_size, INT);
+
+			g_snprintf(key, keysize, "min-size_fixed_%s",
 				   pref->lang);
-			mozilla_prefs_set_int(key, pref->min_size);
+			KZ_CONF_SET("Font", key, pref->min_size, INT);
 		}
 	}
 
 	i = gtk_combo_box_get_active(prefsui->propotional_menu);
 	if (i >= 0 && i < n_font_styles)
-		mozilla_prefs_set_string("font.default", font_styles[i].style);
+		KZ_CONF_SET_STR("Font", "default", font_styles[i].style);
 
 	i = gtk_combo_box_get_active(prefsui->lang_option_menu);
 	if (i >= 0 && i < n_fonts_languages)
-		mozilla_prefs_set_string("font.language.group",
-					 fonts_language[i].code);
+		KZ_CONF_SET_STR("Font", "language_group", fonts_language[i].code);
 }
 
 
