@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: prefs_key_accel.c,v 1.12 2005/02/13 13:20:36 ikezoe Exp $
+ *  $Id: prefs_key_accel.c 2863 2007-03-14 06:43:16Z ikezoe $
  */
 
 /*
@@ -73,11 +73,11 @@ static void       prefs_key_accel_response (GtkWidget *widget,
 
 static KzPrefsWinPageEntry prefs_entry =
 {
-	path:            N_("/Key Accelerator"),
-	priority_hint:   0,
-	ui_level:        ~KZ_UI_LEVEL_BEGINNER,
-	create:          prefs_key_accel_create,
-	response:        prefs_key_accel_response,
+	/* .path          = */ N_("/Key Accelerator"),
+	/* .priority_hint = */ 0,
+	/* .ui_level      = */ ~KZ_UI_LEVEL_BEGINNER,
+	/* .create        = */ prefs_key_accel_create,
+	/* .response      = */ prefs_key_accel_response,
 };
 
 
