@@ -21,7 +21,6 @@
 #include "prefs_privacy.h"
 #include <glib/gi18n.h>
 
-#include "mozilla-prefs.h"
 #include "kazehakase.h"
 #include "kz-window.h"
 
@@ -35,11 +34,11 @@ static void           prefs_privacy_response        (GtkWidget *widget,
 
 static KzPrefsWinPageEntry prefs_entry =
 {
-	path:            N_("/Privacy"),
-	priority_hint:   0,
-	ui_level:        KZ_UI_LEVEL_EXPERT,
-	create:          prefs_privacy_create,
-	response:        prefs_privacy_response,
+	/* .path          = */ N_("/Privacy"),
+	/* .priority_hint = */ 0,
+	/* .ui_level      = */ KZ_UI_LEVEL_EXPERT,
+	/* .create        = */ prefs_privacy_create,
+	/* .response      = */ prefs_privacy_response,
 };
 
 
@@ -155,7 +154,7 @@ prefs_privacy_create (void)
 		 	GTK_RADIO_BUTTON(radio1),
 			_("_Block cookies"));
 	
-	mozilla_prefs_get_int("network.cookie.cookieBehavior", &behaviour);
+	KZ_CONF_GET("Privacy", "cookie_behaviour", behaviour, INT);
 	switch (behaviour)
 	{
 	 case 0:
@@ -214,7 +213,7 @@ prefs_privacy_create (void)
 	gtk_box_pack_start(GTK_BOX(hbox), radio2, FALSE, FALSE, 0);
 	prefsui->except_check = check =
 		gtk_check_button_new_with_mnemonic(_("e_xcept for session cookies"));
-	mozilla_prefs_get_boolean("network.cookie.alwaysAcceptSessionCookies", &except);
+	KZ_CONF_GET("Privacy", "cookie_always_accept_session_cookie", except, BOOL);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check), except);
 	gtk_box_pack_start(GTK_BOX(hbox), check, FALSE, FALSE, 2);
 	gtk_widget_set_sensitive(check, FALSE);
@@ -233,7 +232,7 @@ prefs_privacy_create (void)
 	prefsui->span_spin = spin
 		= gtk_spin_button_new_with_range(0, 1000, 1);
 	adj = gtk_spin_button_get_adjustment(GTK_SPIN_BUTTON(spin));
-	mozilla_prefs_get_int("network.cookie.lifetime.days", &span);
+	KZ_CONF_GET("Privacy", "cookie_lifetime_days", span, INT);
 	gtk_adjustment_set_value(adj, span);
 	gtk_box_pack_start(GTK_BOX(hbox), spin, FALSE, FALSE, 2);	
 	gtk_widget_set_sensitive(spin, FALSE);
@@ -253,7 +252,7 @@ prefs_privacy_create (void)
 	g_signal_connect(radio4, "toggled",
 			 G_CALLBACK(cb_lifespan_span_changed), prefsui);
 	
-	mozilla_prefs_get_int("network.cookie.lifetimePolicy", &lifetime);
+	KZ_CONF_GET("Privacy", "cookie_lifetime_policy", lifetime, INT);
 	switch (lifetime)
 	{
 	 case 0:
@@ -325,12 +324,13 @@ prefs_privacy_response (GtkWidget *widget, gint response)
 		gint behaviour = 0;
 		gint lifetime = 0;
 		gint span, length;
+		gint value;
 
 		gboolean except;
 		if (!prefsui->changed)
 			break;
 		
-		/* cokkie behaviour */
+		/* cookie behaviour */
 		group  = gtk_radio_button_get_group(GTK_RADIO_BUTTON(prefsui->cookie_behaviour));
 		length = g_slist_length(group);
 
@@ -343,10 +343,10 @@ prefs_privacy_response (GtkWidget *widget, gint response)
 				break;
 			behaviour++;
 		}
-		mozilla_prefs_set_int("network.cookie.cookieBehavior",
-				      (length - 1) - behaviour);
+		value = (length -1) - behaviour;
+		KZ_CONF_SET("Privacy", "cookie_behaviour", value, INT);
 
-		/* cokkie lifetime */
+		/* cookie lifetime */
 		group  = gtk_radio_button_get_group(GTK_RADIO_BUTTON(prefsui->cookie_lifetime));
 		length = g_slist_length(group);
 
@@ -359,21 +359,19 @@ prefs_privacy_response (GtkWidget *widget, gint response)
 				break;
 			lifetime++;
 		}
-		mozilla_prefs_set_int("network.cookie.lifetimePolicy",
-				      (length - 1) - lifetime);
+		value = (length -1) - lifetime;
+		KZ_CONF_SET("Privacy", "cookie_lifetime_policy", value, INT);
 		
 		/* cookie lifespan days */
 		adj = gtk_spin_button_get_adjustment
 			(GTK_SPIN_BUTTON(prefsui->span_spin));
 		span = gtk_adjustment_get_value(adj);
-		mozilla_prefs_set_int("network.cookie.lifetime.days",
-				      span);
+		KZ_CONF_SET("Privacy", "cookie_lifetime_days", span, INT);
 		
 		/* except for session cookies */
 		except = gtk_toggle_button_get_active
 			      (GTK_TOGGLE_BUTTON(prefsui->except_check));
-		mozilla_prefs_set_boolean("network.cookie.alwaysAcceptSessionCookies",
-					  except);
+		KZ_CONF_SET("Privacy", "cookie_always_accept_session_cookies", except, BOOL);
 
 		prefsui->changed = FALSE;
 
