@@ -21,9 +21,9 @@
 #include "kz-tabtree.h"
 
 #include <glib/gi18n.h>
-#include "gobject-utils.h"
 #include "gtk-utils.h"
 #include "kz-tab-label.h"
+#include "kz-notebook.h"
 #include "kz-actions-tab.h"
 
 static gchar *label_color[KZ_TAB_LABEL_N_STATE];
@@ -51,20 +51,18 @@ static GtkWidget *kz_tab_tree_new (KzSidebarEntry *entry, KzSidebar *sidebar);
 
 
 /* Object class methods */
-static void     kz_tab_tree_class_init   (KzTabTreeClass *klass);
-static void     kz_tab_tree_init         (KzTabTree      *tabtree);
-static GObject *kz_tab_tree_constructor  (GType           type,
-					  guint           n_props,
-					  GObjectConstructParam *props);
-static void     kz_tab_tree_dispose      (GObject        *obj);
-static void     kz_tab_tree_set_property (GObject        *object,
-					  guint           prop_id,
-					  const GValue   *value,
-					  GParamSpec     *pspec);
-static void     kz_tab_tree_get_property (GObject        *object,
-					  guint           prop_id,
-					  GValue         *value,
-					  GParamSpec     *pspec);
+static GObject *constructor  (GType           type,
+                              guint           n_props,
+                              GObjectConstructParam *props);
+static void     dispose      (GObject        *obj);
+static void     set_property (GObject        *object,
+                              guint           prop_id,
+                              const GValue   *value,
+                              GParamSpec     *pspec);
+static void     get_property (GObject        *object,
+                              guint           prop_id,
+                              GValue         *value,
+                              GParamSpec     *pspec);
 
 /* KzTabTree private methods */
 static void         build_tab_tree         (KzTabTree    *tabtree,
@@ -120,45 +118,20 @@ static void     cb_title_changed  (KzEmbed         *embed,
 static KzSidebarEntry kz_sidebar_tab_tree[] = 
 {
 	{
-		priority_hint: 0,
-		label:         N_("Tab List"),
-		icon:          NULL,
-		create:        kz_tab_list_new,
+		/* .priority_hint = */ 0,
+		/* .label         = */ N_("Tab List"),
+		/* .icon          = */ NULL,
+		/* .create        = */ kz_tab_list_new,
 	},
 	{
-		priority_hint: 0,
-		label:         N_("Tab Tree"),
-		icon:          NULL,
-		create:        kz_tab_tree_new,
+		/* .priority_hint = */ 0,
+		/* .label         = */ N_("Tab Tree"),
+		/* .icon          = */ NULL,
+		/* .create        = */ kz_tab_tree_new,
 	},
 };
 
 
-enum {
-	TARGET_KAZEHAKASE_TAB,
-	TARGET_NETSCAPE_URL,
-	TARGET_TEXT_URI_LIST,
-	TARGET_TEXT_PLAIN,
-	TARGET_STRING
-};
-
-
-#if 0
-static GtkTargetEntry dnd_types [] = 
-{
-        { "_KAZEHAKASE_TAB", 0, TARGET_KAZEHAKASE_TAB},
-        { "_NETSCAPE_URL",   0, TARGET_NETSCAPE_URL},
-	{ "text/uri-list",   0, TARGET_TEXT_URI_LIST},
-	{ "text/plain",      0, TARGET_TEXT_PLAIN},
-	{ "STRING",          0, TARGET_STRING}
-};
-static guint n_dnd_types = G_N_ELEMENTS (dnd_types);
-#endif
-
-
-static GtkVBoxClass *parent_class = NULL;
-
-
 KzSidebarEntry *
 kz_tab_tree_get_entry (gint idx)
 {
@@ -175,24 +148,19 @@ kz_tab_tree_get_entry (gint idx)
 	return NULL;
 }
 
-
-KZ_OBJECT_GET_TYPE(kz_tab_tree, "KzTabTree", KzTabTree,
-		   kz_tab_tree_class_init, kz_tab_tree_init,
-		   GTK_TYPE_VBOX)
-
+G_DEFINE_TYPE(KzTabTree, kz_tab_tree, GTK_TYPE_VBOX)
 
 static void
 kz_tab_tree_class_init (KzTabTreeClass *klass)
 {
 	GObjectClass *gobject_class;
 
-	parent_class = g_type_class_peek_parent(klass);
 	gobject_class = (GObjectClass *) klass;
 
-	gobject_class->constructor  = kz_tab_tree_constructor;
-	gobject_class->dispose      = kz_tab_tree_dispose;
-	gobject_class->set_property = kz_tab_tree_set_property;
-	gobject_class->get_property = kz_tab_tree_get_property;
+	gobject_class->constructor  = constructor;
+	gobject_class->dispose      = dispose;
+	gobject_class->set_property = set_property;
+	gobject_class->get_property = get_property;
 
 	g_object_class_install_property
 		(gobject_class,
@@ -272,21 +240,6 @@ kz_tab_tree_init (KzTabTree *tabtree)
 	tree_view = GTK_TREE_VIEW(widget);
 	gtk_tree_view_set_rules_hint(GTK_TREE_VIEW(tree_view), TRUE);
 	gtk_container_add(GTK_CONTAINER(scrwin), GTK_WIDGET(tree_view));
-#if 0
-	gtk_tree_view_enable_model_drag_source(GTK_TREE_VIEW(tree_view),
-					       GDK_BUTTON1_MASK
-					       | GDK_BUTTON2_MASK
-					       | GDK_BUTTON3_MASK,
-					       dnd_types,
-					       n_dnd_types,
-					       GDK_ACTION_ASK  | GDK_ACTION_COPY
-					       | GDK_ACTION_MOVE | GDK_ACTION_LINK);
-	gtk_tree_view_enable_model_drag_dest(GTK_TREE_VIEW (tree_view),
-					     dnd_types,
-					     n_dnd_types,
-					     GDK_ACTION_ASK  | GDK_ACTION_COPY
-					     | GDK_ACTION_MOVE | GDK_ACTION_LINK);
-#endif
 	gtk_widget_show(GTK_WIDGET(tree_view));
 
 	column = gtk_tree_view_column_new();
@@ -321,14 +274,14 @@ kz_tab_tree_init (KzTabTree *tabtree)
 
 
 static GObject*
-kz_tab_tree_constructor (GType                  type,
-			 guint                  n_props,
-			 GObjectConstructParam *props)
+constructor (GType                  type,
+             guint                  n_props,
+             GObjectConstructParam *props)
 {
 	KzTabTree *tabtree;
 
 	GObject *object;
-	GObjectClass *klass = G_OBJECT_CLASS(parent_class);
+	GObjectClass *klass = G_OBJECT_CLASS(kz_tab_tree_parent_class);
 
 	object = klass->constructor(type, n_props, props);
 
@@ -361,7 +314,7 @@ kz_tab_tree_constructor (GType                  type,
 
 
 static void
-kz_tab_tree_dispose (GObject *obj)
+dispose (GObject *obj)
 {
 	KzTabTree *tabtree = KZ_TAB_TREE(obj);
 
@@ -399,16 +352,16 @@ kz_tab_tree_dispose (GObject *obj)
 		g_object_unref(tabtree->store);
 		tabtree->store = NULL;
 	}
-	if (G_OBJECT_CLASS (parent_class)->dispose)
-		G_OBJECT_CLASS (parent_class)->dispose(obj);
+	if (G_OBJECT_CLASS (kz_tab_tree_parent_class)->dispose)
+		G_OBJECT_CLASS (kz_tab_tree_parent_class)->dispose(obj);
 }
 
 
 static void
-kz_tab_tree_set_property (GObject         *object,
-			  guint            prop_id,
-			  const GValue    *value,
-			  GParamSpec      *pspec)
+set_property (GObject         *object,
+              guint            prop_id,
+              const GValue    *value,
+              GParamSpec      *pspec)
 {
 	KzTabTree *tabtree = KZ_TAB_TREE(object);
   
@@ -428,10 +381,10 @@ kz_tab_tree_set_property (GObject         *object,
 
 
 static void
-kz_tab_tree_get_property (GObject         *object,
-			  guint            prop_id,
-			  GValue          *value,
-			  GParamSpec      *pspec)
+get_property (GObject         *object,
+              guint            prop_id,
+              GValue          *value,
+              GParamSpec      *pspec)
 {
 	KzTabTree *tabtree = KZ_TAB_TREE(object);
 
@@ -534,7 +487,7 @@ build_tab_list (KzTabTree *tabtree)
 	kz = tabtree->sidebar->kz;
 	if (!kz) return;
 
-	num = gtk_notebook_get_n_pages(GTK_NOTEBOOK(kz->notebook));
+	num = kz_notebook_get_n_pages(KZ_NOTEBOOK(kz->notebook));
 
 	for (i = 0; i < num; i++)
 	{
@@ -670,12 +623,12 @@ cb_cursor_changed(GtkTreeView *tree_view, KzTabTree *tabtree)
 			   COLUMN_TERMINATOR);
 	if (!kzembed) return;
 
-	num = gtk_notebook_page_num(GTK_NOTEBOOK(kz->notebook),
-				    GTK_WIDGET(kzembed));
+	num = kz_notebook_page_num(KZ_NOTEBOOK(kz->notebook),
+				   GTK_WIDGET(kzembed));
 	g_return_if_fail(num >= 0);
 
 	tabtree->switching = TRUE;
-	gtk_notebook_set_current_page(GTK_NOTEBOOK(kz->notebook), num);
+	kz_notebook_set_current_page(KZ_NOTEBOOK(kz->notebook), num);
 	tabtree->switching = FALSE;
 }
 
@@ -762,7 +715,7 @@ cb_switch_page (GtkNotebook *notebook, GtkNotebookPage *page,
 
 	if (tabtree->switching) return;
 
-	widget = gtk_notebook_get_nth_page(notebook, page_num);
+	widget = kz_notebook_get_nth_page(KZ_NOTEBOOK(notebook), page_num);
 	iter = find_node(tabtree->store, KZ_EMBED(widget));
 	/* g_return_if_fail(iter); */
 	if (!iter) return;
@@ -798,6 +751,7 @@ cb_append_tab (KzWindow *kz, GtkWidget *widget, GtkWidget *parent,
 	       KzTabTree *tabtree)
 {
 	GtkTreeIter iter;
+	GtkTreePath *path;
 	KzEmbed * kzembed = KZ_EMBED(widget); 
 
 	g_return_if_fail(GTK_IS_WIDGET(widget));
@@ -805,7 +759,7 @@ cb_append_tab (KzWindow *kz, GtkWidget *widget, GtkWidget *parent,
 
 	parent_append(tabtree, kzembed, find_node(tabtree->store, KZ_EMBED(parent)), &iter);
 	
-	GtkTreePath * path = gtk_tree_model_get_path(GTK_TREE_MODEL(tabtree->store), &iter);
+	path = gtk_tree_model_get_path(GTK_TREE_MODEL(tabtree->store), &iter);
 	gtk_tree_view_expand_to_path(tabtree->tree_view, path);
 	gtk_tree_path_free(path);
 }
@@ -817,7 +771,7 @@ parent_append(KzTabTree * tabtree, KzEmbed * kzembed, GtkTreeIter * parent, GtkT
 	const gchar *color;
 	gchar *title = kz_embed_ensure_title(kzembed);
 	const gchar *uri   = kz_embed_get_location(kzembed);
-	GdkPixbuf *favicon = kz_favicon_get_pixbuf(tabtree->sidebar->kz->kzfav,
+	GdkPixbuf *favicon = kz_favicon_get_pixbuf(KZ_GET_FAVICON,
 						   uri,
 						   GTK_ICON_SIZE_MENU);
 
