@@ -108,7 +108,7 @@ gtkutil_append_im_menuitem (GtkMenuShell *shell)
 	menuitem = g_hash_table_lookup(popup_menu_table, shell);
 	if (menuitem)
 	{
-		gtk_menu_item_remove_submenu(GTK_MENU_ITEM(menuitem));
+		gtk_menu_item_set_submenu(GTK_MENU_ITEM(menuitem), NULL);
 	}
 	else
 	{
