@@ -287,35 +287,32 @@ create_filename_with_path_from_uri (const gchar *uri)
 }
 
 
+/**
+ * create uri string from local cache file (ex. /users/http/path.to/data to http://path.to/data)
+ * @param filename filename to create uri for local file path
+ * @return new allocated uri string, that should be g_free
+ */
 gchar *
 create_uri_from_filename (const gchar *filename)
 {
-	gchar *uri;
-	gchar *pos;
-	gchar *scheme;
-	gchar *path;
+	gchar *uri, *pos, *scheme, *path;
 	
 	pos = strstr(filename, G_DIR_SEPARATOR_S);
-	
 	if (!pos)
 		return g_strdup(filename);
 
 	scheme = g_strndup(filename, pos - filename);
-
-	if (g_str_has_suffix(filename, G_DIR_SEPARATOR_S"_"))
+	if (g_str_has_suffix(pos + 1, G_DIR_SEPARATOR_S"_"))
 	{
 		path = g_strndup(pos + 1, strlen(pos) - 2);
 	}
 	else
 	{
-		gchar *query_pos = g_strrstr(filename, "_"G_DIR_SEPARATOR_S);
+		gchar *query_pos = g_strrstr(pos + 1, "_"G_DIR_SEPARATOR_S);
 		if (query_pos)
 		{
 			gchar *string = g_strndup(pos + 1, query_pos - pos - 1);
-			path = g_strconcat(string,
-					   "?",
-					   query_pos + 2,
-					   NULL);
+			path = g_strconcat(string, "?", query_pos + 2, NULL);
 			g_free(string);
 		}
 		else
@@ -1008,6 +1005,7 @@ kz_utils_get_system_name (void)
 	return system;
 }
 
+#ifdef G_OS_WIN32
 static gchar *win32_base_path = NULL;
 
 const gchar *
@@ -1016,10 +1014,9 @@ kz_win32_base_path (void)
 	if (win32_base_path)
 		return win32_base_path;
 
-#ifdef G_OS_WIN32
 	win32_base_path = g_win32_get_package_installation_directory(PACKAGE,
 								     NULL);
-#endif
 
 	return win32_base_path;
 }
+#endif
