@@ -21,7 +21,7 @@
 #ifndef __UTILS_H__
 #define __UTILS_H__
 
-#include <gtk/gtk.h>
+#include <glib.h>
 #include <time.h>
 
 #include "egg-pixbuf-thumbnail.h"
@@ -80,7 +80,9 @@ gchar	*kz_uri_encode_last_component	(const gchar *uri);
 
 gchar	*kz_utils_get_system_name       (void);
 
+#ifdef G_OS_WIN32
 const gchar	*kz_win32_base_path	(void);
+#endif
 
 G_END_DECLS
 
